function SituationList() {
	this.situations = [];
}

SituationList.prototype.add = function(situation) {
	this.situations.push(situation);
};

SituationList.prototype.size = function() {
	return this.situations.length;
};

SituationList.prototype.prettyPrint = function() {
	var ret = "";

	for (var i = 0; i < this.situations.length; i++) {
		if (i > 0)
			ret += "<br/><hr/><br/>";

		ret += this.situations[i].prettyPrint();
	}

	return ret;
};

SituationList.prototype.getSortedUniqueTimesteps = function() {
	var ret = new Array();
	var elements = this.getTimelineElements();

	for (var i = 0; i < elements.length; i++) {
		var timestep = elements[i].start;

		var timestepStr = $.format.date(timestep, 'yyyy-MM-dd HH:mm');
		
		// if ($.inArray(timestep, ret) == -1)
		if (ret.indexOf(timestepStr) > -1)
			continue;

		ret.push(timestepStr);
	}

	return ret.sort();
};

SituationList.prototype.getTimelineElements = function() {
	var ret = [];

	for (var i = 0; i < this.situations.length; i++) {
		var situation = this.situations[i];
		var supportedInfons = situation.getSupportedInfons();

		for (var j = 0; j < supportedInfons.length; j++) {
			var elementaryInfon = supportedInfons[j];
			var relation = elementaryInfon.getRelation();
			var relevantObjects = elementaryInfon.getRelevantObjects();
			var className = RELATION_CLASSNAME_MAP[relation.getId()];
			var group = null;
			
			if (GROUP_TIMELINE) {
				for (var k = 0; k < relevantObjects.length; k++) {
					var relevantObject = relevantObjects[k];
					var relevantObjectType = relevantObject.getType();
					
					if (relevantObjectType == GROUP_RELEVANT_OBJECT_TYPE) {
						var key = null;
						
						if (GROUP_RELEVANT_OBJECT_BY_ID)
							key = relevantObject.getId();
						else 
							key = relevantObject.getValue();
						
						if (GROUP_COVERT_URI_TO_LABEL)
							group = URI_LABEL_MAP[key];
						else
							group = key;
					}
				}
			}
			
			for (var k = 0; k < relevantObjects.length; k++) {
				var relevantObject = relevantObjects[k];
				var relevantObjectType = relevantObject.getType();

				if (relevantObjectType == 'http://envi.uef.fi/wavellite/ontology/entity#TimePoint') {
					var value = relevantObject.getValue();

					ret.push({
						'start' : value,
						'end' : value,
						'content' : relation.getLabel(),
						'className' : className,
						'description' : elementaryInfon.prettyPrint(),
						'group' : group
					});
				} else if (relevantObjectType == 'http://envi.uef.fi/wavellite/ontology/entity#TimeInterval') {
					var start = relevantObject.getStart();
					var end = relevantObject.getEnd();

					ret.push({
						'start' : start,
						'end' : end,
						'content' : relation.getLabel(),
						'className' : className,
						'description' : elementaryInfon.prettyPrint(),
						'group' : group
					});
				}
			}
		}
	}

	return ret;
};

SituationList.prototype.getMapElements = function() {
	var ret = {};

	for (var i = 0; i < this.situations.length; i++) {
		var situation = this.situations[i];
		var supportedInfons = situation.getSupportedInfons();

		for (var j = 0; j < supportedInfons.length; j++) {
			var elementaryInfon = supportedInfons[j];
			var relevantObjects = elementaryInfon.getRelevantObjects();

			for (var k = 0; k < relevantObjects.length; k++) {
				var relevantObject = relevantObjects[k];
				var relevantObjectType = relevantObject.getType();

				if (relevantObjectType != 'http://envi.uef.fi/wavellite/ontology/entity#SpatialRegion')
					continue;

				var geometry = relevantObject.getGeometry();
				var geometryId = geometry.getId();

				var metadata = ret[geometryId];

				if (!metadata) {
					metadata = {
						wkt : geometry.getWKT(),
						situations : new SituationList()
					};
					ret[geometryId] = metadata;
				}

				metadata.situations.add(situation);
			}
		}
	}

	return ret;
};