/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.component.activemq;

import java.util.Properties;

import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.MessageConsumer;
import javax.jms.MessageProducer;
import javax.jms.Session;
import javax.naming.InitialContext;
import javax.naming.NamingException;

/**
 * <p>
 * Title: ActiveMqConnection
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Component
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class ActiveMqConnection {

	private InitialContext jndiContext;
	private ConnectionFactory connectionFactory;
	private javax.jms.Connection connection;
	private Session session;

	public ActiveMqConnection(String connectionFactoryName) {
		this(connectionFactoryName, null);
	}
	
	public ActiveMqConnection(String connectionFactoryName,
			Properties properties) {
		try {
			if (properties == null)
				jndiContext = new InitialContext();
			else
				jndiContext = new InitialContext(properties);
			connectionFactory = (ConnectionFactory) jndiContext
					.lookup(connectionFactoryName);
			connection = connectionFactory.createConnection();
			connection.start();
			session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
		} catch (NamingException | JMSException e) {
			throw new RuntimeException(e);
		}
	}

	public Session getSession() {
		return session;
	}

	public MessageProducer getProducer(String destinationName) {
		try {
			return session.createProducer(getDestination(destinationName));
		} catch (JMSException e) {
			throw new RuntimeException(e);
		}
	}

	public MessageConsumer getConsumer(String destinationName) {
		try {
			return session.createConsumer(getDestination(destinationName));
		} catch (JMSException e) {
			throw new RuntimeException(e);
		}
	}

	public Destination getDestination(String destinationName) {
		try {
			return (Destination) jndiContext.lookup(destinationName);
		} catch (NamingException e) {
			throw new RuntimeException(e);
		}
	}

	public void close() {
		try {
			session.close();
			connection.close();
		} catch (JMSException e) {
			throw new RuntimeException(e);
		}
	}

}
