/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.component.engine.activemq;

import java.io.Serializable;
import java.util.Properties;

import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageConsumer;
import javax.jms.MessageListener;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Session;

import fi.uef.envi.wavellite.component.activemq.ActiveMqConnection;
import fi.uef.envi.wavellite.component.activemq.ActiveMqOptions;
import fi.uef.envi.wavellite.component.engine.base.AbstractEngineSituation;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.situation.Situation;

/**
 * <p>
 * Title: EngineSituationActiveMq
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Component
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public abstract class EngineSituationActiveMq extends AbstractEngineSituation implements
		MessageListener {

	private MessageProducer producer;
	private MessageConsumer consumer;
	private String consumerDestinationName;
	private String producerDestinationName;
	private ActiveMqConnection connection;
	private Session session;

	public EngineSituationActiveMq(String consumerDestinationName,
			String producerDestinationName) {
		this(consumerDestinationName, producerDestinationName,
				ActiveMqOptions.connectionFactoryName);
	}

	public EngineSituationActiveMq(String consumerDestinationName,
			String producerDestinationName, Properties properties) {
		this(consumerDestinationName, producerDestinationName,
				ActiveMqOptions.connectionFactoryName, properties);
	}

	public EngineSituationActiveMq(String consumerDestinationName,
			String producerDestinationName, String connectionFactoryName) {
		this(consumerDestinationName, producerDestinationName,
				connectionFactoryName, null);
	}

	public EngineSituationActiveMq(String consumerDestinationName,
			String producerDestinationName, String connectionFactoryName, Properties properties) {
		if (consumerDestinationName == null)
			throw new NullPointerException("[consumerDestinationName = null]");
		if (producerDestinationName == null)
			throw new NullPointerException("[producerDestinationName = null]");
		if (connectionFactoryName == null)
			throw new NullPointerException("[connectionFactoryName = null]");

		this.consumerDestinationName = consumerDestinationName;
		this.producerDestinationName = producerDestinationName;
		this.connection = new ActiveMqConnection(connectionFactoryName,
				properties);
		this.session = connection.getSession();
		this.open();
	}

	@Override
	public void emit(Situation situation) {
		try {
			producer.send(session.createObjectMessage(situation));
		} catch (JMSException e) {
			throw new RuntimeException(e);
		}
	}

	@Override
	public void open() {
		try {
			consumer = connection.getConsumer(consumerDestinationName);
			consumer.setMessageListener(this);
			producer = connection.getProducer(producerDestinationName);
		} catch (JMSException e) {
			throw new RuntimeException(e);
		}
	}

	@Override
	public void close() {
		connection.close();
	}

	@Override
	public void onMessage(Message message) {
		if (!(message instanceof ObjectMessage))
			throw new RuntimeException(this.getClass().getName()
					+ " expects message to be a ObjectMessage but is "
					+ message.getClass().getName());

		ObjectMessage m = (ObjectMessage) message;

		try {
			Serializable r = m.getObject();

			if (!(r instanceof DatasetObservation))
				throw new RuntimeException(
						this.getClass().getName()
								+ " expects the message object to be a DatasetObservation but is "
								+ r.getClass().getName());

			execute((DatasetObservation) r);
		} catch (JMSException e) {
			throw new RuntimeException(e);
		}
	}

}
