/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.component.reader.activemq;

import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.Session;

import fi.uef.envi.wavellite.component.activemq.ActiveMqConnection;
import fi.uef.envi.wavellite.component.activemq.ActiveMqOptions;
import fi.uef.envi.wavellite.component.reader.base.AbstractReaderMeasurement;
import fi.uef.envi.wavellite.entity.measurement.MeasurementResult;

/**
 * <p>
 * Title: ReaderMeasurementActiveMq
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Component
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class ReaderMeasurementActiveMq extends AbstractReaderMeasurement {

	private String producerDestinationName;
	private ActiveMqConnection connection;
	private MessageProducer producer;
	private Session session;

	public ReaderMeasurementActiveMq(String producerDestinationName) {
		this(producerDestinationName, ActiveMqOptions.connectionFactoryName);
	}

	public ReaderMeasurementActiveMq(String producerDestinationName,
			String connectionFactoryName) {
		if (producerDestinationName == null)
			throw new NullPointerException("[producerDestinationName = null]");
		if (connectionFactoryName == null)
			throw new NullPointerException("[connectionFactoryName = null]");

		this.producerDestinationName = producerDestinationName;
		this.connection = new ActiveMqConnection(connectionFactoryName);
		this.session = connection.getSession();
		this.open();
	}

	@Override
	public void emit(MeasurementResult result) {
		if (producer == null)
			open();

		try {
			producer.send(session.createObjectMessage(result));
		} catch (JMSException e) {
			throw new RuntimeException(e);
		}
	}

	@Override
	public void open() {
		producer = connection.getProducer(producerDestinationName);
	}

	@Override
	public void close() {
		connection.close();
		producer = null;
	}

}
