/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.example.component;

import java.util.Random;

import fi.uef.envi.wavellite.component.engine.EngineSituation;
import fi.uef.envi.wavellite.component.engine.activemq.EngineSituationActiveMq;
import fi.uef.envi.wavellite.component.reader.ReaderMeasurement;
import fi.uef.envi.wavellite.component.reader.activemq.ReaderMeasurementActiveMq;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.measurement.base.MeasurementValueDouble;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.vocabulary.SDMX;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.sensor;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.property;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.feature;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.now;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyMeasure;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyDimension;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.situation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.elementaryInfon;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relevantObject;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.attribute;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.attributeValue;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relevantIndividual;

/**
 * <p>
 * Title: ExampleComponentActiveMq
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Example
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class ExampleComponentActiveMq {

	// Wavellite shell
	// start-observation-engine OE1 tcp://localhost:61616 MeasurementResultStream SensorObservationStream
	// start-observation-writer OW1 tcp://localhost:61616 SensorObservationStream enviapps.uef.fi test
	// start-dataset-engine DE1 tcp://localhost:61616 SensorObservationStream DatasetObservationStream "http://example.org#cp1" "http://example.org#d1"
	// start-derivation-writer DW1 tcp://localhost:61616 DatasetObservationStream enviapps.uef.fi test
	// start-situation-writer SW1 tcp://localhost:61616 SituationStream enviapps.uef.fi test

	public static void main(String[] args) throws InterruptedException {
		Random random = new Random();

		Sensor sensor = sensor("s1");
		Property property = property("p1");
		Feature feature = feature("f1");

		ReaderMeasurement reader = new ReaderMeasurementActiveMq(
				"MeasurementResultStream");
		EngineSituation engine = new EngineSituationActiveMq(
				"DatasetObservationStream", "SituationStream") {

			@Override
			public void execute(DatasetObservation observation) {
				Double value = observation.getComponentPropertyValue(
						componentPropertyMeasure("http://example.org#cp1"))
						.getValueAsDouble();

				if (value > -1.96 && value < 1.96)
					return;

				TemporalLocation temporalLocation = observation
						.getComponentPropertyValue(
								componentPropertyDimension(SDMX.Dimension.timePeriod))
						.getValueAsTemporalLocation();

				// Outlier situation
				Situation situation = situation();
				ElementaryInfon infon = elementaryInfon(
						relation("http://example.org#r1"), Polarity.True,
						relevantIndividual(attribute(attributeValue(value))),
						relevantObject(temporalLocation));
				situation.addSupportedInfon(infon);

				emit(situation);
			}
		};

		for (int i = 0; i < 50; i++) {
			reader.emit(new MeasurementValueDouble(random.nextGaussian()),
					sensor, property, feature, now());
		}

		Thread.sleep(30000);

		reader.close();
		engine.close();

	}
}
