/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.example.representation;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.sensorObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.sensor;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.property;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.feature;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.sensorOutput;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.temporalLocation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.spatialLocation;

import java.util.HashSet;
import java.util.Set;

import org.joda.time.DateTime;
import org.openrdf.model.Statement;
import org.openrdf.rio.RDFFormat;
import org.openrdf.rio.RDFHandlerException;
import org.openrdf.rio.RDFWriter;
import org.openrdf.rio.Rio;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.FeatureBase;
import fi.uef.envi.wavellite.entity.core.base.PropertyBase;
import fi.uef.envi.wavellite.entity.core.base.SensorBase;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.Stimulus;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.observation.base.StimulusBase;
import fi.uef.envi.wavellite.entity.observation.base.SensorObservationBase;
import fi.uef.envi.wavellite.entity.observation.base.SensorOutputBase;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfProv;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfSsn;

/**
 * <p>
 * Title: ExampleRepresentSensorObservation
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Example
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class ExampleRepresentSensorObservation {

	private static final String ns = "http://example.org#";
	private static final GeometryFactory gf = new GeometryFactory();

	public static void main(String[] args) throws RDFHandlerException {
		EntityRepresentationRdfSsn r1 = new EntityRepresentationRdfSsn(ns);
		EntityRepresentationRdfProv r2 = new EntityRepresentationRdfProv(ns);

		Set<Statement> statements = new HashSet<Statement>();

		SensorObservation observation = example3();

		// Create SSN statements
//		 statements.addAll(r1.createRepresentation(observation));
		// Create PROV statements
		statements.addAll(r2.createRepresentation(observation));

		RDFWriter w = Rio.createWriter(RDFFormat.RDFXML, System.out);
		w.handleNamespace("ssn", "http://purl.oclc.org/NET/ssnx/ssn#");
		w.handleNamespace("DUL", "http://www.loa-cnr.it/ontologies/DUL.owl#");
		w.handleNamespace("geo", "http://www.opengis.net/ont/geosparql#");
		w.handleNamespace("ex", ns);
		w.handleNamespace("owl-time", "http://www.w3.org/2006/time#");
		w.handleNamespace("xsd", "http://www.w3.org/2001/XMLSchema#");
		w.handleNamespace("prov", "http://www.w3.org/ns/prov#");
		w.handleNamespace("woe",
				"http://envi.uef.fi/wavellite/ontology/entity#");

		w.startRDF();

		for (Statement statement : statements) {
			w.handleStatement(statement);
		}

		w.endRDF();
	}

	private static SensorObservation example1() {
		return sensorObservation(
				sensor("s1"),
				property("p1"),
				feature("f1"),
				sensorOutput(0.0),
				temporalLocation(2014, 1, 4, 15, 38, 25),
				spatialLocation(gf.createPolygon(new Coordinate[] {
						new Coordinate(0, 0), new Coordinate(1, 1),
						new Coordinate(-1, -1), new Coordinate(0, 0) })));
	}

	private static SensorObservation example2() {
		SensorObservation observation = new SensorObservationBase(
				"a-observation");

		Sensor sensor = new SensorBase("a-thermometer");
		Stimulus stimulus = new StimulusBase("a-stimulus");
		observation.setSensor(sensor);
		observation.setStimulus(stimulus);

		Property property = new PropertyBase("temperature");
		observation.setProperty(property);

		Feature feature = new FeatureBase("ambient-air");
		observation.setFeature(feature);

		SensorOutput output = new SensorOutputBase("a-output");
		observation.setSensorOutput(output);
		ObservationValue value = new ObservationValueDouble("a-value", 14.6);
		output.setObservationValue(value);

		TemporalLocation time = new TemporalLocationDateTime("a-datetime",
				new DateTime(2014, 10, 24, 19, 36));
		observation.setTemporalLocation(time);

		SpatialLocation space = new SpatialLocationRegion("a-region",
				new SpatialGeometryPolygon("a-geometry", gf
						.createPolygon(new Coordinate[] { new Coordinate(0, 0),
								new Coordinate(1, 1), new Coordinate(-1, -1),
								new Coordinate(0, 0) })));
		observation.setSpatialLocation(space);

		return observation;
	}
	
	private static SensorObservation example3() {
		SensorObservation observation = new SensorObservationBase();

		Sensor sensor = new SensorBase("sd1");
		Stimulus stimulus = new StimulusBase("vibration");
		observation.setSensor(sensor);
		observation.setStimulus(stimulus);

		Property property = new PropertyBase("acceleration");
		observation.setProperty(property);

		Feature feature = new FeatureBase("pavement");
		observation.setFeature(feature);

		SensorOutput output = new SensorOutputBase();
		observation.setSensorOutput(output);
		ObservationValue value = new ObservationValueDouble(-0.044921875);
		output.setObservationValue(value);

		TemporalLocation time = new TemporalLocationDateTime(
				new DateTime(2014, 10, 24, 19, 36, 57, 546));
		observation.setTemporalLocation(time);

		return observation;
	}
}
