/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.example.representation;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentProperty;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.temporalLocation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.spatialLocation;

import java.util.HashSet;
import java.util.Set;

import org.joda.time.DateTime;
import org.openrdf.model.Statement;
import org.openrdf.rio.RDFFormat;
import org.openrdf.rio.RDFHandlerException;
import org.openrdf.rio.RDFWriter;
import org.openrdf.rio.Rio;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Operation;
import fi.uef.envi.wavellite.entity.core.Operator;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.FeatureBase;
import fi.uef.envi.wavellite.entity.core.base.OperationBase;
import fi.uef.envi.wavellite.entity.core.base.OperatorBase;
import fi.uef.envi.wavellite.entity.core.base.PropertyBase;
import fi.uef.envi.wavellite.entity.core.base.SensorBase;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueSpatialLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.Stimulus;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.observation.base.SensorObservationBase;
import fi.uef.envi.wavellite.entity.observation.base.SensorOutputBase;
import fi.uef.envi.wavellite.entity.observation.base.StimulusBase;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfProv;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfQb;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfSsn;
import fi.uef.envi.wavellite.vocabulary.SDMX;

/**
 * <p>
 * Title: ExampleRepresentationDatasetObservation
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Example
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class ExampleRepresentationDatasetObservation {

	private static final String ns = "http://example.org#";
	private static GeometryFactory gf = new GeometryFactory();

	public static void main(String[] args) throws RDFHandlerException {
		EntityRepresentationRdfQb r1 = new EntityRepresentationRdfQb(ns);
		EntityRepresentationRdfProv r2 = new EntityRepresentationRdfProv(ns);
		EntityRepresentationRdfSsn r3 = new EntityRepresentationRdfSsn(ns);

		Set<Statement> statements = new HashSet<Statement>();

		DatasetObservation observation = example3();
		
		statements.addAll(r1.createRepresentation(observation));
		statements.addAll(r2.createRepresentation(observation));
		// statements.addAll(r3.createRepresentation(sensorObservation()));

		RDFWriter w = Rio.createWriter(RDFFormat.RDFXML, System.out);
		w.handleNamespace("cube", "http://purl.org/linked-data/cube#");
		w.handleNamespace("geo", "http://www.opengis.net/ont/geosparql#");
		w.handleNamespace("ex", ns);
		w.handleNamespace("owl-time", "http://www.w3.org/2006/time#");
		w.handleNamespace("wto", "http://envi.uef.fi/wavellite/wto#");
		w.handleNamespace("xsd", "http://www.w3.org/2001/XMLSchema#");
		w.handleNamespace("woo",
				"http://envi.uef.fi/wavellite/ontology/operator#");
		w.handleNamespace("prov", "http://www.w3.org/ns/prov#");
		w.handleNamespace("woe",
				"http://envi.uef.fi/wavellite/ontology/entity#");
		w.handleNamespace("ssn", "http://purl.oclc.org/NET/ssnx/ssn#");
		w.handleNamespace("sdmx-dimension", "http://purl.org/linked-data/sdmx/2009/dimension#");

		w.startRDF();

		for (Statement statement : statements) {
			w.handleStatement(statement);
		}

		w.endRDF();
	}

	private static DatasetObservation example1() {
		return datasetObservation(
				dataset("d1"),
				component(componentProperty("p1"),
						temporalLocation(2014, 1, 4, 15, 38, 25)),
				component(
						componentProperty("p2"),
						spatialLocation(gf.createPolygon(new Coordinate[] {
								new Coordinate(0, 0), new Coordinate(1, 0),
								new Coordinate(1, 1), new Coordinate(0, 1),
								new Coordinate(0, 0) }))),
				component(componentProperty("p3"), 1.0));
	}

	private static DatasetObservation example2() {
		DatasetObservation ret = new DatasetObservationBase("a-do");

		Dataset d = new DatasetBase("a-dataset");

		Component c1 = new ComponentBase();
		ComponentProperty p1 = new ComponentPropertyBase("p1");
		c1.setComponentProperty(p1);
		c1.setComponentPropertyValue(new ComponentPropertyValueTemporalLocation(
				"v1", new TemporalLocationDateTime("a-time", new DateTime(2014,
						10, 24, 19, 36))));
		ret.setComponent(c1);

		Component c2 = new ComponentBase();
		ComponentProperty p2 = new ComponentPropertyBase("p2");
		c2.setComponentProperty(p2);
		c2.setComponentPropertyValue(new ComponentPropertyValueSpatialLocation(
				"v2", new SpatialLocationRegion("a-region",
						new SpatialGeometryPolygon("a-geometry", gf
								.createPolygon(new Coordinate[] {
										new Coordinate(0, 0),
										new Coordinate(1, 0),
										new Coordinate(1, 1),
										new Coordinate(0, 1),
										new Coordinate(0, 0) })))));
		ret.setComponent(c2);

		Component c3 = new ComponentBase();
		ComponentProperty p3 = new ComponentPropertyBase("temperature");
		c3.setComponentProperty(p3);
		c3.setComponentPropertyValue(new ComponentPropertyValueDouble(
				"a-value", 14.6));
		ret.setComponent(c3);

		Operator operator = new OperatorBase("a-translator");
		Operation operation = new OperationBase("translation");
		operation.setAssociatedWith(operator);

		ret.addDerivedFrom(sensorObservation());
		ret.setAttributedTo(operator);
		ret.setGeneratedBy(operation);

		ret.setDataset(d);

		return ret;
	}

	private static DatasetObservation example3() {
		DatasetObservation ret = new DatasetObservationBase();

		Dataset d = new DatasetBase("d1");

		Component c1 = new ComponentBase();
		ComponentProperty p1 = new ComponentPropertyBase(
				SDMX.Dimension.timePeriod);
		c1.setComponentProperty(p1);
		c1.setComponentPropertyValue(new ComponentPropertyValueTemporalLocation(
				new TemporalLocationDateTime(new DateTime(2014, 10, 24, 19, 36,
						57, 546))));
		ret.setComponent(c1);

		Component c3 = new ComponentBase();
		ComponentProperty p3 = new ComponentPropertyBase("acceleration");
		c3.setComponentProperty(p3);
		c3.setComponentPropertyValue(new ComponentPropertyValueDouble(
				-0.044921875));
		ret.setComponent(c3);

		Operator operator = new OperatorBase("dse");
		Operation operation = new OperationBase("so2do");
		operation.setAssociatedWith(operator);

		ret.addDerivedFrom(new SensorObservationBase("44b"));
		ret.setAttributedTo(operator);
		ret.setGeneratedBy(operation);

		ret.setDataset(d);

		return ret;
	}

	private static SensorObservation sensorObservation() {
		SensorObservation observation = new SensorObservationBase("a-so");

		Sensor sensor = new SensorBase("a-thermometer");
		Stimulus stimulus = new StimulusBase("a-stimulus");
		observation.setSensor(sensor);
		observation.setStimulus(stimulus);

		Property property = new PropertyBase("temperature");
		observation.setProperty(property);

		Feature feature = new FeatureBase("ambient-air");
		observation.setFeature(feature);

		SensorOutput output = new SensorOutputBase("a-output");
		observation.setSensorOutput(output);
		ObservationValue value = new ObservationValueDouble("a-value", 14.6);
		output.setObservationValue(value);

		TemporalLocation time = new TemporalLocationDateTime("a-datetime",
				new DateTime(2014, 10, 24, 19, 36));
		observation.setTemporalLocation(time);

		SpatialLocation space = new SpatialLocationRegion("a-region",
				new SpatialGeometryPolygon("a-geometry",
						gf.createPolygon(new Coordinate[] {
								new Coordinate(0, 0), new Coordinate(1, 0),
								new Coordinate(1, 1), new Coordinate(0, 1),
								new Coordinate(0, 0) })));
		observation.setSpatialLocation(space);

		return observation;
	}
}
