/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.example.representation;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.elementaryInfon;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relevantIndividual;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relevantObject;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.situation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.temporalLocation;

import java.util.HashSet;
import java.util.Set;

import org.joda.time.DateTime;
import org.openrdf.model.Statement;
import org.openrdf.rio.RDFFormat;
import org.openrdf.rio.RDFHandlerException;
import org.openrdf.rio.RDFWriter;
import org.openrdf.rio.Rio;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;

import fi.uef.envi.wavellite.entity.core.Operation;
import fi.uef.envi.wavellite.entity.core.Operator;
import fi.uef.envi.wavellite.entity.core.base.OperationBase;
import fi.uef.envi.wavellite.entity.core.base.OperatorBase;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ElementaryInfonBase;
import fi.uef.envi.wavellite.entity.situation.base.RelationBase;
import fi.uef.envi.wavellite.entity.situation.base.RelevantIndividualBase;
import fi.uef.envi.wavellite.entity.situation.base.SituationBase;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfProv;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfSto;

/**
 * <p>
 * Title: ExampleRepresentationSituation
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Example
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class ExampleRepresentationSituation {

	private static final String ns = "http://example.org#";
	private static final GeometryFactory gf = new GeometryFactory();

	public static void main(String[] args) throws RDFHandlerException {

		EntityRepresentationRdfSto r1 = new EntityRepresentationRdfSto(ns);
		EntityRepresentationRdfProv r2 = new EntityRepresentationRdfProv(ns);

		Situation situation = situation3();
		
		Set<Statement> statements = new HashSet<Statement>();
		
		statements.addAll(r1.createRepresentation(situation));
		statements.addAll(r2.createRepresentation(situation));

		RDFWriter w = Rio.createWriter(RDFFormat.RDFXML, System.out);
		w.handleNamespace("geo", "http://www.opengis.net/ont/geosparql#");
		w.handleNamespace("ex", ns);
		w.handleNamespace("owl-time", "http://www.w3.org/2006/time#");
		w.handleNamespace("wto", "http://envi.uef.fi/wavellite/wto#");
		w.handleNamespace("xsd", "http://www.w3.org/2001/XMLSchema#");
		w.handleNamespace("STO", "http://vistology.com/ont/2008/STO/STO.owl#");
		w.handleNamespace("prov", "http://www.w3.org/ns/prov#");

		w.startRDF();

		for (Statement statement : statements) {
			w.handleStatement(statement);
		}

		w.endRDF();
	}

	public static Situation situation1() {
		return situation(elementaryInfon(
				relation("r1"),
				Polarity.True,
				relevantIndividual(0.0),
				relevantObject(temporalLocation(new DateTime(2014, 1, 4, 15,
						19, 25), new DateTime(2014, 1, 4, 15, 19, 30))),
				relevantObject(gf.createPoint(new Coordinate(0.0, 0.0)))));
	}

	public static Situation situation2() {
		Situation situation = new SituationBase("a-situation");

		ElementaryInfon infon = new ElementaryInfonBase("a-infon");
		situation.addSupportedInfon(infon);

		infon.setRelation(new RelationBase("storm-at"));

		RelevantIndividual storm = new RelevantIndividualBase("a-storm");
		Attribute area = new AttributeValue("a-attribute");
		area.setName("hasArea");
		area.setValue(new ValueDouble(1.0));
		storm.addAttribute(area);

		infon.addRelevantObject(storm);
		infon.addRelevantObject(new AttributeSpatialLocation("a-place",
				new SpatialLocationRegion("a-region",
						new SpatialGeometryPolygon("a-polygon", gf
								.createPolygon(new Coordinate[] {
										new Coordinate(0, 0),
										new Coordinate(1, 1),
										new Coordinate(-1, -1),
										new Coordinate(0, 0) })))));
		infon.addRelevantObject(new AttributeTemporalLocation("a-time",
				new TemporalLocationDateTime("a-datetime", new DateTime(2014,
						10, 24, 19, 36))));

		return situation;
	}
	
	public static Situation situation3() {
		Situation situation = new SituationBase();

		ElementaryInfon infon = new ElementaryInfonBase();
		situation.addSupportedInfon(infon);

		infon.setRelation(new RelationBase("vehicle-at"));

		RelevantIndividual vehicle = new RelevantIndividualBase();
		vehicle.setType("LightVehicle");
		vehicle.addDerivedFrom(new DatasetObservationBase("aa3"));

		Operator operator = new OperatorBase("se");
		Operation operation = new OperationBase("classification");
		operation.setAssociatedWith(operator);
		vehicle.setAttributedTo(operator);
		vehicle.setGeneratedBy(operation);
		
		infon.addRelevantObject(vehicle);
		infon.addRelevantObject(new AttributeTemporalLocation(
				new TemporalLocationDateTime(new DateTime(2014,
						10, 24, 20, 05, 36))));

		return situation;
	}
}
