/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.example.store;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyTimePeriod;

import java.util.Random;

import org.joda.time.DateTime;

import fi.uef.envi.wavellite.module.store.ModuleStore;
import fi.uef.envi.wavellite.module.store.stardog.ModuleStoreStardog;

/**
 * <p>
 * Title: ExampleModuleStoreStardogDatasetObservation
 * </p>
 * <p>
 * Description: Example for how to persist a dataset observation to a Stardog
 * database. Note that the example assumes that Stardog runs on localhost, on
 * port 5820, with credentials admin/admin, and that a 'test' database was
 * created.
 * </p>
 * <p>
 * Project: Wavellite Example
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class ExampleModuleStoreStardogDatasetObservation {

	// Our domain namespace
	private static final String ns = "http://example.org";

	public static void main(String[] args) {
		// The namespace here is optional (sort of)
		ModuleStore store = new ModuleStoreStardog("localhost", "test", ns);

		// Store a dataset observation with the given component properties
		store.consider(datasetObservation(dataset("d1"),
				component(componentPropertyTimePeriod(), DateTime.now()),
				component("p1", new Random().nextDouble())));

		store.close();
	}

}
