/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.example.store;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.feature;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.measurementResult;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.measurementValue;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.measurementValueContext;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.property;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.sensor;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.temporalLocation;

import fi.uef.envi.wavellite.module.store.ModuleStore;
import fi.uef.envi.wavellite.module.store.stardog.ModuleStoreStardog;

/**
 * <p>
 * Title: ExampleModuleStoreStardogMeasurementResult
 * </p>
 * <p>
 * Description: Example for how to persist a measurement result to a Stardog
 * database. Note that the example assumes that Stardog runs on localhost, on
 * port 5820, with credentials admin/admin, and that a 'test' database was
 * created.
 * </p>
 * <p>
 * Project: Wavellite Example
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class ExampleModuleStoreStardogMeasurementResult {

	// Our domain namespace
	private static final String ns = "http://example.org";

	public static void main(String[] args) {
		ModuleStore store = new ModuleStoreStardog("localhost", "test", ns);

		// Store a measurement result with random double value obtained just now
		// by a sensor that monitors a property of a feature
		store.consider(measurementResult(
				measurementValue(),
				measurementValueContext(sensor("aSensor"),
						property("aProperty"), feature("aFeature"),
						temporalLocation())));

		store.close();
	}

}
