/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.example.store;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.situation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.elementaryInfon;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relevantIndividual;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.relevantObject;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.temporalLocation;

import org.joda.time.DateTime;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;

import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.module.store.ModuleStore;
import fi.uef.envi.wavellite.module.store.stardog.ModuleStoreStardog;

/**
 * <p>
 * Title: ExampleModuleStoreStardogSituation
 * </p>
 * <p>
 * Description: Example for how to persist a situation to a Stardog database.
 * Note that the example assumes that Stardog runs on localhost, on port 5820,
 * with credentials admin/admin, and that a 'test' database was created.
 * </p>
 * <p>
 * Project: Wavellite Example
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class ExampleModuleStoreStardogSituation {

	// Our domain namespace
	private static final String ns = "http://example.org";

	public static void main(String[] args) {
		GeometryFactory gf = new GeometryFactory();

		ModuleStore store = new ModuleStoreStardog("localhost", "test", ns);

		// Store a situation with an r1-Relation infon with three objects,
		// including an interval temporal location and a polygon spatial
		// location
		store.consider(situation(elementaryInfon(
				relation("r1"),
				Polarity.True,
				relevantIndividual(0.0),
				relevantObject(temporalLocation(new DateTime(2014, 1, 4,
						15, 19, 25), new DateTime(2014, 1, 4, 15, 19, 30))),
						relevantObject(gf.createPolygon(new Coordinate[] {
						new Coordinate(0, 0), new Coordinate(1, 1),
						new Coordinate(-1, -1), new Coordinate(0, 0) })))));

		store.close();
	}

}
