/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix;

import java.util.Iterator;
import java.util.List;

import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;

/**
 * <p>
 * Title: MatrixIterator
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class MatrixIterator implements
		Iterator<DatasetObservation> {

	private Dataset dataset;
	private List<ComponentProperty> componentProperties;
	private Iterator<List<ComponentPropertyValue>> iterator;

	public MatrixIterator(
			List<List<ComponentPropertyValue>> matrix, Dataset dataset,
			List<ComponentProperty> componentProperties) {
		if (matrix == null)
			throw new NullPointerException("[matrix = null]");
		if (dataset == null)
			throw new NullPointerException("[dataset = null]");
		if (componentProperties == null)
			throw new NullPointerException("[componentProperties = null]");

		this.dataset = dataset;
		this.componentProperties = componentProperties;
		this.iterator = matrix.iterator();
	}

	@Override
	public boolean hasNext() {
		return iterator.hasNext();
	}

	@Override
	public DatasetObservation next() {
		List<ComponentPropertyValue> values = iterator.next();

		DatasetObservation ret = new DatasetObservationBase();
		ret.setDataset(dataset);

		for (int i = 0; i < values.size(); i++) {
			ComponentProperty property = componentProperties.get(i);
			ComponentPropertyValue value = values.get(i);
			ret.addComponent(property, value);
		}

		return ret;
	}

	@Override
	public void remove() {
		throw new UnsupportedOperationException(
				"Operation not supported by this iterator");
	}

}
