/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.joda.time.DateTime;

import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.math.AggregationFunction;
import fi.uef.envi.wavellite.math.AggregationPeriod;
import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.OperationDescriptiveStatistic;

/**
 * <p>
 * Title: OperationAggregate
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationAggregate {

	private static final Logger log = Logger.getLogger(OperationAggregate.class
			.getName());

	public Matrix evaluate(Matrix matrix, ComponentProperty componentProperty,
			AggregationFunction aggregationFunction,
			AggregationPeriod aggregationPeriod, Dataset targetDataset) {
		OperationSplit split = new OperationSplit();

		Matrix[] matrices = split.evaluate(matrix, componentProperty,
				aggregationPeriod, targetDataset);

		Matrix ret = new Matrix();

		for (Matrix matrice : matrices) {
			OperationDescriptiveStatistic operation = new OperationMean();

			if (aggregationFunction.equals(AggregationFunction.MEAN)) {
				operation = new OperationMean();
			} else if (aggregationFunction.equals(AggregationFunction.MIN)) {
				operation = new OperationMin();
			} else if (aggregationFunction.equals(AggregationFunction.MAX)) {
				operation = new OperationMax();
			} else if (aggregationFunction.equals(AggregationFunction.SUM)) {
				operation = new OperationSum();
			} else {
				if (log.isLoggable(Level.WARNING))
					log.warning("Unsupported aggregation function; using mean as default [aggregationFunction = "
							+ aggregationFunction + "]");

			}

			DatasetObservation observation = operation.evaluate(matrice,
					componentProperty, targetDataset);

			// Update the temporal component property to match the aggregation
			// period
			ComponentPropertyValue componentPropertyValue = observation
					.getComponentPropertyValue(componentProperty);

			if (!ComponentPropertyValueTemporalLocation.class
					.isInstance(componentPropertyValue))
				throw new RuntimeException(
						"Expected temporal location property value [componentPropertyValue = "
								+ componentPropertyValue.getClass().getName()
								+ "]");

			TemporalLocation temporalLocation = ((ComponentPropertyValueTemporalLocation) componentPropertyValue)
					.getValue();

			if (!TemporalLocationDateTime.class.isInstance(temporalLocation))
				throw new RuntimeException(
						"Expected date time temporal location [temporalLocation = "
								+ temporalLocation.getClass().getName() + "]");
			
			DateTime dateTime = temporalLocation.getValueAsDateTime();

			if (aggregationPeriod.equals(AggregationPeriod.MINUTE))
				dateTime = dateTime.minuteOfHour().roundFloorCopy();
			else if (aggregationPeriod.equals(AggregationPeriod.HOUR))
				dateTime = dateTime.hourOfDay().roundFloorCopy();
			else if (aggregationPeriod.equals(AggregationPeriod.DAY))
				dateTime = dateTime.dayOfMonth().roundFloorCopy();
			else {
				if (log.isLoggable(Level.WARNING))
					log.warning("Usupported aggregation period; using MINUTE as default [aggregationPeriod = "
							+ aggregationPeriod + "]");
				dateTime = dateTime.minuteOfHour().roundFloorCopy();
			}

			temporalLocation.setValue(dateTime);
			
			ret.addDatasetObservation(observation);
		}

		return ret;
	}

}
