/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base;

import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.math.matrix.Matrix;

/**
 * <p>
 * Title: OperationOutlier
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationOutlier {

	private boolean hasRemovedOutliers = false;

	public Matrix remove(Matrix matrix,
			ComponentProperty temporalLocationDimension,
			Dataset targetDataset, double factor) {
		hasRemovedOutliers = false;

		Matrix ret = new Matrix();

		// First sort the matrix in ascending order of temporal location
		OperationSort sortOp = new OperationSort();
		Matrix sorted = sortOp.temporalLocation(
				matrix, temporalLocationDimension, targetDataset);

		OperationMean meanOp = new OperationMean();
		OperationStandardDeviation standardDeviationOp = new OperationStandardDeviation();

		DatasetObservation mean = meanOp.evaluate(sorted,
				temporalLocationDimension, targetDataset);
		DatasetObservation standardDeviation = standardDeviationOp
				.evaluate(sorted, temporalLocationDimension,
						targetDataset);

		for (int i = 0; i < sorted.size(); i++) {
			DatasetObservation observation = sorted.getDatasetObservation(i);

			if (isOutlier(observation, mean, standardDeviation, factor,
					temporalLocationDimension)) {
				hasRemovedOutliers = true;

				continue;

				// Set the observation to the mean
				// Don't do that, because the data will eventually regress to
				// the mean
				// for (ComponentProperty componentProperty : mean
				// .getComponentProperties()) {
				// // Do not override the observation's temporal location
				// if (componentProperty.equals(temporalLocationDimension))
				// continue;
				//
				// observation.setComponentPropertyValue(componentProperty,
				// mean.getComponentPropertyValue(componentProperty));
				// }
			}

			ret.addDatasetObservation(observation);
		}

		return ret;
	}

	public boolean hasRemovedOutliers() {
		return hasRemovedOutliers;
	}

	private boolean isOutlier(DatasetObservation observation,
			DatasetObservation mean, DatasetObservation standardDeviation,
			double f, ComponentProperty temporalLocationDimension) {
		for (Component component : observation.getComponents()) {
			ComponentProperty componentProperty = component
					.getComponentProperty();

			if (componentProperty.equals(temporalLocationDimension))
				continue;

			Double v = (Double) component.getComponentPropertyValue()
					.getValue();
			Double m = (Double) mean.getComponentPropertyValue(
					componentProperty).getValue();
			Double s = (Double) standardDeviation.getComponentPropertyValue(
					componentProperty).getValue();

			if (v > m + f * s || v < m - f * s)
				return true;
		}

		return false;
	}
}
