/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base;

import java.util.Arrays;
import java.util.Comparator;

import org.apache.commons.collections4.IteratorUtils;
import org.joda.time.DateTime;

import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.math.SortDirection;
import fi.uef.envi.wavellite.math.matrix.Matrix;

/**
 * <p>
 * Title: OperationSort
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationSort {

	private ComponentProperty componentProperty;
	private SortDirection sortDirection;
	private Comparator<DatasetObservation> dateTimeComparator = new DateTimeComparator();

	public Matrix temporalLocation(Matrix matrix,
			ComponentProperty componentProperty, Dataset targetDataset) {
		return temporalLocation(matrix, componentProperty, SortDirection.ASC,
				targetDataset);
	}

	public Matrix temporalLocation(Matrix matrix,
			ComponentProperty componentProperty, SortDirection sortDirection,
			Dataset targetDataset) {
		if (componentProperty == null)
			throw new NullPointerException("[temporalLocationProperty = null]");

		this.componentProperty = componentProperty;

		if (sortDirection == null)
			sortDirection = SortDirection.ASC;

		this.sortDirection = sortDirection;

		DatasetObservation[] a = IteratorUtils.toArray(matrix.iterator(),
				DatasetObservation.class);

		Arrays.sort(a, dateTimeComparator);

		Matrix ret = new Matrix();

		ret.setIsSorted(true);
		ret.setSortComponentProperty(componentProperty);
		ret.setSortDirection(sortDirection);

		for (DatasetObservation o : a) {
			o.setDataset(targetDataset);
			ret.addDatasetObservation(o);
		}

		return ret;
	}

	private class DateTimeComparator implements Comparator<DatasetObservation> {

		@Override
		public int compare(DatasetObservation o1, DatasetObservation o2) {
			DateTime dt1 = o1.getComponentPropertyValue(componentProperty)
					.getValueAsTemporalLocation().getValueAsDateTime();
			DateTime dt2 = o2.getComponentPropertyValue(componentProperty)
					.getValueAsTemporalLocation().getValueAsDateTime();

			// Compares its two arguments for order. Returns a negative integer,
			// zero, or a positive integer as the first argument is less than,
			// equal to, or greater than the second.
			if (dt1 != null && dt2 != null) {
				if (dt1.isEqual(dt2))
					return 0;

				if (dt1.isBefore(dt2)
						&& sortDirection.equals(SortDirection.ASC))
					return -1;

				if (dt1.isAfter(dt2)
						&& sortDirection.equals(SortDirection.DESC))
					return -1;

				return 1;
			}

			throw new RuntimeException("[dt1 = " + dt1 + "; dt2 = " + dt2 + "]");
		}

	}

}
