/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base;

import org.apache.commons.collections4.IteratorUtils;
import org.apache.commons.math3.linear.MatrixUtils;
import org.apache.commons.math3.linear.RealMatrix;

import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.math.matrix.Matrix;

/**
 * <p>
 * Title: OperationSubtract
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationSubtract {

	public Matrix evaluate(Matrix matrix, double value, Dataset targetDataset) {
		Matrix ret = new Matrix();

		RealMatrix m = matrix.asRealMatrix();

		int rowDimension = m.getRowDimension();
		int columnDimension = m.getColumnDimension();

		double[][] data = new double[rowDimension][columnDimension];

		for (int i = 0; i < rowDimension; i++) {
			for (int j = 0; j < columnDimension; j++)
				data[i][j] = value;
		}

		RealMatrix s = MatrixUtils.createRealMatrix(data);

		m = m.subtract(s);

		DatasetObservation[] observations = IteratorUtils.toArray(
				matrix.iterator(), DatasetObservation.class);

		if (observations.length != m.getRowDimension())
			throw new RuntimeException("[" + observations.length + " != "
					+ m.getRowDimension() + "]");

		for (int i = 0; i < observations.length; i++) {
			DatasetObservation observation = observations[i];
			observation.setDataset(targetDataset);

			double[] r = m.getRow(i);

			for (int j = 0; j < r.length; j++) {
				ComponentProperty property = matrix
						.getNumericalComponentProperty(j);
				observation.setComponentPropertyValue(property,
						new ComponentPropertyValueDouble(r[j]));
			}

			ret.addDatasetObservation(observation);
		}

		return ret;
	}

}
