/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.utils;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.List;
import java.util.UUID;
import java.util.logging.Level;
import java.util.logging.Logger;

import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.representation.core.EntityRepresentation;
import fi.uef.envi.wavellite.representation.csv.EntityRepresentationCsvQb;

/**
 * <p>
 * Title: CsvRead
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class CsvRead {

	private static final Logger log = Logger.getLogger(CsvRead.class.getName());

	public Matrix createMatrix(File file) {
		return createMatrix(file, null, new DatasetBase(UUID.randomUUID().toString()));
	}

	public Matrix createMatrix(File file, List<ComponentProperty> componentProperties) {
		return createMatrix(file,
				componentProperties.toArray(new ComponentProperty[] {}),
				new DatasetBase(UUID.randomUUID().toString()));
	}

	public Matrix createMatrix(File file, ComponentProperty... componentProperties) {
		return createMatrix(file, componentProperties, new DatasetBase(UUID
				.randomUUID().toString()));
	}

	public Matrix createMatrix(File file, ComponentProperty[] componentProperties,
			Dataset targetDataset) {
		return createMatrix(file, componentProperties, targetDataset, false, ",");
	}

	public Matrix createMatrix(File file, ComponentProperty[] componentProperties,
			Dataset targetDataset, boolean skipFirstLine, String columnSeparator) {
		if (file == null) {
			if (log.isLoggable(Level.SEVERE))
				log.severe("[file = null]");

			return null;
		}

		if (componentProperties == null) {
			if (log.isLoggable(Level.WARNING))
				log.warning("Component properties not provided; assuming first line contains component property ids separated by '"
						+ columnSeparator + "'");
		}

		Matrix m = new Matrix();

		try (BufferedReader br = new BufferedReader(new FileReader(file))) {
			int row = -1;

			for (String line; (line = br.readLine()) != null;) {
				row++;

				String[] cols = line.split(columnSeparator);

				if (row == 0) {
					if (componentProperties == null) {
						if (skipFirstLine) {
							throw new RuntimeException(
									"Component properties not provided; assumed in first line but required to be skipped.");
						}

						componentProperties = new ComponentProperty[cols.length];

						for (int i = 0; i < cols.length; i++) {
							String col = cols[i];

							componentProperties[i] = new ComponentPropertyBase(
									col);
						}
						continue;
					}

					if (skipFirstLine) {
						continue;
					}
				}

				if (cols.length != componentProperties.length) {
					if (log.isLoggable(Level.SEVERE))
						log.severe("Mismatch in column and component properties size: skipped row [row = "
								+ row
								+ "; cols = "
								+ cols.length
								+ "; componentProperties = "
								+ componentProperties.length + "]");

					continue;
				}

				EntityRepresentation<String> er = new EntityRepresentationCsvQb(
						targetDataset, componentProperties);

				m.addDatasetObservation(er.createDatasetObservation(line));
			}

			br.close();
		} catch (FileNotFoundException e) {
			if (log.isLoggable(Level.SEVERE))
				log.severe(e.getMessage());
		} catch (IOException e) {
			if (log.isLoggable(Level.SEVERE))
				log.severe(e.getMessage());
		}

		return m;
	}
}
