/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base.test;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentProperty;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyValue;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dimension;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.measure;

import java.io.File;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import fi.uef.envi.wavellite.math.AggregationFunction;
import fi.uef.envi.wavellite.math.AggregationPeriod;
import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.base.OperationAggregate;
import fi.uef.envi.wavellite.math.utils.CsvRead;

/**
 * <p>
 * Title: OperationAggregateTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationAggregateTest {

	private static final DateTimeFormatter dtf = ISODateTimeFormat
			.dateTimeParser().withOffsetParsed();

	@Test
	public void test0() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 30),
				component(measure("p2"), 0.2)));

		OperationAggregate operation = new OperationAggregate();

		Matrix a = operation.evaluate(m, dimension("p1"),
				AggregationFunction.MEAN, AggregationPeriod.MINUTE,
				dataset("d1"));

		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.1)));

		assertEquals(e, a);
	}

	@Test
	public void test1() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 30),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 0),
				component(measure("p2"), 0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 30),
				component(measure("p2"), 0.3)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 2, 0),
				component(measure("p2"), -0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 2, 30),
				component(measure("p2"), -0.3)));

		OperationAggregate operation = new OperationAggregate();

		Matrix a = operation.evaluate(m, dimension("p1"),
				AggregationFunction.MEAN, AggregationPeriod.MINUTE,
				dataset("d1"));

		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.1)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 0),
				component(measure("p2"), 0.2)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 2, 0),
				component(measure("p2"), -0.2)));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 30),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 0),
				component(measure("p2"), 0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 30),
				component(measure("p2"), 0.3)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 2, 0),
				component(measure("p2"), -0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 2, 30),
				component(measure("p2"), -0.3)));

		OperationAggregate operation = new OperationAggregate();

		Matrix a = operation.evaluate(m, dimension("p1"),
				AggregationFunction.MEAN, AggregationPeriod.MINUTE,
				dataset("d1"));

		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.1)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 0),
				component(measure("p2"), 0.2)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 2, 0),
				component(measure("p2"), 0.2)));

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		CsvRead r = new CsvRead();
		Matrix m1 = r.createMatrix(new File("src/test/resources/matrix.5.csv"));

		OperationAggregate op = new OperationAggregate();

		Matrix a = op.evaluate(m1, componentProperty("p1"),
				AggregationFunction.SUM, AggregationPeriod.MINUTE,
				dataset("d2"));

		Matrix e = new Matrix();

		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:01:00.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(3.2))),
				component(componentProperty("p3"),
						componentPropertyValue(Double
								.valueOf(3.4000000000000004)))));

		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:02:00.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double
								.valueOf(7.199999999999999))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(7.4)))));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		CsvRead r = new CsvRead();
		Matrix m1 = r.createMatrix(new File("src/test/resources/matrix.5.csv"));

		OperationAggregate op = new OperationAggregate();

		Matrix a = op.evaluate(m1, componentProperty("p1"),
				AggregationFunction.MAX, AggregationPeriod.MINUTE,
				dataset("d2"));

		Matrix e = new Matrix();

		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:01:00.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(2.1))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(2.2)))));

		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:02:00.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(4.1))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(4.2)))));

		assertEquals(e, a);
	}

	@Test
	public void test5() {
		CsvRead r = new CsvRead();
		Matrix m1 = r.createMatrix(new File("src/test/resources/matrix.6.csv"));

		OperationAggregate op = new OperationAggregate();

		Matrix a = op.evaluate(m1, componentProperty("p1"),
				AggregationFunction.MAX, AggregationPeriod.MINUTE,
				dataset("d2"));

		Matrix e = new Matrix();

		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:01:00.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(2.1))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(2.2)))));

		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:02:00.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(4.1))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(4.2)))));

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		CsvRead r = new CsvRead();
		Matrix m1 = r.createMatrix(new File("src/test/resources/matrix.8.csv"));

		OperationAggregate op = new OperationAggregate();

		Matrix a = op.evaluate(m1, componentProperty("p1"),
				AggregationFunction.MEAN, AggregationPeriod.DAY, dataset("d2"));

		Matrix e = new Matrix();

		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:00:00.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(1.1)))));

		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-02T00:00:00.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(2.1)))));

		assertEquals(e, a);
	}

}
