/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base.test;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentProperty;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyValue;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;

import java.io.File;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;
import static org.junit.Assert.assertEquals;

import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.base.OperationMax;
import fi.uef.envi.wavellite.math.utils.CsvRead;

/**
 * <p>
 * Title: OperationMaxTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationMaxTest {

	private static final DateTimeFormatter dtf = ISODateTimeFormat.dateTimeParser()
			.withOffsetParsed();

	@Test
	public void test1() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.1.csv"),
				componentProperty("p1"), componentProperty("p2"),
				componentProperty("p3"));

		OperationMax op = new OperationMax();

		DatasetObservation a = op.evaluate(m, dataset("d2"));

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(dataset("d2"));
		e.addComponent(componentProperty("p1"), componentPropertyValue(3.1));
		e.addComponent(componentProperty("p2"), componentPropertyValue(3.2));
		e.addComponent(componentProperty("p3"), componentPropertyValue(3.3));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.2.csv"));

		OperationMax op = new OperationMax();

		DatasetObservation a = op.evaluate(m, dataset("d2"));

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(dataset("d2"));
		e.addComponent(componentProperty("p1"), componentPropertyValue(3.1));
		e.addComponent(componentProperty("p2"), componentPropertyValue(3.2));
		e.addComponent(componentProperty("p3"), componentPropertyValue(3.3));

		assertEquals(e, a);
	}

	@Test
	public void test3() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.3.csv"));

		OperationMax op = new OperationMax();

		DatasetObservation a = op.evaluate(m, dataset("d2"));

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(dataset("d2"));
		e.addComponent(componentProperty("p1"), componentPropertyValue(3.0));
		e.addComponent(componentProperty("p2"), componentPropertyValue(3.2));
		e.addComponent(componentProperty("p3"), componentPropertyValue(3.3));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.3.csv"));

		OperationMax op = new OperationMax();

		DatasetObservation o = op.evaluate(m);

		assertEquals(Double.valueOf(3.0),
				o.getComponentPropertyValue(componentProperty("p1"))
						.getValueAsDouble());
	}

	@Test
	public void test5() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.4.csv"));

		OperationMax op = new OperationMax();

		DatasetObservation o = op.evaluate(m, componentProperty("p1"));

		assertEquals(dtf.parseDateTime("2013-01-01T00:00:00.000+02:00"), o
				.getComponentPropertyValue(componentProperty("p1"))
				.getValueAsTemporalLocation().getValueAsDateTime());
		assertEquals(Double.valueOf(3.0),
				o.getComponentPropertyValue(componentProperty("p2"))
						.getValueAsDouble());
	}

	@Test
	public void test6() {
		CsvRead r = new CsvRead();
		Matrix m1 = r.createMatrix(new File("src/test/resources/matrix.5.csv"));

		OperationMax op = new OperationMax();

		DatasetObservation o = op.evaluate(m1, componentProperty("p1"));

		assertEquals(dtf.parseDateTime("2013-01-01T00:01:00.000+02:00"), o
				.getComponentPropertyValue(componentProperty("p1"))
				.getValueAsTemporalLocation().getValueAsDateTime());
		assertEquals(Double.valueOf(4.1),
				o.getComponentPropertyValue(componentProperty("p2"))
						.getValueAsDouble());
	}
}
