/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base.test;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentProperty;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyValue;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dimension;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.measure;

import java.io.File;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.base.OperationMean;
import fi.uef.envi.wavellite.math.utils.CsvRead;

/**
 * <p>
 * Title: OperationMeanTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationMeanTest {

	private static final DateTimeFormatter dtf = ISODateTimeFormat.dateTimeParser()
			.withOffsetParsed();

	@Test
	public void test1() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1)));

		OperationMean mean = new OperationMean();

		DatasetObservation a = mean.evaluate(m, dimension("p1"), dataset("d1"));

		DatasetObservation e = datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.1));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1)));

		OperationMean mean = new OperationMean();

		DatasetObservation a = mean.evaluate(m, dimension("p1"), dataset("d1"));

		DatasetObservation e = datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0));

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0), component(measure("p3"), 0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2), component(measure("p3"), 1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1), component(measure("p3"), 2)));

		OperationMean mean = new OperationMean();

		DatasetObservation a = mean.evaluate(m, dimension("p1"), dataset("d1"));

		DatasetObservation e = datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.1), component(measure("p3"), 1.0));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0), component(measure("p3"), 0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2), component(measure("p3"), 1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1), component(measure("p3"), 2)));

		OperationMean mean = new OperationMean();

		DatasetObservation a = mean.evaluate(m, dimension("p1"), dataset("d1"));

		DatasetObservation e = datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.1), component(measure("p3"), 0.0));

		assertNotEquals(e, a);
	}

	@Test
	public void test5() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0), component(measure("p3"), 0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2), component(measure("p3"), 1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1), component(measure("p3"), 2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 0),
				component(measure("p2"), 0.0), component(measure("p3"), 0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 2),
				component(measure("p2"), 0.2), component(measure("p3"), 1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 1),
				component(measure("p2"), 0.1), component(measure("p3"), 2)));

		OperationMean mean = new OperationMean();

		DatasetObservation a = mean.evaluate(m, dimension("p1"), dataset("d1"));

		DatasetObservation e = datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.1), component(measure("p3"), 1.0));

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.1.csv"),
				componentProperty("p1"), componentProperty("p2"),
				componentProperty("p3"));

		OperationMean op = new OperationMean();

		DatasetObservation a = op.evaluate(m, dataset("d2"));

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(dataset("d2"));
		e.addComponent(componentProperty("p1"), componentPropertyValue(2.1));
		e.addComponent(componentProperty("p2"), componentPropertyValue(2.2));
		e.addComponent(componentProperty("p3"), componentPropertyValue(2.3));

		assertEquals(e, a);
	}

	@Test
	public void test7() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.2.csv"));

		OperationMean op = new OperationMean();

		DatasetObservation a = op.evaluate(m, dataset("d2"));

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(dataset("d2"));
		e.addComponent(componentProperty("p1"), componentPropertyValue(2.1));
		e.addComponent(componentProperty("p2"), componentPropertyValue(2.2));
		e.addComponent(componentProperty("p3"), componentPropertyValue(2.3));

		assertEquals(e, a);
	}

	@Test
	public void test8() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.3.csv"));

		OperationMean op = new OperationMean();

		DatasetObservation a = op.evaluate(m, dataset("d2"));

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(dataset("d2"));
		e.addComponent(componentProperty("p1"), componentPropertyValue(2.0));
		e.addComponent(componentProperty("p2"), componentPropertyValue(2.2));
		e.addComponent(componentProperty("p3"), componentPropertyValue(2.3));

		assertEquals(e, a);
	}

	@Test
	public void test9() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.3.csv"));

		OperationMean op = new OperationMean();

		DatasetObservation o = op.evaluate(m);

		assertEquals(Double.valueOf(2.0),
				o.getComponentPropertyValue(componentProperty("p1"))
						.getValueAsDouble());
	}

	@Test
	public void test10() {
		CsvRead r = new CsvRead();
		Matrix m = r.createMatrix(new File("src/test/resources/matrix.4.csv"));

		OperationMean op = new OperationMean();

		DatasetObservation o = op.evaluate(m, componentProperty("p1"));

		assertEquals(dtf.parseDateTime("2013-01-01T00:00:00.000+02:00"), o
				.getComponentPropertyValue(componentProperty("p1"))
				.getValueAsTemporalLocation().getValueAsDateTime());
		assertEquals(Double.valueOf(2.0),
				o.getComponentPropertyValue(componentProperty("p2"))
						.getValueAsDouble());
	}

	@Test
	public void test11() {
		CsvRead r = new CsvRead();
		Matrix m1 = r.createMatrix(new File("src/test/resources/matrix.5.csv"));

		OperationMean op = new OperationMean();

		DatasetObservation o = op.evaluate(m1, componentProperty("p1"));

		assertEquals(dtf.parseDateTime("2013-01-01T00:01:00.000+02:00"), o
				.getComponentPropertyValue(componentProperty("p1"))
				.getValueAsTemporalLocation().getValueAsDateTime());
		assertEquals(Double.valueOf(2.6),
				o.getComponentPropertyValue(componentProperty("p2"))
						.getValueAsDouble());
		assertEquals(Double.valueOf(2.7),
				o.getComponentPropertyValue(componentProperty("p3"))
						.getValueAsDouble());
	}
}
