/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base.test;

import java.io.File;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;

import org.junit.Test;
import static org.junit.Assert.assertEquals;

import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.base.OperationNumericalDifferentiation;
import fi.uef.envi.wavellite.math.utils.CsvRead;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentProperty;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyValue;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;

/**
 * <p>
 * Title: OperationNumericalDifferentiationTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationNumericalDifferentiationTest {

	private static final DateTimeFormatter dtf = ISODateTimeFormat.dateTimeParser()
			.withOffsetParsed();

	@Test
	public void test1() {
		CsvRead r = new CsvRead();
		Matrix m1 = r.createMatrix(new File("src/test/resources/matrix.7.csv"));

		OperationNumericalDifferentiation op = new OperationNumericalDifferentiation();

		Matrix a = op.evaluate(m1, componentProperty("p1"), dataset("d2"));
		
		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:00:01.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(1/1000d))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(1/1000d)))));
		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:00:02.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(0/1000d))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(0/1000d)))));
		
		assertEquals(e, a);
	}
	
	@Test
	public void test2() {
		CsvRead r = new CsvRead();
		Matrix m1 = r.createMatrix(new File("src/test/resources/matrix.7.csv"));

		OperationNumericalDifferentiation op = new OperationNumericalDifferentiation();

		Matrix a = op.evaluate(m1, componentProperty("p1"), dataset("d2"), false);
		
		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:00:01.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(1))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(1)))));
		e.addDatasetObservation(datasetObservation(
				dataset("d2"),
				component(componentProperty("p1"), componentPropertyValue(dtf
						.parseDateTime("2013-01-01T00:00:02.000+02:00"))),
				component(componentProperty("p2"),
						componentPropertyValue(Double.valueOf(0))),
				component(componentProperty("p3"),
						componentPropertyValue(Double.valueOf(0)))));
		
		assertEquals(e, a);
	}
	
}
