/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base.test;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dimension;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.measure;

import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.base.OperationOutlier;

/**
 * <p>
 * Title: OperationOutlierTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationOutlierTest {

	@Test
	public void test1() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 1.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 3),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 4),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 5),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 6),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 7),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 8),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 9),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 10),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 11),
				component(measure("p2"), 0.0)));

		OperationOutlier op = new OperationOutlier();

		Matrix a = op.remove(m, dimension("p1"), dataset("d1"), 3);

		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 3),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 4),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 5),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 6),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 7),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 8),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 9),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 10),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 11),
				component(measure("p2"), 0.0)));

		assertEquals(e, a);
		assertTrue(op.hasRemovedOutliers());
	}

}
