/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base.test;

import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import fi.uef.envi.wavellite.math.SortDirection;
import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.base.OperationSort;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dimension;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.measure;

/**
 * <p>
 * Title: OperationSortTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Operator
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationSortTest {

	@Test
	public void test1() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1)));

		OperationSort sort = new OperationSort();

		Matrix a = sort.temporalLocation(m, dimension("p1"), dataset("d1"));

		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2)));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1)));

		OperationSort sort = new OperationSort();

		Matrix a = sort.temporalLocation(m, dimension("p1"), dataset("d1"));

		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1)));

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1)));

		OperationSort sort = new OperationSort();

		Matrix a = sort.temporalLocation(m, dimension("p1"),
				SortDirection.DESC, dataset("d1"));

		Matrix e = new Matrix();
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 2),
				component(measure("p2"), 0.2)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 1),
				component(measure("p2"), 0.1)));
		e.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));

		assertEquals(e, a);
	}

}
