/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.operation.base.test;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dimension;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.measure;

import org.junit.Test;
import static org.junit.Assert.assertArrayEquals;

import fi.uef.envi.wavellite.math.AggregationPeriod;
import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.base.OperationSplit;

/**
 * <p>
 * Title: OperationSplitTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class OperationSplitTest {

	@Test
	public void test1() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 30),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 0),
				component(measure("p2"), 0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 1, 30),
				component(measure("p2"), 0.3)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 2, 0),
				component(measure("p2"), -0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 2, 30),
				component(measure("p2"), -0.3)));

		OperationSplit op = new OperationSplit();

		Matrix[] a = op.evaluate(m, dimension("p1"), AggregationPeriod.MINUTE,
				dataset("d1"));

		Matrix[] e = new Matrix[] {
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
						component(measure("p2"), 0.0)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 0, 30),
						component(measure("p2"), 0.2))),
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 1, 0),
						component(measure("p2"), 0.1)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 1, 30),
						component(measure("p2"), 0.3))),
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 2, 0),
						component(measure("p2"), -0.1)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 2, 30),
						component(measure("p2"), -0.3))) };

		assertArrayEquals(e, a);
	}
	
	@Test
	public void test2() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 30, 0),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 1, 0, 0),
				component(measure("p2"), 0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 1, 30, 0),
				component(measure("p2"), 0.3)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 2, 0, 0),
				component(measure("p2"), -0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 2, 30, 0),
				component(measure("p2"), -0.3)));

		OperationSplit op = new OperationSplit();

		Matrix[] a = op.evaluate(m, dimension("p1"), AggregationPeriod.HOUR,
				dataset("d1"));

		Matrix[] e = new Matrix[] {
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
						component(measure("p2"), 0.0)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 30, 0),
						component(measure("p2"), 0.2))),
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 1, 0, 0),
						component(measure("p2"), 0.1)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 1, 30, 0),
						component(measure("p2"), 0.3))),
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 2, 0, 0),
						component(measure("p2"), -0.1)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 2, 30, 0),
						component(measure("p2"), -0.3))) };

		assertArrayEquals(e, a);
	}
	
	@Test
	public void test3() {
		Matrix m = new Matrix();
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
				component(measure("p2"), 0.0)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 1, 12, 0, 0),
				component(measure("p2"), 0.2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 2, 0, 0, 0),
				component(measure("p2"), 0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 2, 12, 0, 0),
				component(measure("p2"), 0.3)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 3, 0, 0, 0),
				component(measure("p2"), -0.1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component(dimension("p1"), 2000, 1, 3, 12, 0, 0),
				component(measure("p2"), -0.3)));

		OperationSplit op = new OperationSplit();

		Matrix[] a = op.evaluate(m, dimension("p1"), AggregationPeriod.DAY,
				dataset("d1"));

		Matrix[] e = new Matrix[] {
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 0, 0, 0),
						component(measure("p2"), 0.0)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 1, 12, 0, 0),
						component(measure("p2"), 0.2))),
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 2, 0, 0, 0),
						component(measure("p2"), 0.1)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 2, 12, 0, 0),
						component(measure("p2"), 0.3))),
				new Matrix(datasetObservation(dataset("d1"),
						component(dimension("p1"), 2000, 1, 3, 0, 0, 0),
						component(measure("p2"), -0.1)), datasetObservation(
						dataset("d1"),
						component(dimension("p1"), 2000, 1, 3, 12, 0, 0),
						component(measure("p2"), -0.3))) };

		assertArrayEquals(e, a);
	}
	
}
