/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.matrix.test;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.commons.collections4.IteratorUtils;
import org.apache.commons.math3.linear.MatrixUtils;
import org.apache.commons.math3.linear.RealMatrix;
import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.ComponentSpecification;
import fi.uef.envi.wavellite.entity.derivation.DataStructureDefinition;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentSpecificationBase;
import fi.uef.envi.wavellite.entity.derivation.base.DataStructureDefinitionBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.math.matrix.Matrix;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.datasetObservation;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentProperty;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyValue;

/**
 * <p>
 * Title: MatrixTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class MatrixTest {

	@Test
	public void test1() {
		DataStructureDefinition d = new DataStructureDefinitionBase();
		ComponentSpecification cs1 = new ComponentSpecificationBase();
		cs1.setComponentProperty(new ComponentPropertyBase("p1"));
		ComponentSpecification cs2 = new ComponentSpecificationBase();
		cs2.setComponentProperty(new ComponentPropertyBase("p2"));
		d.addComponentSpecification(cs1);
		d.addComponentSpecification(cs2);

		Matrix m = new Matrix(d);

		assertEquals(2, m.getDimensionality());

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));

		assertEquals(1, m.size());
	}

	@Test
	public void test2() {
		Matrix m = new Matrix();

		assertEquals(0, m.getDimensionality());

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));

		assertEquals(2, m.getDimensionality());
		assertEquals(1, m.size());
	}

	@Test
	public void test3() {
		DataStructureDefinition dsd = new DataStructureDefinitionBase();
		ComponentSpecification cs1 = new ComponentSpecificationBase();
		cs1.setComponentProperty(new ComponentPropertyBase("p1"));
		ComponentSpecification cs2 = new ComponentSpecificationBase();
		cs2.setComponentProperty(new ComponentPropertyBase("p2"));
		dsd.addComponentSpecification(cs1);
		dsd.addComponentSpecification(cs2);

		Dataset d = new DatasetBase("d1");
		d.setDataStructureDefinition(dsd);

		Matrix m = new Matrix(d);

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));

		assertEquals(2, m.getDimensionality());
		assertEquals(1, m.size());
	}

	@Test
	public void test4() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0)));

		assertEquals(2, m.getDimensionality());
		assertEquals(2, m.size());
	}

	@Test
	public void test5() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0)));

		Iterator<DatasetObservation> it = m.iterator();

		List<DatasetObservation> a = IteratorUtils.toList(it);

		List<DatasetObservation> e = new ArrayList<DatasetObservation>();

		e.add(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		e.add(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 1, 0, 0), component("p2", 0.0)));

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0)));

		Iterator<DatasetObservation> it = m.iterator();

		List<DatasetObservation> a = IteratorUtils.toList(it);

		List<DatasetObservation> e = new ArrayList<DatasetObservation>();

		e.add(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		e.add(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 1, 0, 0), component("p2", 0.5)));

		assertNotEquals(e, a);
	}

	@Test
	public void test7() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0)));

		Iterator<ComponentPropertyValue> it = m
				.columnIterator(componentProperty("p2"));

		List<ComponentPropertyValue> a = IteratorUtils.toList(it);

		List<ComponentPropertyValue> e = new ArrayList<ComponentPropertyValue>();

		e.add(componentPropertyValue(0.5));
		e.add(componentPropertyValue(0.0));

		assertEquals(e, a);
	}

	@Test
	public void test8() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0)));

		Iterator<ComponentPropertyValue> it = m
				.columnIterator(componentProperty("p2"));

		List<ComponentPropertyValue> a = IteratorUtils.toList(it);

		List<ComponentPropertyValue> e = new ArrayList<ComponentPropertyValue>();

		e.add(componentPropertyValue(0.5));
		e.add(componentPropertyValue(0.5));

		assertNotEquals(e, a);
	}

	@Test
	public void test9() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0)));

		DatasetObservation a = m.getDatasetObservation(1);

		DatasetObservation e = datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0));

		assertEquals(e, a);
	}

	@Test
	public void test10() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0)));

		DatasetObservation a = m.getDatasetObservation(1);

		DatasetObservation e = datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 1, 0, 0), component("p2", 0.0));

		assertEquals(e, a);
	}

	@Test
	public void test11() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0)));

		DatasetObservation a = m.getDatasetObservation(1);

		DatasetObservation e = datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 1, 0, 0), component("p2", 0.5));

		assertNotEquals(e, a);
	}

	@Test
	public void test12() {
		Matrix m = new Matrix();

		m.addDatasetObservation(
				0,
				datasetObservation(dataset("d1"),
						component("p1", 2013, 12, 13, 0, 0, 0),
						component("p2", 0.5)));
		m.addDatasetObservation(
				1,
				datasetObservation(dataset("d1"), component("p2", 0.0),
						component("p1", 2013, 12, 13, 1, 0, 0)));

		DatasetObservation a = m.getDatasetObservation(1);

		DatasetObservation e = datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 1, 0, 0), component("p2", 0.0));

		assertEquals(e, a);
	}

	@Test
	public void test13() {
		Matrix m = new Matrix();

		m.addDatasetObservation(
				0,
				datasetObservation(dataset("d1"),
						component("p1", 2013, 12, 13, 0, 0, 0),
						component("p2", 0.5)));
		m.addDatasetObservation(
				1,
				datasetObservation(dataset("d1"), component("p2", 0.0),
						component("p1", 2013, 12, 13, 1, 0, 0)));

		DatasetObservation a = m.getDatasetObservation(1);

		DatasetObservation e = datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 1, 0, 0), component("p2", 0.5));

		assertNotEquals(e, a);
	}

	@Test
	public void test14() {
		Matrix m = new Matrix();

		m.addDatasetObservation(
				1,
				datasetObservation(dataset("d1"),
						component("p1", 2013, 12, 13, 0, 0, 0),
						component("p2", 0.5)));
		m.addDatasetObservation(
				2,
				datasetObservation(dataset("d1"), component("p2", 0.0),
						component("p1", 2013, 12, 13, 1, 0, 0)));
		m.addDatasetObservation(
				3,
				datasetObservation(dataset("d1"), component("p2", -0.5),
						component("p1", 2013, 12, 13, 2, 0, 0)));

		assertEquals(3, m.size());
	}

	@Test
	public void test15() {
		Matrix m = new Matrix(dataset("d1"), componentProperty("p1"));

		m.addDatasetObservation(0.5);

		assertEquals(Double.valueOf(0.5), m.getComponentPropertyValue(0, 0)
				.getValueAsDouble());
	}

	@Test
	public void test16() {
		Matrix m = new Matrix(dataset("d1"), componentProperty("p1"),
				componentProperty("p2"));

		m.addDatasetObservation(0.5, 1.0);
		m.addDatasetObservation(1.5, 2.0);

		assertEquals(Double.valueOf(2.0), m.getComponentPropertyValue(1, 1)
				.getValueAsDouble());
	}

	@Test
	public void test17() {
		Matrix m = new Matrix();

		Dataset d1 = new DatasetBase("d1", "dt1");
		ComponentProperty p1 = new ComponentPropertyBase("p1", "pt1");
		DatasetObservation e = new DatasetObservationBase("o1", "ot1");
		e.setDataset(d1);
		e.addComponent(p1, new ComponentPropertyValueDouble(0.5));

		m.addDatasetObservation(e);

		DatasetObservation a = m.getDatasetObservation(0);

		assertEquals(e, a);
	}

	@Test
	public void test18() {
		Matrix m = new Matrix();

		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p1", 2013, 12, 13, 0, 0, 0), component("p2", 0.5),
				component("p3", 1)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", 0.0), component("p1", 2013, 12, 13, 1, 0, 0),
				component("p3", 2)));
		m.addDatasetObservation(datasetObservation(dataset("d1"),
				component("p2", -0.5), component("p1", 2013, 12, 13, 2, 0, 0),
				component("p3", 3)));

		RealMatrix a = m.asRealMatrix();

		RealMatrix e = MatrixUtils.createRealMatrix(new double[][] {
				{ 0.5, 1 }, { 0.0, 2 }, { -0.5, 3 } });
		
		assertEquals(e, a);
	}

}
