/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.math.utils.test;

import java.io.File;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;
import static org.junit.Assert.assertEquals;

import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.utils.CsvRead;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentProperty;

/**
 * <p>
 * Title: CsvReadTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Math
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class CsvReadTest {

	private static final DateTimeFormatter dtf = ISODateTimeFormat.dateTimeParser()
			.withOffsetParsed();

	@Test
	public void test1() {
		CsvRead r = new CsvRead();

		Matrix m = r.createMatrix(new File("src/test/resources/matrix.1.csv"),
				componentProperty("p1"), componentProperty("p2"),
				componentProperty("p3"));

		assertEquals(Double.valueOf(1.1), m.getComponentPropertyValue(0, 0)
				.getValueAsDouble());
		assertEquals(Double.valueOf(3.3), m.getComponentPropertyValue(2, 2)
				.getValueAsDouble());
	}

	@Test
	public void test2() {
		CsvRead r = new CsvRead();

		Matrix m = r.createMatrix(new File("src/test/resources/matrix.2.csv"));

		assertEquals(Double.valueOf(1.1), m.getComponentPropertyValue(0, 0)
				.getValueAsDouble());
		assertEquals(Double.valueOf(3.3), m.getComponentPropertyValue(2, 2)
				.getValueAsDouble());
	}

	@Test
	public void test3() {
		CsvRead r = new CsvRead();

		Matrix m = r.createMatrix(new File("src/test/resources/matrix.3.csv"));

		assertEquals(Integer.valueOf(1), m.getComponentPropertyValue(0, 0)
				.getValueAsInteger());
		assertEquals(Integer.valueOf(3), m.getComponentPropertyValue(2, 0)
				.getValueAsInteger());
	}

	@Test
	public void test4() {
		CsvRead r = new CsvRead();

		Matrix m = r.createMatrix(new File("src/test/resources/matrix.4.csv"));

		assertEquals(dtf.parseDateTime("2013-01-01T00:00:00.000+02:00"), m
				.getComponentPropertyValue(0, 0).getValueAsTemporalLocation()
				.getValueAsDateTime());
		assertEquals(Integer.valueOf(3), m.getComponentPropertyValue(2, 1)
				.getValueAsInteger());
	}

}
