/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.operator.processing.base.aggregation;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

import org.apache.commons.collections4.IteratorUtils;

import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyDimension;
import fi.uef.envi.wavellite.math.AggregationFunction;
import fi.uef.envi.wavellite.math.AggregationPeriod;
import fi.uef.envi.wavellite.math.matrix.Matrix;
import fi.uef.envi.wavellite.math.matrix.operation.base.OperationAggregate;
import fi.uef.envi.wavellite.operator.processing.base.AbstractDatasetObservationProcessor;

/**
 * <p>
 * Title: DatasetObservationProcessorAggregate
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Operator
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class DatasetObservationProcessorAggregate extends
		AbstractDatasetObservationProcessor {

	private AggregationFunction function;
	private AggregationPeriod period;
	private ComponentPropertyDimension temporalLocationDimension;
	private OperationAggregate operation;

	public DatasetObservationProcessorAggregate(Dataset targetDataset,
			AggregationFunction function, AggregationPeriod period,
			ComponentPropertyDimension temporalLocationDimension) {
		this(targetDataset, function, period, temporalLocationDimension, null);
	}

	public DatasetObservationProcessorAggregate(Dataset targetDataset,
			AggregationFunction function, AggregationPeriod period,
			ComponentPropertyDimension temporalLocationDimension,
			String datasetObservationType) {
		super(targetDataset, datasetObservationType);

		this.function = function;
		this.period = period;
		this.temporalLocationDimension = temporalLocationDimension;
		this.datasetObservationType = datasetObservationType;
		this.operation = new OperationAggregate();
	}

	@Override
	public Set<DatasetObservation> process(Set<DatasetObservation> observations) {
		if (observations.isEmpty())
			return Collections.emptySet();

		return new HashSet<DatasetObservation>(IteratorUtils.toList(operation
				.evaluate(new Matrix(observations), temporalLocationDimension,
						function, period, targetDataset).iterator()));
	}

	public AggregationFunction getAggregationFunction() {
		return function;
	}

	public void setAggregationFunction(AggregationFunction function) {
		this.function = function;
	}

	public AggregationPeriod getAggregationPeriod() {
		return period;
	}

	public void setAggregationPeriod(AggregationPeriod period) {
		this.period = period;
	}

}
