/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.operator.processing.base.merging;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.operator.processing.base.AbstractDatasetObservationProcessor;

/**
 * <p>
 * Title: DatasetObservationProcessorMerge
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Operator
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class DatasetObservationProcessorMerge extends
		AbstractDatasetObservationProcessor {

	public DatasetObservationProcessorMerge(Dataset targetDataset) {
		this(targetDataset, null);
	}
	
	public DatasetObservationProcessorMerge(Dataset targetDataset, String datasetObservationType) {
		super(targetDataset, datasetObservationType);
	}

	@Override
	public Set<DatasetObservation> process(Set<DatasetObservation> observations) {
		if (observations.isEmpty())
			return Collections.emptySet();

		DatasetObservation ret = new DatasetObservationBase();
		ret.setDataset(targetDataset);

		if (datasetObservationType != null)
			ret.setType(datasetObservationType);
		
		// Create a temporary collection for the components of all observations
		// to avoid warning messages of duplicate component properties in
		// returned dataset observation. This temporary set will have all
		// duplicates removed. Note that this will fail if .equals() includes
		// the unique ids.
		Set<Component> tmp = new HashSet<Component>();

		for (DatasetObservation observation : observations) {
			tmp.addAll(observation.getComponents());
		}

		ret.addComponents(tmp);

		return Collections.singleton(ret);
	}

}
