/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.operator.translation.base;

import fi.uef.envi.wavellite.entity.measurement.MeasurementValueContext;
import fi.uef.envi.wavellite.entity.measurement.MeasurementResult;
import fi.uef.envi.wavellite.entity.measurement.MeasurementValueVisitor;
import fi.uef.envi.wavellite.entity.measurement.base.MeasurementValueDouble;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.observation.base.SensorObservationBase;
import fi.uef.envi.wavellite.entity.observation.base.SensorOutputBase;
import fi.uef.envi.wavellite.operator.translation.MeasurementResultTranslator;

/**
 * <p>
 * Title: MeasurementResultTranslatorBase
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Operator
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class MeasurementResultTranslatorBase implements
		MeasurementResultTranslator {

	private SensorObservation ret;
	private MeasurementValueVisitor visitor;
	private String sensorObservationType;
	private String sensorOutputType;
	private String observationValueType;

	public MeasurementResultTranslatorBase() {
		this(null, null, null);
	}

	public MeasurementResultTranslatorBase(String sensorObservationType,
			String sensorOutputType, String observationValueType) {
		visitor = new TranslatorMeasurementValueVisitor();

		this.sensorObservationType = sensorObservationType;
		this.sensorOutputType = sensorOutputType;
		this.observationValueType = observationValueType;
	}

	@Override
	public SensorObservation translate(MeasurementResult result) {
		MeasurementValueContext context = result.getContext();

		ret = new SensorObservationBase();

		if (sensorObservationType != null)
			ret.setType(sensorObservationType);

		ret.setSensor(context.getSensor());
		ret.setProperty(context.getProperty());
		ret.setFeature(context.getFeature());
		ret.setTemporalLocation(context.getTemporalLocation());

		result.getValue().accept(visitor);

		return ret;
	}

	private class TranslatorMeasurementValueVisitor implements
			MeasurementValueVisitor {

		@Override
		public void visit(MeasurementValueDouble value) {
			SensorOutput o = new SensorOutputBase();

			if (sensorOutputType != null)
				ret.setType(sensorOutputType);

			ObservationValue ov = new ObservationValueDouble();
			ov.setValue(value.getValue());

			if (observationValueType != null)
				ret.setType(observationValueType);

			o.setObservationValue(ov);

			ret.setSensorOutput(o);
		}
	}

	@Override
	public String getSensorObservationType() {
		return sensorObservationType;
	}

	@Override
	public void setSensorObservationType(String type) {
		sensorObservationType = type;
	}

	@Override
	public String getSensorOutputType() {
		return sensorOutputType;
	}

	@Override
	public void setSensorOutputType(String type) {
		sensorOutputType = type;
	}

	@Override
	public String getObservationValueType() {
		return observationValueType;
	}

	@Override
	public void setObservationValueType(String type) {
		observationValueType = type;
	}

}
