/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.operator.extraction.esper.test;

import java.util.HashSet;
import java.util.LinkedHashSet;
import java.util.Set;

import org.joda.time.DateTime;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import com.espertech.esper.client.EventBean;
import com.espertech.esper.client.UpdateListener;

import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ElementaryInfonBase;
import fi.uef.envi.wavellite.entity.situation.base.RelationBase;
import fi.uef.envi.wavellite.entity.situation.base.RelevantIndividualBase;
import fi.uef.envi.wavellite.entity.situation.base.SituationBase;
import fi.uef.envi.wavellite.operator.extraction.base.esper.AbstractSituationExtractorListenerEsper;
import fi.uef.envi.wavellite.operator.extraction.base.esper.SituationExtractorEsper;
import fi.uef.envi.wavellite.vocabulary.SDMX;

/**
 * <p>
 * Title: SituationExtractionWekaTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Operator
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class SituationExtractionEsperTest {

	@Test
	public void test1() {
		// String e = "select * from DatasetObservationType "
		// + "where components[1].componentProperty.id = 'p1' " +
		// "and cast(components[1].componentPropertyValue.value, double) > 0.0";
		String ex = "select avg(components[1].componentPropertyValue.value) as avg "
				+ "from DatasetObservationType.win:time_batch(5 sec) "
				+ "having avg(components[1].componentPropertyValue.value) = 0.0";

		SituationExtractorEsper o = new SituationExtractorEsper();
		o.setListener(new TestSituationAcquirerListenerEsper());
		o.addExpression(ex);

		Set<DatasetObservation> s = new LinkedHashSet<DatasetObservation>();

		DatasetObservation o1 = new DatasetObservationBase();
		o1.setDataset(new DatasetBase("d1"));
		o1.addComponent(new ComponentPropertyBase(SDMX.Dimension.timePeriod),
				new ComponentPropertyValueTemporalLocation(
						new TemporalLocationDateTime(new DateTime(2013, 11, 05,
								0, 0, 0))));
		o1.addComponent(new ComponentPropertyBase("p1"),
				new ComponentPropertyValueDouble(0.5));
		s.add(o1);

		DatasetObservation o2 = new DatasetObservationBase();
		o2.setDataset(new DatasetBase("d1"));
		o2.addComponent(new ComponentPropertyBase(SDMX.Dimension.timePeriod),
				new ComponentPropertyValueTemporalLocation(
						new TemporalLocationDateTime(new DateTime(2013, 11, 05,
								0, 0, 4))));
		o2.addComponent(new ComponentPropertyBase("p1"),
				new ComponentPropertyValueDouble(-0.5));
		s.add(o2);

		DatasetObservation o3 = new DatasetObservationBase();
		o3.setDataset(new DatasetBase("d1"));
		o3.addComponent(new ComponentPropertyBase(SDMX.Dimension.timePeriod),
				new ComponentPropertyValueTemporalLocation(
						new TemporalLocationDateTime(new DateTime(2013, 11, 05,
								0, 0, 10))));
		o3.addComponent(new ComponentPropertyBase("p1"),
				new ComponentPropertyValueDouble(1.0));
		s.add(o3);

		Set<Situation> a = new HashSet<Situation>();

		o.extract(s, a);

		Set<Situation> e = new HashSet<Situation>();

		Situation sit = new SituationBase();
		ElementaryInfon i = new ElementaryInfonBase();
		i.setRelation(new RelationBase("avg"));
		i.addRelevantObject(new RelevantIndividualBase(new AttributeValue(
				new ValueDouble(0.0))));
		i.setPolarity(Polarity.True);
		sit.addSupportedInfon(i);
		e.add(sit);

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		// String e = "select * from DatasetObservationType "
		// + "where components[1].componentProperty.id = 'p1' " +
		// "and cast(components[1].componentPropertyValue.value, double) > 0.0";
		String ex = "select avg(components[1].componentPropertyValue.value) as avg "
				+ "from DatasetObservationType.win:time_batch(5 sec) "
				+ "having avg(components[1].componentPropertyValue.value) = 0.0";

		SituationExtractorEsper o = new SituationExtractorEsper();
		o.setListener(new TestSituationAcquirerListenerEsper());
		o.addExpression(ex);

		Set<DatasetObservation> s = new HashSet<DatasetObservation>();

		DatasetObservation o1 = new DatasetObservationBase();
		o1.setDataset(new DatasetBase("d1"));
		o1.addComponent(new ComponentPropertyBase(SDMX.Dimension.timePeriod),
				new ComponentPropertyValueTemporalLocation(
						new TemporalLocationDateTime(new DateTime(2013, 11, 05,
								0, 0, 0))));
		o1.addComponent(new ComponentPropertyBase("p1"),
				new ComponentPropertyValueDouble(0.5));
		s.add(o1);

		DatasetObservation o2 = new DatasetObservationBase();
		o2.setDataset(new DatasetBase("d1"));
		o2.addComponent(new ComponentPropertyBase(SDMX.Dimension.timePeriod),
				new ComponentPropertyValueTemporalLocation(
						new TemporalLocationDateTime(new DateTime(2013, 11, 05,
								0, 0, 5))));
		o2.addComponent(new ComponentPropertyBase("p1"),
				new ComponentPropertyValueDouble(-0.5));
		s.add(o2);

		DatasetObservation o3 = new DatasetObservationBase();
		o3.setDataset(new DatasetBase("d1"));
		o3.addComponent(new ComponentPropertyBase(SDMX.Dimension.timePeriod),
				new ComponentPropertyValueTemporalLocation(
						new TemporalLocationDateTime(new DateTime(2013, 11, 05,
								0, 0, 10))));
		o3.addComponent(new ComponentPropertyBase("p1"),
				new ComponentPropertyValueDouble(1.0));
		s.add(o3);

		Set<Situation> a = new HashSet<Situation>();

		o.extract(s, a);

		Set<Situation> e = new HashSet<Situation>();

		Situation sit = new SituationBase();
		ElementaryInfon i = new ElementaryInfonBase();
		i.setRelation(new RelationBase("avg"));
		i.addRelevantObject(new RelevantIndividualBase(new AttributeValue(
				new ValueDouble(0.5))));
		i.setPolarity(Polarity.True);
		sit.addSupportedInfon(i);
		e.add(sit);

		assertNotEquals(e, a);
	}

	public class TestSituationAcquirerListenerEsper extends
			AbstractSituationExtractorListenerEsper {
		{
			setUpdateListener(new UpdateListener() {
				@Override
				public void update(EventBean[] newEvents, EventBean[] oldEvents) {
					double avg = (double) newEvents[0].get("avg");

					Situation s = new SituationBase();
					ElementaryInfon i = new ElementaryInfonBase();
					i.setRelation(new RelationBase("avg"));
					i.addRelevantObject(new RelevantIndividualBase(
							new AttributeValue(new ValueDouble(avg))));
					i.setPolarity(Polarity.True);
					s.addSupportedInfon(i);

					situations.add(s);
				}
			});
		}
	}

}
