/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.operator.processing.base.aggregation.test;

import java.util.HashSet;
import java.util.Set;

import org.junit.Test;
import static org.junit.Assert.assertEquals;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.component;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyTimePeriod;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.math.AggregationFunction;
import fi.uef.envi.wavellite.math.AggregationPeriod;
import fi.uef.envi.wavellite.operator.processing.base.aggregation.DatasetObservationProcessorAggregate;

/**
 * <p>
 * Title: DatasetObservationProcessorAggregateTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Operator
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class DatasetObservationProcessorAggregateTest {

	@Test
	public void test1() {
		DatasetObservationProcessorAggregate p = new DatasetObservationProcessorAggregate(
				new DatasetBase("d2"), AggregationFunction.MEAN,
				AggregationPeriod.MINUTE, componentPropertyTimePeriod());

		Set<DatasetObservation> observations = new HashSet<DatasetObservation>();

		Set<DatasetObservation> a = p.process(observations);

		Set<DatasetObservation> e = new HashSet<DatasetObservation>();

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		DatasetObservationProcessorAggregate p = new DatasetObservationProcessorAggregate(
				new DatasetBase("d2"), AggregationFunction.MEAN,
				AggregationPeriod.MINUTE, componentPropertyTimePeriod());

		Set<DatasetObservation> observations = new HashSet<DatasetObservation>();

		DatasetObservation o;

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(component(2013, 12, 04, 00, 00, 45));
		o.addComponent(component("p1", 0.5));
		observations.add(o);

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(component(2013, 12, 04, 00, 00, 50));
		o.addComponent(component("p1", 0.5));
		observations.add(o);

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(component(2013, 12, 04, 00, 00, 55));
		o.addComponent(component("p1", 0.5));
		observations.add(o);

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(component(2013, 12, 04, 00, 01, 05));
		o.addComponent(component("p1", 0.0));
		observations.add(o);

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(component(2013, 12, 04, 00, 01, 30));
		o.addComponent(component("p1", 0.0));
		observations.add(o);

		Set<DatasetObservation> a = p.process(observations);

		Set<DatasetObservation> e = new HashSet<DatasetObservation>();

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d2"));
		o.addComponent(component(2013, 12, 04, 00, 00, 00));
		o.addComponent(component("p1", 0.5));
		e.add(o);

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d2"));
		o.addComponent(component(2013, 12, 04, 00, 01, 00));
		o.addComponent(component("p1", 0.0));
		e.add(o);

		assertEquals(e, a);
	}

}
