/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.operator.processing.base.merging.test;

import java.util.HashSet;
import java.util.Set;

import org.joda.time.DateTime;
import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import fi.uef.envi.wavellite.entity.core.EntityFactory;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.operator.processing.base.merging.DatasetObservationProcessorMerge;

/**
 * <p>
 * Title: DatasetObservationProcessorMergeTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project:
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class DatasetObservationProcessorMergeTest {

	@Test
	public void test1() {
		DatasetObservationProcessorMerge p = new DatasetObservationProcessorMerge(
				new DatasetBase("d2"));

		Set<DatasetObservation> a = p
				.process(new HashSet<DatasetObservation>());
		Set<DatasetObservation> e = new HashSet<DatasetObservation>();

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		DatasetObservationProcessorMerge p = new DatasetObservationProcessorMerge(
				new DatasetBase("d2"));

		Set<DatasetObservation> s = new HashSet<DatasetObservation>();

		DatasetObservation o;

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(EntityFactory.componentPropertyTimePeriod(),
				EntityFactory.componentPropertyValue(EntityFactory
						.temporalLocation(new DateTime(2013, 11, 29, 0, 0, 0))));
		o.addComponent(EntityFactory.componentProperty("p1"),
				EntityFactory.componentPropertyValue(0.0));
		s.add(o);

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(EntityFactory.componentPropertyTimePeriod(),
				EntityFactory.componentPropertyValue(EntityFactory
						.temporalLocation(new DateTime(2013, 11, 29, 0, 0, 0))));
		o.addComponent(EntityFactory.componentProperty("p2"),
				EntityFactory.componentPropertyValue(0.5));
		s.add(o);

		Set<DatasetObservation> a = p.process(s);

		Set<DatasetObservation> e = new HashSet<DatasetObservation>();

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d2"));
		o.addComponent(EntityFactory.componentPropertyTimePeriod(),
				EntityFactory.componentPropertyValue(EntityFactory
						.temporalLocation(new DateTime(2013, 11, 29, 0, 0, 0))));
		o.addComponent(EntityFactory.componentProperty("p1"),
				EntityFactory.componentPropertyValue(0.0));
		o.addComponent(EntityFactory.componentProperty("p2"),
				EntityFactory.componentPropertyValue(0.5));
		e.add(o);

		assertEquals(e, a);
	}

	@Test
	public void test3() {
		DatasetObservationProcessorMerge p = new DatasetObservationProcessorMerge(
				new DatasetBase("d2"));

		Set<DatasetObservation> s = new HashSet<DatasetObservation>();

		DatasetObservation o;

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(EntityFactory.componentPropertyTimePeriod(),
				EntityFactory.componentPropertyValue(EntityFactory
						.temporalLocation(new DateTime(2013, 11, 29, 0, 0, 0))));
		o.addComponent(EntityFactory.componentProperty("p1"),
				EntityFactory.componentPropertyValue(0.0));
		s.add(o);

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(EntityFactory.componentPropertyTimePeriod(),
				EntityFactory.componentPropertyValue(EntityFactory
						.temporalLocation(new DateTime(2013, 11, 29, 0, 0, 0))));
		o.addComponent(EntityFactory.componentProperty("p2"),
				EntityFactory.componentPropertyValue(0.5));
		s.add(o);

		Set<DatasetObservation> a = p.process(s);

		Set<DatasetObservation> e = new HashSet<DatasetObservation>();

		o = new DatasetObservationBase();
		o.setDataset(new DatasetBase("d2"));
		o.addComponent(EntityFactory.componentPropertyTimePeriod(),
				EntityFactory.componentPropertyValue(EntityFactory
						.temporalLocation(new DateTime(2013, 11, 29, 0, 0, 0))));
		o.addComponent(EntityFactory.componentProperty("p1"),
				EntityFactory.componentPropertyValue(0.0));
		o.addComponent(EntityFactory.componentProperty("p2"),
				EntityFactory.componentPropertyValue(0.0));
		e.add(o);

		assertNotEquals(e, a);
	}

}
