/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.operator.translation.base.test;

import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import fi.uef.envi.wavellite.entity.core.base.FeatureBase;
import fi.uef.envi.wavellite.entity.core.base.PropertyBase;
import fi.uef.envi.wavellite.entity.core.base.SensorBase;
import fi.uef.envi.wavellite.entity.measurement.MeasurementValue;
import fi.uef.envi.wavellite.entity.measurement.MeasurementValueContext;
import fi.uef.envi.wavellite.entity.measurement.MeasurementResult;
import fi.uef.envi.wavellite.entity.measurement.base.MeasurementResultBase;
import fi.uef.envi.wavellite.entity.measurement.base.MeasurementValueContextBase;
import fi.uef.envi.wavellite.entity.measurement.base.MeasurementValueDouble;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.operator.translation.base.MeasurementResultTranslatorBase;

/**
 * <p>
 * Title: TranslatorMeasurementResultBaseTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Operator
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class TranslatorMeasurementResultBaseTest {

	@Test
	public void test1() {
		MeasurementResultTranslatorBase c = new MeasurementResultTranslatorBase();

		MeasurementResult mr = new MeasurementResultBase();
		MeasurementValue mv = new MeasurementValueDouble(0.0);
		MeasurementValueContext mc = new MeasurementValueContextBase();

		mc.setSensor(new SensorBase("s1"));
		mc.setProperty(new PropertyBase("p1"));
		mc.setFeature(new FeatureBase("f1"));

		mr.setContext(mc);
		mr.setValue(mv);

		SensorObservation so = c.translate(mr);

		assertEquals(new SensorBase("s1"), so.getSensor());
		assertEquals(new PropertyBase("p1"), so.getProperty());
		assertEquals(new FeatureBase("f1"), so.getFeature());
		assertEquals(Double.valueOf(0.0), so.getSensorOutput()
				.getObservationValue().getValue());
	}
	
	@Test
	public void test2() {
		MeasurementResultTranslatorBase c = new MeasurementResultTranslatorBase();

		MeasurementResult mr = new MeasurementResultBase();
		MeasurementValue mv = new MeasurementValueDouble(0.5);
		MeasurementValueContext mc = new MeasurementValueContextBase();

		mc.setSensor(new SensorBase("s1"));
		mc.setProperty(new PropertyBase("p1"));
		mc.setFeature(new FeatureBase("f1"));

		mr.setContext(mc);
		mr.setValue(mv);

		SensorObservation so = c.translate(mr);

		assertEquals(new SensorBase("s1"), so.getSensor());
		assertEquals(new PropertyBase("p1"), so.getProperty());
		assertEquals(new FeatureBase("f1"), so.getFeature());
		assertNotEquals(Double.valueOf(0.0), so.getSensorOutput()
				.getObservationValue().getValue());
	}

}
