/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.operator.translation.base.test;

import org.joda.time.DateTime;
import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import fi.uef.envi.wavellite.entity.core.EntityFactory;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyMeasure;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.observation.base.SensorObservationBase;
import fi.uef.envi.wavellite.entity.observation.base.SensorOutputBase;
import fi.uef.envi.wavellite.operator.translation.base.SensorObservationTranslatorBase;

/**
 * <p>
 * Title: TranslatorSensorObservationBaseTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Operator
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class TranslatorSensorObservationBaseTest {

	@Test
	public void test1() {
		SensorObservationTranslatorBase op = new SensorObservationTranslatorBase(
				new ComponentPropertyMeasure("v1"), new DatasetBase("d1"));

		SensorObservation so = new SensorObservationBase();
		so.setTemporalLocation(new TemporalLocationDateTime(new DateTime(2013,
				11, 27, 0, 0, 0)));
		so.setSensorOutput(new SensorOutputBase(new ObservationValueDouble(0.0)));

		DatasetObservation o = op.translate(so);

		assertEquals(new DatasetBase("d1"), o.getDataset());

		for (Component component : o.getComponents()) {
			ComponentProperty componentProperty = component
					.getComponentProperty();
			ComponentPropertyValue componentPropertyValue = component
					.getComponentPropertyValue();

			if (componentProperty.getId().equals(
					EntityFactory.componentPropertyTimePeriod().getId()))
				assertEquals(new DateTime(2013, 11, 27, 0, 0, 0),
						((TemporalLocationDateTime) componentPropertyValue
								.getValue()).getValue());
			else if (componentProperty.equals(new ComponentPropertyBase("v1")))
				assertEquals(0.0, componentPropertyValue.getValue());
		}
	}

	@Test
	public void test2() {
		SensorObservationTranslatorBase op = new SensorObservationTranslatorBase(
				new ComponentPropertyMeasure("v1"), new DatasetBase("d1"));

		SensorObservation so = new SensorObservationBase();
		so.setTemporalLocation(new TemporalLocationDateTime(new DateTime(2013,
				11, 27, 0, 0, 0)));
		so.setSensorOutput(new SensorOutputBase(new ObservationValueDouble(0.0)));

		DatasetObservation o = op.translate(so);

		assertEquals(new DatasetBase("d1"), o.getDataset());

		for (Component component : o.getComponents()) {
			ComponentProperty componentProperty = component
					.getComponentProperty();
			ComponentPropertyValue componentPropertyValue = component
					.getComponentPropertyValue();

			if (componentProperty.getId().equals(
					EntityFactory.componentPropertyTimePeriod().getId()))
				assertNotEquals(new DateTime(2013, 11, 27, 1, 0, 0),
						((TemporalLocationDateTime) componentPropertyValue
								.getValue()).getValue());
			else if (componentProperty.equals(new ComponentPropertyBase("v1")))
				assertNotEquals(0.5, componentPropertyValue.getValue());
		}
	}

}
