/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.core;

import fi.uef.envi.wavellite.entity.core.Entity;
import fi.uef.envi.wavellite.entity.core.EntityVisitor;
import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Operation;
import fi.uef.envi.wavellite.entity.core.Operator;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialGeometry;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.ComponentSpecification;
import fi.uef.envi.wavellite.entity.derivation.DataStructureDefinition;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.measurement.MeasurementResult;
import fi.uef.envi.wavellite.entity.measurement.MeasurementValue;
import fi.uef.envi.wavellite.entity.measurement.MeasurementValueContext;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.Stimulus;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ValueInteger;
import fi.uef.envi.wavellite.entity.situation.base.ValuePeriod;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;

/**
 * <p>
 * Title: AbstractEntityRepresentation
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project:
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public abstract class AbstractEntityRepresentation<T> implements
		EntityRepresentation<T> {

	private T representation;
	private EntityVisitor visitor = new ThisEntityVisitor();
	
	@Override
	public T createRepresentation(Entity entity) {
		entity.accept(visitor);
		
		return representation;
	}
	
	private class ThisEntityVisitor implements EntityVisitor {

		@Override
		public void visit(Feature entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Property entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Sensor entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(SpatialGeometry entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(SpatialLocation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(TemporalLocation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Component entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ComponentProperty entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ComponentPropertyValue entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ComponentSpecification entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Dataset entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(DatasetObservation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(DataStructureDefinition entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(MeasurementResult entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(MeasurementValueContext entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(MeasurementValue entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ObservationValue entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(SensorObservation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(SensorOutput entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Attribute entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ValueDouble entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ValueInteger entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ValuePeriod entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ValueString entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(AttributeUri entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(ElementaryInfon entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Relation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(RelevantObject entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(AttributeSpatialLocation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(AttributeTemporalLocation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Situation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Stimulus entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Operation entity) {
			representation = createRepresentation(entity);
		}

		@Override
		public void visit(Operator entity) {
			representation = createRepresentation(entity);
		}
		
	}
	
}
