/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.core;

import fi.uef.envi.wavellite.entity.core.Entity;
import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Operation;
import fi.uef.envi.wavellite.entity.core.Operator;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialGeometry;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryLineString;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.ComponentSpecification;
import fi.uef.envi.wavellite.entity.derivation.DataStructureDefinition;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueInteger;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueSpatialLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueString;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueUri;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.Stimulus;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.Value;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ValueInteger;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.ValuePeriod;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ValueUri;

/**
 * <p>
 * Title: EntityRepresentation
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public interface EntityRepresentation<T> {

	// The problem with these methods is that it is not necessarily
	// straightforward to rebuild a type from a representation. For instance, in
	// RDF the set of statements may have multiple statements with RDF.Type
	// predicate (reasoning); which one to use, etc. For now, limit this to the
	// representation of entities.
	// public Sensor createSensor(T representation);

	public T createRepresentation(Entity entity);

	public T createRepresentation(Operator operator);
	
	public T createRepresentation(Operation operation);
	
	public T createRepresentation(Sensor sensor);
	
	public T createRepresentation(Stimulus sensing);

	public Sensor createSensor(T object);

	public T createRepresentation(Property property);

	public Property createProperty(T object);

	public T createRepresentation(Feature feature);

	public Feature createFeature(T object);

	public T createRepresentation(SensorOutput output);

	public SensorOutput createSensorOutput(T object);

	public T createRepresentation(ObservationValue value);

	public ObservationValue createObservationValue(T object);

	public T createRepresentation(ObservationValueDouble value);

	public ObservationValueDouble createObservationValueDouble(T object);

	public T createRepresentation(SensorObservation observation);

	public SensorObservation createSensorObservation(T object);

	public T createRepresentation(TemporalLocation location);

	public TemporalLocation createTemporalLocation(T object);

	public T createRepresentation(TemporalLocationDateTime location);

	public TemporalLocationDateTime createTemporalLocationDateTime(T object);

	public T createRepresentation(TemporalLocationInterval location);

	public TemporalLocationInterval createTemporalLocationInterval(T object);

	public T createRepresentation(SpatialLocation location);

	public SpatialLocation createSpatialLocation(T object);

	public T createRepresentation(SpatialLocationPlace location);

	public SpatialLocationPlace createSpatialLocationPlace(T object);

	public T createRepresentation(SpatialLocationRegion location);

	public SpatialLocationRegion createSpatialLocationRegion(T object);

	public T createRepresentation(SpatialGeometry geometry);

	public SpatialGeometry createSpatialGeometry(T object);

	public T createRepresentation(SpatialGeometryPoint geometry);

	public SpatialGeometryPoint createSpatialGeometryPoint(T object);

	public T createRepresentation(SpatialGeometryPolygon geometry);

	public SpatialGeometryPolygon createSpatialGeometryPolygon(T object);

	public T createRepresentation(SpatialGeometryLineString geometry);

	public SpatialGeometryLineString createSpatialGeometryLineString(T object);

	public T createRepresentation(DatasetObservation observation);

	public DatasetObservation createDatasetObservation(T object);

	public T createRepresentation(Dataset dataset);

	public Dataset createDataset(T object);

	public T createRepresentation(DataStructureDefinition definition);

	public T createRepresentation(ComponentSpecification specification);

	public T createRepresentation(Component component);

	public Component createComponent(T object);

	public T createRepresentation(ComponentProperty property);

	public ComponentProperty createComponentProperty(T object);

	public T createRepresentation(ComponentPropertyValue value);

	public ComponentPropertyValue createComponentPropertyValue(T object);

	public T createRepresentation(ComponentPropertyValueDouble value);

	public ComponentPropertyValueDouble createComponentPropertyValueDouble(
			T object);

	public T createRepresentation(ComponentPropertyValueInteger value);

	public ComponentPropertyValueInteger createComponentPropertyValueInteger(
			T object);

	public T createRepresentation(ComponentPropertyValueString value);

	public ComponentPropertyValueString createComponentPropertyValueString(
			T object);

	public T createRepresentation(ComponentPropertyValueTemporalLocation value);

	public ComponentPropertyValueTemporalLocation createComponentPropertyValueTemporalLocation(
			T object);

	public T createRepresentation(ComponentPropertyValueSpatialLocation value);

	public ComponentPropertyValueSpatialLocation createComponentPropertyValueSpatialLocation(
			T object);

	public T createRepresentation(ComponentPropertyValueUri value);
	
	public ComponentPropertyValueUri createComponentPropertyValueUri(T object);

	public T createRepresentation(Situation situation);

	public Situation createSituation(T object);
	
	public T createRepresentation(ElementaryInfon infon);
	
	public ElementaryInfon createElementaryInfon(T object);

	public T createRepresentation(Relation relation);
	
	public Relation createRelation(T object);

	public T createRepresentation(RelevantObject object);
	
	public RelevantObject createRelevantObject(T object);

	public T createRepresentation(Polarity polarity);
	
	public Polarity createPolarity(T object);

	public T createRepresentation(RelevantIndividual individual);
	
	public RelevantIndividual createRelevantIndividual(T object);

	public T createRepresentation(Attribute attribute);
	
	public Attribute createAttribute(T object);

	public T createRepresentation(Value value);
	
	public Value createValue(T object);

	public T createRepresentation(AttributeValue attribute);
	
	public AttributeValue createAttributeValue(T object);

	public T createRepresentation(ValueDouble value);
	
	public ValueDouble createValueDouble(T object);

	public T createRepresentation(ValueString value);
	
	public ValueString createValueString(T object);

	public T createRepresentation(ValueInteger value);
	
	public ValueInteger createValueInteger(T object);

	public T createRepresentation(ValuePeriod value);
	
	public ValuePeriod createValuePeriod(T object);
	
	public T createRepresentation(ValueUri value);
	
	public ValueUri createValueUri(T object);

	public T createRepresentation(AttributeUri attribute);
	
	public AttributeUri createAttributeUri(T object);

	public T createRepresentation(AttributeTemporalLocation attribute);
	
	public AttributeTemporalLocation createAttributeTemporalLocation(T object);

	public T createRepresentation(AttributeSpatialLocation attribute);
	
	public AttributeSpatialLocation createAttributeSpatialLocation(T object);

}
