/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.json;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Operation;
import fi.uef.envi.wavellite.entity.core.Operator;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialGeometry;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryLineString;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.ComponentSpecification;
import fi.uef.envi.wavellite.entity.derivation.DataStructureDefinition;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueInteger;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueSpatialLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueString;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueUri;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.Stimulus;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.Value;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ValueInteger;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.ValuePeriod;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ValueUri;
import fi.uef.envi.wavellite.representation.core.AbstractEntityRepresentation;

/**
 * <p>
 * Title: EntityRepresentationJson
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public abstract class EntityRepresentationJson extends
		AbstractEntityRepresentation<JsonNode> {

	protected static final ObjectMapper mapper = new ObjectMapper();

	@Override
	public JsonNode createRepresentation(Operation operation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [operation = " + operation + "]");
	}

	@Override
	public JsonNode createRepresentation(Operator operator) {
		throw new UnsupportedOperationException(
				"Cannot create representation [operator = " + operator + "]");
	}

	@Override
	public JsonNode createRepresentation(Sensor sensor) {
		throw new UnsupportedOperationException(
				"Cannot create representation [sensor = " + sensor + "]");
	}

	@Override
	public Sensor createSensor(JsonNode node) {
		throw new UnsupportedOperationException("Cannot create sensor [node = "
				+ node + "]");
	}

	@Override
	public JsonNode createRepresentation(Stimulus sensing) {
		throw new UnsupportedOperationException(
				"Cannot create representation [sensing = " + sensing + "]");
	}

	@Override
	public JsonNode createRepresentation(Property property) {
		throw new UnsupportedOperationException(
				"Cannot create representation [property = " + property + "]");
	}

	@Override
	public Property createProperty(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create property [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(Feature feature) {
		throw new UnsupportedOperationException(
				"Cannot create representation [feature = " + feature + "]");
	}

	@Override
	public Feature createFeature(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create feature [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(SensorObservation observation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [observation = " + observation
						+ "]");
	}

	@Override
	public SensorObservation createSensorObservation(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create sensor observation [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(SensorOutput output) {
		throw new UnsupportedOperationException(
				"Cannot create representation [output = " + output + "]");
	}

	@Override
	public SensorOutput createSensorOutput(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create sensor output [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ObservationValue value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ObservationValue createObservationValue(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create observation value [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ObservationValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ObservationValueDouble createObservationValueDouble(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create observation value double [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(TemporalLocation location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocation createTemporalLocation(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(TemporalLocationDateTime location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocationDateTime createTemporalLocationDateTime(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location date time [node = " + node
						+ "]");
	}

	@Override
	public JsonNode createRepresentation(TemporalLocationInterval location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocationInterval createTemporalLocationInterval(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location interval [node = " + node
						+ "]");
	}

	@Override
	public JsonNode createRepresentation(SpatialLocation location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocation createSpatialLocation(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(SpatialLocationPlace location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocationPlace createSpatialLocationPlace(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location place [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(SpatialLocationRegion location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocationRegion createSpatialLocationRegion(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location region [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(SpatialGeometry geometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + geometry + "]");
	}

	@Override
	public SpatialGeometry createSpatialGeometry(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(SpatialGeometryPoint geometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + geometry + "]");
	}

	@Override
	public SpatialGeometryPoint createSpatialGeometryPoint(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry point [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(SpatialGeometryPolygon geometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + geometry + "]");
	}

	@Override
	public SpatialGeometryPolygon createSpatialGeometryPolygon(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry polygon [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(SpatialGeometryLineString geometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + geometry + "]");
	}

	@Override
	public SpatialGeometryLineString createSpatialGeometryLineString(
			JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry line string [node = " + node
						+ "]");
	}

	@Override
	public JsonNode createRepresentation(DatasetObservation observation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [observation = " + observation
						+ "]");
	}

	@Override
	public DatasetObservation createDatasetObservation(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create representation [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(Dataset dataset) {
		throw new UnsupportedOperationException(
				"Cannot create representation [dataset = " + dataset + "]");
	}

	@Override
	public Dataset createDataset(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create dataset [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(DataStructureDefinition definition) {
		throw new UnsupportedOperationException(
				"Cannot create representation [definition = " + definition
						+ "]");
	}

	@Override
	public JsonNode createRepresentation(ComponentSpecification specification) {
		throw new UnsupportedOperationException(
				"Cannot create representation [specification = "
						+ specification + "]");
	}

	@Override
	public JsonNode createRepresentation(Component component) {
		throw new UnsupportedOperationException(
				"Cannot create representation [component = " + component + "]");
	}

	@Override
	public Component createComponent(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create component [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ComponentProperty property) {
		throw new UnsupportedOperationException(
				"Cannot create representation [property = " + property + "]");
	}

	@Override
	public ComponentProperty createComponentProperty(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create component property [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ComponentPropertyValue value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValue createComponentPropertyValue(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create representation [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ComponentPropertyValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueDouble createComponentPropertyValueDouble(
			JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create representation [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ComponentPropertyValueInteger value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueInteger createComponentPropertyValueInteger(
			JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create representation [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ComponentPropertyValueString value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueString createComponentPropertyValueString(
			JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create component property value string [node = " + node
						+ "]");
	}

	@Override
	public JsonNode createRepresentation(
			ComponentPropertyValueTemporalLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueTemporalLocation createComponentPropertyValueTemporalLocation(
			JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create representation [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(
			ComponentPropertyValueSpatialLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueSpatialLocation createComponentPropertyValueSpatialLocation(
			JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create component property value spatial location [node = "
						+ node + "]");
	}

	@Override
	public JsonNode createRepresentation(ComponentPropertyValueUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueUri createComponentPropertyValueUri(
			JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create component property value uri [node = " + node
						+ "]");
	}

	@Override
	public JsonNode createRepresentation(Situation situation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [situation = " + situation + "]");
	}

	@Override
	public Situation createSituation(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create situation [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ElementaryInfon infon) {
		throw new UnsupportedOperationException(
				"Cannot create representation [infon = " + infon + "]");
	}

	@Override
	public ElementaryInfon createElementaryInfon(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create elementary infon [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(Relation relation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [relation = " + relation + "]");
	}

	@Override
	public Relation createRelation(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create relation [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(RelevantObject object) {
		throw new UnsupportedOperationException(
				"Cannot create representation [object = " + object + "]");
	}

	@Override
	public RelevantObject createRelevantObject(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create relevant object [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(Polarity polarity) {
		throw new UnsupportedOperationException(
				"Cannot create representation [polarity = " + polarity + "]");
	}

	@Override
	public Polarity createPolarity(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create polarity [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(RelevantIndividual individual) {
		throw new UnsupportedOperationException(
				"Cannot create representation [individual = " + individual
						+ "]");
	}

	@Override
	public RelevantIndividual createRelevantIndividual(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create relevant individual [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(Attribute attribute) {
		throw new UnsupportedOperationException(
				"Cannot create representation [attribute = " + attribute + "]");
	}

	@Override
	public Attribute createAttribute(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create attribute [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(AttributeValue attribute) {
		throw new UnsupportedOperationException(
				"Cannot create representation [attribute = " + attribute + "]");
	}

	@Override
	public AttributeValue createAttributeValue(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create attribute value [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(Value value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public Value createValue(JsonNode node) {
		throw new UnsupportedOperationException("Cannot create value [node = "
				+ node + "]");
	}

	@Override
	public JsonNode createRepresentation(ValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueDouble createValueDouble(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create value double [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ValueString value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueString createValueString(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create value string [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ValueInteger value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueInteger createValueInteger(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create value integer [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ValuePeriod value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValuePeriod createValuePeriod(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create value period [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(ValueUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueUri createValueUri(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create value period [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(AttributeUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeUri createAttributeUri(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create attribute uri [node = " + node + "]");
	}

	@Override
	public JsonNode createRepresentation(AttributeTemporalLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeTemporalLocation createAttributeTemporalLocation(
			JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create attribute temporal location [node = " + node
						+ "]");
	}

	@Override
	public JsonNode createRepresentation(AttributeSpatialLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeSpatialLocation createAttributeSpatialLocation(JsonNode node) {
		throw new UnsupportedOperationException(
				"Cannot create attribute spatial location [node = " + node
						+ "]");
	}

}
