/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.json;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.ObjectNode;

import fi.uef.envi.wavellite.entity.core.SpatialGeometry;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.SpatialLocationVisitor;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryLineString;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;

/**
 * <p>
 * Title: EntityRepresentationJsonGeo
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationJsonGeo extends EntityRepresentationJson {

	private SpatialLocationVisitor spatialLocationVisitor;
	private JsonNode spatialLocationN;

	public EntityRepresentationJsonGeo() {
		this.spatialLocationVisitor = new ThisSpatialLocationVisitor();
	}

	@Override
	public JsonNode createRepresentation(SpatialLocation location) {
		location.accept(spatialLocationVisitor);

		return spatialLocationN;
	}

	@Override
	public JsonNode createRepresentation(SpatialLocationRegion region) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", region.getId());
		ret.put("type", region.getType());
		ret.put("class", region.getClass().getName());
		ret.put("geometry", createRepresentation(region.getSpatialGeometry()));

		return ret;
	}

	@Override
	public JsonNode createRepresentation(SpatialGeometry geometry) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", geometry.getId());
		ret.put("type", geometry.getType());
		ret.put("class", geometry.getClass().getName());
		ret.put("wkt", geometry.getValueAsWKT());

		return ret;
	}

	@Override
	public JsonNode createRepresentation(SpatialGeometryPoint geometry) {
		return createRepresentation((SpatialGeometry)geometry);
	}
	
	@Override
	public JsonNode createRepresentation(SpatialGeometryLineString geometry) {
		return createRepresentation((SpatialGeometry)geometry);
	}
	
	@Override
	public JsonNode createRepresentation(SpatialGeometryPolygon geometry) {
		return createRepresentation((SpatialGeometry)geometry);
	}

	private class ThisSpatialLocationVisitor implements SpatialLocationVisitor {

		@Override
		public void visit(SpatialLocationPlace location) {
			spatialLocationN = createRepresentation(location);
		}

		@Override
		public void visit(SpatialLocationRegion location) {
			spatialLocationN = createRepresentation(location);
		}

	}

}
