/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.json;

import java.util.Set;

import org.joda.time.format.ISOPeriodFormat;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.ArrayNode;
import com.fasterxml.jackson.databind.node.ObjectNode;

import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.AttributeVisitor;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.RelevantObjectVisitor;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.Value;
import fi.uef.envi.wavellite.entity.situation.ValueVisitor;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ValueInteger;
import fi.uef.envi.wavellite.entity.situation.base.ValuePeriod;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.entity.situation.base.ValueUri;

/**
 * <p>
 * Title: EntityRepresentationJsonSto
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project:
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationJsonSto extends EntityRepresentationJson {

	private RelevantObjectVisitor relevantObjectVisitor;
	private AttributeVisitor attributeVisitor;
	private ValueVisitor valueVisitor;
	private JsonNode relevantObjectN, attributeN, valueN;
	private EntityRepresentationJsonGeo entityRepresentationJsonGeo;
	private EntityRepresentationJsonTime entityRepresentationJsonTime;

	public EntityRepresentationJsonSto() {
		this.relevantObjectVisitor = new ThisRelevantObjectVisitor();
		this.attributeVisitor = new ThisAttributeVisitor();
		this.valueVisitor = new ThisValueVisitor();
		this.entityRepresentationJsonGeo = new EntityRepresentationJsonGeo();
		this.entityRepresentationJsonTime = new EntityRepresentationJsonTime();
	}

	@Override
	public JsonNode createRepresentation(Situation situation) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", situation.getId());
		ret.put("type", situation.getType());
		ret.put("class", situation.getClass().getName());

		if (situation.getSupportedInfons().isEmpty())
			return ret;

		ArrayNode supportedInfonsN = mapper.createArrayNode();
		ret.put("supportedInfons", supportedInfonsN);

		for (ElementaryInfon infon : situation.getSupportedInfons()) {
			supportedInfonsN.add(createRepresentation(infon));
		}

		return ret;
	}

	@Override
	public JsonNode createRepresentation(ElementaryInfon infon) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", infon.getId());
		ret.put("type", infon.getType());
		ret.put("class", infon.getClass().getName());

		if (infon.getRelation() != null)
			ret.put("relation", createRepresentation(infon.getRelation()));

		if (!infon.getRelevantObjects().isEmpty()) {
			ArrayNode objectsN = mapper.createArrayNode();
			ret.put("objects", objectsN);

			for (RelevantObject object : infon.getRelevantObjects()) {
				objectsN.add(createRepresentation(object));
			}
		}

		if (infon.getPolarity() != null)
			ret.put("polarity", infon.getPolarity().value());

		return ret;
	}

	@Override
	public JsonNode createRepresentation(Relation relation) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", relation.getId());
		ret.put("type", relation.getType());
		ret.put("class", relation.getClass().getName());

		return ret;
	}

	@Override
	public JsonNode createRepresentation(RelevantObject object) {
		object.accept(relevantObjectVisitor);

		return relevantObjectN;
	}

	@Override
	public JsonNode createRepresentation(RelevantIndividual individual) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", individual.getId());
		ret.put("type", individual.getType());
		ret.put("class", individual.getClass().getName());

		Set<Attribute> attributes = individual.getAttributes();

		if (attributes == null)
			return ret;

		if (attributes.isEmpty())
			return ret;

		ArrayNode attributesA = mapper.createArrayNode();

		ret.put("attributes", attributesA);

		for (Attribute attribute : attributes) {
			attributesA.add(createRepresentation(attribute));
		}

		return ret;
	}

	@Override
	public JsonNode createRepresentation(Attribute attribute) {
		attribute.accept(attributeVisitor);

		return attributeN;
	}

	@Override
	public JsonNode createRepresentation(AttributeValue attribute) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", attribute.getId());
		ret.put("type", attribute.getType());
		ret.put("class", attribute.getClass().getName());

		Value value = attribute.getValue();

		if (value == null)
			return ret;

		ret.put("value", createRepresentation(value));

		return ret;
	}

	@Override
	public JsonNode createRepresentation(AttributeSpatialLocation location) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", location.getId());
		ret.put("type", location.getType());
		ret.put("class", location.getClass().getName());
		ret.put("value", entityRepresentationJsonGeo
				.createRepresentation(location.getValue()));

		return ret;
	}

	@Override
	public JsonNode createRepresentation(AttributeTemporalLocation location) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", location.getId());
		ret.put("type", location.getType());
		ret.put("class", location.getClass().getName());
		ret.put("value", entityRepresentationJsonTime
				.createRepresentation(location.getValue()));

		return ret;
	}

	@Override
	public JsonNode createRepresentation(Value value) {
		value.accept(valueVisitor);

		return valueN;
	}

	@Override
	public JsonNode createRepresentation(ValueString value) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", value.getId());
		ret.put("type", value.getType());
		ret.put("class", value.getClass().getName());
		ret.put("value", value.getValue());

		return ret;
	}

	@Override
	public JsonNode createRepresentation(ValueInteger value) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", value.getId());
		ret.put("type", value.getType());
		ret.put("class", value.getClass().getName());
		ret.put("value", value.getValue());

		return ret;
	}

	@Override
	public JsonNode createRepresentation(ValueDouble value) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", value.getId());
		ret.put("type", value.getType());
		ret.put("class", value.getClass().getName());
		ret.put("value", value.getValue());

		return ret;
	}

	@Override
	public JsonNode createRepresentation(ValuePeriod value) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", value.getId());
		ret.put("type", value.getType());
		ret.put("class", value.getClass().getName());
		ret.put("value", ISOPeriodFormat.standard().print(value.getValue()));

		return ret;
	}

	@Override
	public JsonNode createRepresentation(AttributeUri value) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", value.getId());
		ret.put("type", value.getType());
		ret.put("class", value.getClass().getName());
		ret.put("value", value.getValue().stringValue());

		return ret;
	}

	private class ThisRelevantObjectVisitor implements RelevantObjectVisitor {

		@Override
		public void visit(RelevantIndividual object) {
			relevantObjectN = createRepresentation(object);
		}

		@Override
		public void visit(AttributeSpatialLocation object) {
			relevantObjectN = createRepresentation(object);
		}

		@Override
		public void visit(AttributeTemporalLocation object) {
			relevantObjectN = createRepresentation(object);
		}

		@Override
		public void visit(ValueDouble object) {
			relevantObjectN = createRepresentation(object);
		}

		@Override
		public void visit(ValueInteger object) {
			relevantObjectN = createRepresentation(object);
		}

		@Override
		public void visit(ValuePeriod object) {
			relevantObjectN = createRepresentation(object);
		}

		@Override
		public void visit(ValueString object) {
			relevantObjectN = createRepresentation(object);
		}

		@Override
		public void visit(AttributeUri object) {
			relevantObjectN = createRepresentation(object);
		}

		@Override
		public void visit(ValueUri object) {
			relevantObjectN = createRepresentation(object);
		}

	}

	private class ThisAttributeVisitor implements AttributeVisitor {

		@Override
		public void visit(AttributeValue attribute) {
			attributeN = createRepresentation(attribute);
		}

		@Override
		public void visit(AttributeSpatialLocation attribute) {
			attributeN = createRepresentation(attribute);
		}

		@Override
		public void visit(AttributeTemporalLocation attribute) {
			attributeN = createRepresentation(attribute);
		}

		@Override
		public void visit(AttributeUri attribute) {
			attributeN = createRepresentation(attribute);
		}

	}

	private class ThisValueVisitor implements ValueVisitor {

		@Override
		public void visit(ValueDouble value) {
			valueN = createRepresentation(value);
		}

		@Override
		public void visit(ValueString value) {
			valueN = createRepresentation(value);
		}

		@Override
		public void visit(ValueUri value) {
			valueN = createRepresentation(value);
		}

		@Override
		public void visit(ValueInteger value) {
			valueN = createRepresentation(value);
		}

		@Override
		public void visit(ValuePeriod value) {
			valueN = createRepresentation(value);
		}

	}

}
