/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.json;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.ObjectNode;

import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocationVisitor;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;

/**
 * <p>
 * Title: EntityRepresentationJsonTime
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationJsonTime extends EntityRepresentationJson {

	private TemporalLocationVisitor temporalLocationVisitor;
	private JsonNode temporalLocationN;
	private static final DateTimeFormatter dtf1 = ISODateTimeFormat.dateTime()
			.withOffsetParsed();

	public EntityRepresentationJsonTime() {
		temporalLocationVisitor = new ThisTemporalLocationVisitor();
	}

	@Override
	public JsonNode createRepresentation(TemporalLocation location) {
		location.accept(temporalLocationVisitor);

		return temporalLocationN;
	}

	@Override
	public JsonNode createRepresentation(TemporalLocationDateTime time) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", time.getId());
		ret.put("type", time.getType());
		ret.put("class", time.getClass().getName());
		ret.put("value", dtf1.print(time.getValue()));

		return ret;
	}

	@Override
	public JsonNode createRepresentation(TemporalLocationInterval interval) {
		ObjectNode ret = mapper.createObjectNode();

		ret.put("id", interval.getId());
		ret.put("type", interval.getType());
		ret.put("class", interval.getClass().getName());
		ret.put("value", dtf1.print(interval.getValue().getStart()) + "/"
				+ dtf1.print(interval.getValue().getEnd()));

		return ret;
	}

	private class ThisTemporalLocationVisitor implements
			TemporalLocationVisitor {

		@Override
		public void visit(TemporalLocationDateTime time) {
			temporalLocationN = createRepresentation(time);
		}

		@Override
		public void visit(TemporalLocationInterval interval) {
			temporalLocationN = createRepresentation(interval);
		}

	}

}
