/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.rdf;

import java.util.Set;

import org.openrdf.model.Literal;
import org.openrdf.model.Statement;
import org.openrdf.model.URI;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Operation;
import fi.uef.envi.wavellite.entity.core.Operator;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialGeometry;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryLineString;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.ComponentSpecification;
import fi.uef.envi.wavellite.entity.derivation.DataStructureDefinition;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueInteger;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueSpatialLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueString;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueUri;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.Stimulus;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.Value;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ValueInteger;
import fi.uef.envi.wavellite.entity.situation.base.ValuePeriod;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ValueUri;
import fi.uef.envi.wavellite.representation.core.AbstractEntityRepresentation;
import fi.uef.envi.wavellite.vocabulary.WO;

/**
 * <p>
 * Title: EntityRepresentationRdf
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public abstract class EntityRepresentationRdf extends
		AbstractEntityRepresentation<Set<Statement>> {

	protected static final ValueFactory f = ValueFactoryImpl.getInstance();

	private String ns;

	public EntityRepresentationRdf() {
		this(null);
	}

	public EntityRepresentationRdf(String ns) {
		if (ns == null)
			ns = WO.ns;

		this.ns = ns;
	}

	public void setNamespace(String ns) {
		if (ns == null)
			ns = WO.ns;

		this.ns = ns;
	}

	@Override
	public Set<Statement> createRepresentation(Operator operator) {
		throw new UnsupportedOperationException(
				"Cannot create representation [operator = " + operator + "]");
	}
	
	@Override
	public Set<Statement> createRepresentation(Operation operation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [operation = " + operation + "]");
	}
	
	@Override
	public Set<Statement> createRepresentation(Sensor sensor) {
		throw new UnsupportedOperationException(
				"Cannot create representation [sensor = " + sensor + "]");
	}

	@Override
	public Sensor createSensor(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create sensor [statements = " + statements + "]");
	}
	
	@Override
	public Set<Statement> createRepresentation(Stimulus sensing) {
		throw new UnsupportedOperationException(
				"Cannot create representation [sensing = " + sensing + "]");
	}

	@Override
	public Set<Statement> createRepresentation(Property property) {
		throw new UnsupportedOperationException(
				"Cannot create representation [property = " + property + "]");
	}

	@Override
	public Property createProperty(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create property [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(Feature feature) {
		throw new UnsupportedOperationException(
				"Cannot create representation [feature = " + feature + "]");
	}

	@Override
	public Feature createFeature(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create feature [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(SensorObservation observation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [observation = " + observation
						+ "]");
	}

	@Override
	public SensorObservation createSensorObservation(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create sensor observation [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(SensorOutput output) {
		throw new UnsupportedOperationException(
				"Cannot create representation [output = " + output + "]");
	}

	@Override
	public SensorOutput createSensorOutput(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create sensor output [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(ObservationValue value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ObservationValue createObservationValue(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create observation value [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(ObservationValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ObservationValueDouble createObservationValueDouble(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create observation value double [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(TemporalLocation location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocation createTemporalLocation(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(TemporalLocationDateTime location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocationDateTime createTemporalLocationDateTime(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location date time [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(TemporalLocationInterval location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocationInterval createTemporalLocationInterval(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location interval [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(SpatialLocation location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocation createSpatialLocation(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(SpatialLocationPlace location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocationPlace createSpatialLocationPlace(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location place [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(SpatialLocationRegion location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocationRegion createSpatialLocationRegion(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location region [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(SpatialGeometry spatialGeometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [spatialGeometry = "
						+ spatialGeometry + "]");
	}

	@Override
	public SpatialGeometry createSpatialGeometry(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			SpatialGeometryPoint spatialGeometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [spatialGeometry = "
						+ spatialGeometry + "]");
	}

	@Override
	public SpatialGeometryPoint createSpatialGeometryPoint(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry point [statement = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			SpatialGeometryPolygon spatialGeometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [spatialGeometry = "
						+ spatialGeometry + "]");
	}

	@Override
	public SpatialGeometryPolygon createSpatialGeometryPolygon(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry polygon [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			SpatialGeometryLineString spatialGeometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [spatialGeometry = "
						+ spatialGeometry + "]");
	}

	@Override
	public SpatialGeometryLineString createSpatialGeometryLineString(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry line string [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(DatasetObservation observation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [observation = " + observation
						+ "]");
	}

	@Override
	public DatasetObservation createDatasetObservation(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create representation [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(Dataset dataset) {
		throw new UnsupportedOperationException(
				"Cannot create representation [dataset = " + dataset + "]");
	}

	@Override
	public Dataset createDataset(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create dataset [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			DataStructureDefinition definition) {
		throw new UnsupportedOperationException(
				"Cannot create representation [definition = " + definition
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			ComponentSpecification specification) {
		throw new UnsupportedOperationException(
				"Cannot create representation [specification = "
						+ specification + "]");
	}

	@Override
	public Set<Statement> createRepresentation(Component component) {
		throw new UnsupportedOperationException(
				"Cannot create representation [component = " + component + "]");
	}

	@Override
	public Component createComponent(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create component [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(ComponentProperty property) {
		throw new UnsupportedOperationException(
				"Cannot create representation [property = " + property + "]");
	}

	@Override
	public ComponentProperty createComponentProperty(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create component property [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(ComponentPropertyValue value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValue createComponentPropertyValue(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create representation [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			ComponentPropertyValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueDouble createComponentPropertyValueDouble(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create representation [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			ComponentPropertyValueInteger value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueInteger createComponentPropertyValueInteger(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create representation [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			ComponentPropertyValueString value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueString createComponentPropertyValueString(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create component property value string [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			ComponentPropertyValueTemporalLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueTemporalLocation createComponentPropertyValueTemporalLocation(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create representation [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(
			ComponentPropertyValueSpatialLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueSpatialLocation createComponentPropertyValueSpatialLocation(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create component property value spatial location [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(ComponentPropertyValueUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueUri createComponentPropertyValueUri(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create component property value uri [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(Situation situation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [situation = " + situation + "]");
	}

	@Override
	public Situation createSituation(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create situation [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(ElementaryInfon infon) {
		throw new UnsupportedOperationException(
				"Cannot create representation [infon = " + infon + "]");
	}

	@Override
	public ElementaryInfon createElementaryInfon(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create elementary infon [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(Relation relation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [relation = " + relation + "]");
	}

	@Override
	public Relation createRelation(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create relation [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(RelevantObject object) {
		throw new UnsupportedOperationException(
				"Cannot create representation [object = " + object + "]");
	}

	@Override
	public RelevantObject createRelevantObject(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create relevant object [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(Polarity polarity) {
		throw new UnsupportedOperationException(
				"Cannot create representation [polarity = " + polarity + "]");
	}

	@Override
	public Polarity createPolarity(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create polarity [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(RelevantIndividual individual) {
		throw new UnsupportedOperationException(
				"Cannot create representation [individual = " + individual
						+ "]");
	}

	@Override
	public RelevantIndividual createRelevantIndividual(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create relevant individual [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(Attribute attribute) {
		throw new UnsupportedOperationException(
				"Cannot create representation [attribute = " + attribute + "]");
	}

	@Override
	public Attribute createAttribute(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create attribute [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(Value value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public Value createValue(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create value [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(AttributeValue attribute) {
		throw new UnsupportedOperationException(
				"Cannot create representation [attribute = " + attribute + "]");
	}

	@Override
	public AttributeValue createAttributeValue(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create attribute value [statements = " + statements
						+ "]");
	}

	@Override
	public Set<Statement> createRepresentation(ValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueDouble createValueDouble(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create value double [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(ValueString value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueString createValueString(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create value string [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(ValueInteger value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueInteger createValueInteger(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create value integer [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(ValuePeriod value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValuePeriod createValuePeriod(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create value period [statements = " + statements + "]");
	}
	
	@Override
	public Set<Statement> createRepresentation(ValueUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueUri createValueUri(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create value period [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(AttributeUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeUri createAttributeUri(Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create attribute uri [statements = " + statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(AttributeTemporalLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeTemporalLocation createAttributeTemporalLocation(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create attribute temporal location [statements = "
						+ statements + "]");
	}

	@Override
	public Set<Statement> createRepresentation(AttributeSpatialLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeSpatialLocation createAttributeSpatialLocation(
			Set<Statement> statements) {
		throw new UnsupportedOperationException(
				"Cannot create attribute spatial location [statements = "
						+ statements + "]");
	}

	protected URI _uri(String s) {
		// Apparently this is the check Sesame does
		// See http://www.openrdf.org/forum/mvnforum/viewthread?thread=2229
		if (s.contains(":"))
			return f.createURI(s);

		if (ns.endsWith("#") && s.startsWith("#"))
			return f.createURI(ns + s.substring(1, s.length()));

		if (ns.endsWith("#") || s.startsWith("#"))
			return f.createURI(ns + s);

		return f.createURI(ns + "#" + s);
	}

	protected Literal _typedLiteral(String label, URI datatype) {
		return f.createLiteral(label, datatype);
	}

	protected Literal _literal(String value) {
		return f.createLiteral(value);
	}

	protected Statement _statement(URI s, URI p, URI o) {
		return f.createStatement(s, p, o);
	}

	protected Statement _statement(URI s, URI p, Literal o) {
		return f.createStatement(s, p, o);
	}

	protected void getStatementsMatchingSubject(String id,
			Set<Statement> statements, Set<Statement> result) {
		for (Statement statement : statements) {
			if (statement.getSubject().stringValue().equals(id))
				result.add(statement);
		}
	}

	protected static void getTransitiveStatementsMatchingSubjectAndPredicate(
			String id, Set<Statement> statements, Set<Statement> result) {
		getTransitiveStatementsMatchingSubject(id, statements, result);

		for (Statement statement : statements) {
			if (statement.getPredicate().stringValue().equals(id)) {
				result.add(statement);
				if (statement.getObject() instanceof URI)
					getTransitiveStatementsMatchingSubjectAndPredicate(
							statement.getObject().stringValue(), statements,
							result);
			}
		}
	}

	protected static void getTransitiveStatementsMatchingSubject(String id,
			Set<Statement> statements, Set<Statement> result) {
		for (Statement statement : statements) {
			if (statement.getSubject().stringValue().equals(id)) {
				result.add(statement);
				if (statement.getObject() instanceof URI)
					getTransitiveStatementsMatchingSubject(statement
							.getObject().stringValue(), statements, result);
			}
		}
	}

}
