/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.text;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Operation;
import fi.uef.envi.wavellite.entity.core.Operator;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialGeometry;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryLineString;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.derivation.Component;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentPropertyValue;
import fi.uef.envi.wavellite.entity.derivation.ComponentSpecification;
import fi.uef.envi.wavellite.entity.derivation.DataStructureDefinition;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueInteger;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueSpatialLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueString;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueUri;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.Stimulus;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.Value;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ValueInteger;
import fi.uef.envi.wavellite.entity.situation.base.ValuePeriod;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.entity.situation.base.ValueUri;
import fi.uef.envi.wavellite.representation.core.AbstractEntityRepresentation;

/**
 * <p>
 * Title: EntityRepresentationText
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public abstract class EntityRepresentationText extends
		AbstractEntityRepresentation<String> {

	@Override
	public String createRepresentation(Operator operator) {
		throw new UnsupportedOperationException(
				"Cannot create representation [operator = " + operator + "]");
	}

	@Override
	public String createRepresentation(Operation operation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [operation = " + operation + "]");
	}

	@Override
	public String createRepresentation(Sensor sensor) {
		throw new UnsupportedOperationException(
				"Cannot create representation [sensor = " + sensor + "]");
	}

	@Override
	public Sensor createSensor(String string) {
		throw new UnsupportedOperationException(
				"Cannot create sensor [string = " + string + "]");
	}

	@Override
	public String createRepresentation(Stimulus sensing) {
		throw new UnsupportedOperationException(
				"Cannot create representation [sensing = " + sensing + "]");
	}

	@Override
	public String createRepresentation(Property property) {
		throw new UnsupportedOperationException(
				"Cannot create representation [property = " + property + "]");
	}

	@Override
	public Property createProperty(String string) {
		throw new UnsupportedOperationException(
				"Cannot create property [string = " + string + "]");
	}

	@Override
	public String createRepresentation(Feature feature) {
		throw new UnsupportedOperationException(
				"Cannot create representation [feature = " + feature + "]");
	}

	@Override
	public Feature createFeature(String string) {
		throw new UnsupportedOperationException(
				"Cannot create feature [string = " + string + "]");
	}

	@Override
	public String createRepresentation(SensorObservation observation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [observation = " + observation
						+ "]");
	}

	@Override
	public SensorObservation createSensorObservation(String string) {
		throw new UnsupportedOperationException(
				"Cannot create sensor observation [string = " + string + "]");
	}

	@Override
	public String createRepresentation(SensorOutput output) {
		throw new UnsupportedOperationException(
				"Cannot create representation [output = " + output + "]");
	}

	@Override
	public SensorOutput createSensorOutput(String string) {
		throw new UnsupportedOperationException(
				"Cannot create sensor output [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ObservationValue value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ObservationValue createObservationValue(String string) {
		throw new UnsupportedOperationException(
				"Cannot create observation value [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ObservationValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ObservationValueDouble createObservationValueDouble(String string) {
		throw new UnsupportedOperationException(
				"Cannot create observation value double [string = " + string
						+ "]");
	}

	@Override
	public String createRepresentation(TemporalLocation location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocation createTemporalLocation(String string) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location [string = " + string + "]");
	}

	@Override
	public String createRepresentation(TemporalLocationDateTime location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocationDateTime createTemporalLocationDateTime(String string) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location date time [string = " + string
						+ "]");
	}

	@Override
	public String createRepresentation(TemporalLocationInterval location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public TemporalLocationInterval createTemporalLocationInterval(String string) {
		throw new UnsupportedOperationException(
				"Cannot create temporal location interval [string = " + string
						+ "]");
	}

	@Override
	public String createRepresentation(SpatialLocation location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocation createSpatialLocation(String string) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location [string = " + string + "]");
	}

	@Override
	public String createRepresentation(SpatialLocationPlace location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocationPlace createSpatialLocationPlace(String string) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location place [string = " + string
						+ "]");
	}

	@Override
	public String createRepresentation(SpatialLocationRegion location) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + location + "]");
	}

	@Override
	public SpatialLocationRegion createSpatialLocationRegion(String string) {
		throw new UnsupportedOperationException(
				"Cannot create spatial location region [string = " + string
						+ "]");
	}

	@Override
	public String createRepresentation(SpatialGeometry geometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + geometry + "]");
	}

	@Override
	public SpatialGeometry createSpatialGeometry(String string) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry [string = " + string + "]");
	}

	@Override
	public String createRepresentation(SpatialGeometryPoint geometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + geometry + "]");
	}

	@Override
	public SpatialGeometryPoint createSpatialGeometryPoint(String string) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry point [string = " + string
						+ "]");
	}

	@Override
	public String createRepresentation(SpatialGeometryPolygon geometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + geometry + "]");
	}

	@Override
	public SpatialGeometryPolygon createSpatialGeometryPolygon(String string) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry polygon [string = " + string
						+ "]");
	}

	@Override
	public String createRepresentation(SpatialGeometryLineString geometry) {
		throw new UnsupportedOperationException(
				"Cannot create representation [location = " + geometry + "]");
	}

	@Override
	public SpatialGeometryLineString createSpatialGeometryLineString(
			String string) {
		throw new UnsupportedOperationException(
				"Cannot create spatial geometry line string [string = "
						+ string + "]");
	}

	@Override
	public String createRepresentation(DatasetObservation observation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [observation = " + observation
						+ "]");
	}

	@Override
	public DatasetObservation createDatasetObservation(String string) {
		throw new UnsupportedOperationException(
				"Cannot create dataset observation [string = " + string + "]");
	}

	@Override
	public String createRepresentation(Dataset dataset) {
		throw new UnsupportedOperationException(
				"Cannot create representation [dataset = " + dataset + "]");
	}

	@Override
	public Dataset createDataset(String string) {
		throw new UnsupportedOperationException(
				"Cannot create dataset [string = " + string + "]");
	}

	@Override
	public String createRepresentation(DataStructureDefinition definition) {
		throw new UnsupportedOperationException(
				"Cannot create representation [definition = " + definition
						+ "]");
	}

	@Override
	public String createRepresentation(ComponentSpecification specification) {
		throw new UnsupportedOperationException(
				"Cannot create representation [specification = "
						+ specification + "]");
	}

	@Override
	public String createRepresentation(Component component) {
		throw new UnsupportedOperationException(
				"Cannot create representation [component = " + component + "]");
	}

	@Override
	public Component createComponent(String string) {
		throw new UnsupportedOperationException(
				"Cannot create component [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ComponentProperty property) {
		throw new UnsupportedOperationException(
				"Cannot create representation [property = " + property + "]");
	}

	@Override
	public ComponentProperty createComponentProperty(String string) {
		throw new UnsupportedOperationException(
				"Cannot create component property [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ComponentPropertyValue value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValue createComponentPropertyValue(String string) {
		throw new UnsupportedOperationException(
				"Cannot create representation [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ComponentPropertyValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueDouble createComponentPropertyValueDouble(
			String string) {
		throw new UnsupportedOperationException(
				"Cannot create representation [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ComponentPropertyValueInteger value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueInteger createComponentPropertyValueInteger(
			String string) {
		throw new UnsupportedOperationException(
				"Cannot create representation [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ComponentPropertyValueString value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueString createComponentPropertyValueString(
			String string) {
		throw new UnsupportedOperationException(
				"Cannot create component property value string [string = "
						+ string + "]");
	}

	@Override
	public String createRepresentation(
			ComponentPropertyValueTemporalLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueTemporalLocation createComponentPropertyValueTemporalLocation(
			String string) {
		throw new UnsupportedOperationException(
				"Cannot create representation [string = " + string + "]");
	}

	@Override
	public String createRepresentation(
			ComponentPropertyValueSpatialLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueSpatialLocation createComponentPropertyValueSpatialLocation(
			String string) {
		throw new UnsupportedOperationException(
				"Cannot create component property value spatial location [string = "
						+ string + "]");
	}

	@Override
	public String createRepresentation(ComponentPropertyValueUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ComponentPropertyValueUri createComponentPropertyValueUri(
			String string) {
		throw new UnsupportedOperationException(
				"Cannot create component property value uri [string = "
						+ string + "]");
	}

	@Override
	public String createRepresentation(Situation situation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [situation = " + situation + "]");
	}

	@Override
	public Situation createSituation(String string) {
		throw new UnsupportedOperationException(
				"Cannot create situation [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ElementaryInfon infon) {
		throw new UnsupportedOperationException(
				"Cannot create representation [infon = " + infon + "]");
	}

	@Override
	public ElementaryInfon createElementaryInfon(String string) {
		throw new UnsupportedOperationException(
				"Cannot create elementary infon [string = " + string + "]");
	}

	@Override
	public String createRepresentation(Relation relation) {
		throw new UnsupportedOperationException(
				"Cannot create representation [relation = " + relation + "]");
	}

	@Override
	public Relation createRelation(String string) {
		throw new UnsupportedOperationException(
				"Cannot create relation [string = " + string + "]");
	}

	@Override
	public String createRepresentation(RelevantObject object) {
		throw new UnsupportedOperationException(
				"Cannot create representation [object = " + object + "]");
	}

	@Override
	public RelevantObject createRelevantObject(String string) {
		throw new UnsupportedOperationException(
				"Cannot create relevant object [string = " + string + "]");
	}

	@Override
	public String createRepresentation(Polarity polarity) {
		throw new UnsupportedOperationException(
				"Cannot create representation [polarity = " + polarity + "]");
	}

	@Override
	public Polarity createPolarity(String string) {
		throw new UnsupportedOperationException(
				"Cannot create polarity [string = " + string + "]");
	}

	@Override
	public String createRepresentation(RelevantIndividual individual) {
		throw new UnsupportedOperationException(
				"Cannot create representation [individual = " + individual
						+ "]");
	}

	@Override
	public RelevantIndividual createRelevantIndividual(String string) {
		throw new UnsupportedOperationException(
				"Cannot create relevant individual [string = " + string + "]");
	}

	@Override
	public String createRepresentation(Attribute attribute) {
		throw new UnsupportedOperationException(
				"Cannot create representation [attribute = " + attribute + "]");
	}

	@Override
	public Attribute createAttribute(String string) {
		throw new UnsupportedOperationException(
				"Cannot create attribute [string = " + string + "]");
	}

	@Override
	public String createRepresentation(AttributeValue attribute) {
		throw new UnsupportedOperationException(
				"Cannot create representation [attribute = " + attribute + "]");
	}

	@Override
	public AttributeValue createAttributeValue(String string) {
		throw new UnsupportedOperationException(
				"Cannot create attribute value [string = " + string + "]");
	}

	@Override
	public String createRepresentation(Value value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public Value createValue(String string) {
		throw new UnsupportedOperationException(
				"Cannot create value [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ValueDouble value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueDouble createValueDouble(String string) {
		throw new UnsupportedOperationException(
				"Cannot create value double [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ValueString value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueString createValueString(String string) {
		throw new UnsupportedOperationException(
				"Cannot create value string [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ValueInteger value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueInteger createValueInteger(String string) {
		throw new UnsupportedOperationException(
				"Cannot create value integer [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ValuePeriod value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValuePeriod createValuePeriod(String string) {
		throw new UnsupportedOperationException(
				"Cannot create value period [string = " + string + "]");
	}

	@Override
	public String createRepresentation(ValueUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public ValueUri createValueUri(String string) {
		throw new UnsupportedOperationException(
				"Cannot create value period [string = " + string + "]");
	}

	@Override
	public String createRepresentation(AttributeUri value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeUri createAttributeUri(String string) {
		throw new UnsupportedOperationException(
				"Cannot create attribute uri [string = " + string + "]");
	}

	@Override
	public String createRepresentation(AttributeTemporalLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeTemporalLocation createAttributeTemporalLocation(
			String string) {
		throw new UnsupportedOperationException(
				"Cannot create attribute temporal location [string = " + string
						+ "]");
	}

	@Override
	public String createRepresentation(AttributeSpatialLocation value) {
		throw new UnsupportedOperationException(
				"Cannot create representation [value = " + value + "]");
	}

	@Override
	public AttributeSpatialLocation createAttributeSpatialLocation(String string) {
		throw new UnsupportedOperationException(
				"Cannot create attribute spatial location [string = " + string
						+ "]");
	}

}
