/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.text;

import java.util.logging.Level;
import java.util.logging.Logger;

import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.RelevantObjectVisitor;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ValueInteger;
import fi.uef.envi.wavellite.entity.situation.base.ValuePeriod;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.entity.situation.base.ValueUri;

/**
 * <p>
 * Title: EntityRepresentationTextSto
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationTextSto extends EntityRepresentationText {

	private static final String NL = System.getProperty("line.separator");

	private String representation;

	private RelevantObjectVisitor relevantObjectVisitor = new ThisRelevantObjectVisitor();
	private EntityRepresentationTextGeo entityRepresentationGeo = new EntityRepresentationTextGeo();
	private EntityRepresentationTextTime entityRepresentationTime = new EntityRepresentationTextTime();

	private static final Logger log = Logger
			.getLogger(EntityRepresentationTextSto.class.getName());

	@Override
	public String createRepresentation(Situation situation) {
		StringBuffer sb = new StringBuffer();

		for (ElementaryInfon infon : situation.getSupportedInfons()) {
			sb.append(situation.getId() + " |= " + createRepresentation(infon)
					+ NL);
		}

		return sb.toString();
	}

	@Override
	public String createRepresentation(ElementaryInfon infon) {
		StringBuffer sb = new StringBuffer();

		sb.append("<<");

		Relation relation = infon.getRelation();

		if (relation == null) {
			if (log.isLoggable(Level.WARNING))
				log.warning("[relation = null]");
		} else {
			sb.append(relation.getId());
		}

		for (RelevantObject object : infon.getRelevantObjects()) {
			sb.append(", " + createRepresentation(object));
		}

		if (infon.getPolarity().equals(Polarity.True))
			sb.append(", 1");
		else
			sb.append(", 0");

		sb.append(">>");

		return sb.toString();
	}

	@Override
	public String createRepresentation(RelevantObject object) {
		object.accept(relevantObjectVisitor);

		return representation;
	}

	@Override
	public String createRepresentation(RelevantIndividual individual) {
		return individual.getId();
	}

	@Override
	public String createRepresentation(AttributeSpatialLocation location) {
		return entityRepresentationGeo
				.createRepresentation(location.getValue());
	}

	@Override
	public String createRepresentation(AttributeTemporalLocation location) {
		return entityRepresentationTime.createRepresentation(location
				.getValue());
	}

	@Override
	public String createRepresentation(ValueDouble value) {
		return value.getValue().toString();
	}

	@Override
	public String createRepresentation(ValueInteger value) {
		return value.getValue().toString();
	}

	@Override
	public String createRepresentation(ValuePeriod value) {
		return value.getValue().toString();
	}

	@Override
	public String createRepresentation(ValueString value) {
		return value.getValue();
	}

	@Override
	public String createRepresentation(AttributeUri uri) {
		return uri.getValue().stringValue();
	}

	private class ThisRelevantObjectVisitor implements RelevantObjectVisitor {

		@Override
		public void visit(RelevantIndividual object) {
			representation = createRepresentation(object);
		}

		@Override
		public void visit(AttributeSpatialLocation object) {
			representation = createRepresentation(object);
		}

		@Override
		public void visit(AttributeTemporalLocation object) {
			representation = createRepresentation(object);
		}

		@Override
		public void visit(AttributeUri object) {
			representation = createRepresentation(object);
		}
		
		@Override
		public void visit(ValueDouble object) {
			representation = createRepresentation(object);
		}

		@Override
		public void visit(ValueInteger object) {
			representation = createRepresentation(object);
		}

		@Override
		public void visit(ValuePeriod object) {
			representation = createRepresentation(object);
		}

		@Override
		public void visit(ValueString object) {
			representation = createRepresentation(object);
		}

		@Override
		public void visit(ValueUri object) {
			representation = createRepresentation(object);
		}

	}

}
