/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.text;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;

import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocationVisitor;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;

/**
 * <p>
 * Title: EntityRepresentationTextTime
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationTextTime extends EntityRepresentationText {

	private String representation;
	private TemporalLocationVisitor visitor = new ThisTemporalLocationVisitor();

	private DateTimeFormatter dtf = ISODateTimeFormat.dateTime()
			.withOffsetParsed();

	@Override
	public String createRepresentation(TemporalLocation location) {
		location.accept(visitor);

		return representation;
	}

	@Override
	public String createRepresentation(TemporalLocationDateTime time) {
		return dtf.print(time.getValueAsDateTime());
	}

	@Override
	public String createRepresentation(TemporalLocationInterval interval) {
		return createRepresentation(interval.getStart()) + "/"
				+ createRepresentation(interval.getEnd());
	}

	private class ThisTemporalLocationVisitor implements
			TemporalLocationVisitor {

		@Override
		public void visit(TemporalLocationDateTime time) {
			representation = createRepresentation(time);
		}

		@Override
		public void visit(TemporalLocationInterval interval) {
			representation = createRepresentation(interval);
		}

	}

}
