/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.csv.test;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;
import static org.junit.Assert.assertEquals;

import fi.uef.envi.wavellite.entity.derivation.ComponentSpecification;
import fi.uef.envi.wavellite.entity.derivation.DataStructureDefinition;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentSpecificationBase;
import fi.uef.envi.wavellite.entity.derivation.base.DataStructureDefinitionBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.representation.csv.EntityRepresentationCsvQb;

import static fi.uef.envi.wavellite.entity.core.EntityFactory.dataset;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentProperty;
import static fi.uef.envi.wavellite.entity.core.EntityFactory.componentPropertyValue;

/**
 * <p>
 * Title: EntityRepresentationCsvQbTest.java
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationCsvQbTest {

	private static final DateTimeFormatter dtf = ISODateTimeFormat.dateTime()
			.withOffsetParsed();

	@Test
	public void test1() {
		Dataset d = dataset("d1");
		DataStructureDefinition dsd = new DataStructureDefinitionBase();
		d.setDataStructureDefinition(dsd);

		ComponentSpecification cs1 = new ComponentSpecificationBase();
		cs1.setComponentProperty(componentProperty("p1"));
		cs1.setOrder(1);
		ComponentSpecification cs2 = new ComponentSpecificationBase();
		cs2.setComponentProperty(componentProperty("p2"));
		cs2.setOrder(2);

		dsd.addComponentSpecification(cs2);
		dsd.addComponentSpecification(cs1);

		EntityRepresentationCsvQb r = new EntityRepresentationCsvQb(d);

		DatasetObservation a = r.createDatasetObservation("1.0,2.0");

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(d);
		e.addComponent(componentProperty("p1"),
				componentPropertyValue(Double.valueOf("1.0")));
		e.addComponent(componentProperty("p2"),
				componentPropertyValue(Double.valueOf("2.0")));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		Dataset d = dataset("d1");
		DataStructureDefinition dsd = new DataStructureDefinitionBase();
		d.setDataStructureDefinition(dsd);

		ComponentSpecification cs1 = new ComponentSpecificationBase();
		cs1.setComponentProperty(componentProperty("p1"));
		cs1.setOrder(1);
		ComponentSpecification cs2 = new ComponentSpecificationBase();
		cs2.setComponentProperty(componentProperty("p2"));
		cs2.setOrder(2);

		dsd.addComponentSpecification(cs2);
		dsd.addComponentSpecification(cs1);

		EntityRepresentationCsvQb r = new EntityRepresentationCsvQb(d);

		DatasetObservation a = r
				.createDatasetObservation("2014-01-15T13:53:30.000+02:00,2.0");

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(d);
		e.addComponent(componentProperty("p1"), componentPropertyValue(dtf
				.parseDateTime("2014-01-15T13:53:30.000+02:00")));
		e.addComponent(componentProperty("p2"),
				componentPropertyValue(Double.valueOf("2.0")));

		assertEquals(e, a);
	}
	
	@Test
	public void test3() {
		Dataset d = dataset("d1");
		DataStructureDefinition dsd = new DataStructureDefinitionBase();
		d.setDataStructureDefinition(dsd);

		ComponentSpecification cs1 = new ComponentSpecificationBase();
		cs1.setComponentProperty(componentProperty("p1"));
		cs1.setOrder(1);
		ComponentSpecification cs2 = new ComponentSpecificationBase();
		cs2.setComponentProperty(componentProperty("p2"));
		cs2.setOrder(2);

		dsd.addComponentSpecification(cs2);
		dsd.addComponentSpecification(cs1);

		EntityRepresentationCsvQb r = new EntityRepresentationCsvQb(d);

		DatasetObservation a = r.createDatasetObservation("1.0,2");

		DatasetObservation e = new DatasetObservationBase();
		e.setDataset(d);
		e.addComponent(componentProperty("p1"),
				componentPropertyValue(Double.valueOf("1.0")));
		e.addComponent(componentProperty("p2"),
				componentPropertyValue(Integer.valueOf("2")));

		assertEquals(e, a);
	}

}
