/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.json.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import org.junit.Test;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ObjectNode;

import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.base.SensorBase;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.base.SensorObservationBase;
import fi.uef.envi.wavellite.representation.json.EntityRepresentationJsonSsn;
import fi.uef.envi.wavellite.vocabulary.SSN;
import fi.uef.envi.wavellite.vocabulary.WOE;

/**
 * <p>
 * Title: EntityRepresentationJsonSsnTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationJsonSsnTest {

	private static final ObjectMapper mapper = new ObjectMapper();

	@Test
	public void test1() {
		EntityRepresentationJsonSsn r = new EntityRepresentationJsonSsn();

		Sensor s = new SensorBase("s1", "st");
		JsonNode a = r.createRepresentation(s);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "s1");
		e.put("type", "st");

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		EntityRepresentationJsonSsn r = new EntityRepresentationJsonSsn();

		Sensor s = new SensorBase("s2", "st");
		JsonNode a = r.createRepresentation(s);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "s1");
		e.put("type", "st");

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		EntityRepresentationJsonSsn r = new EntityRepresentationJsonSsn();

		Sensor s = new SensorBase("s1");
		SensorObservation so = new SensorObservationBase("so1");
		so.setSensor(s);
		JsonNode a = r.createRepresentation(so);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "so1");
		e.put("type", WOE.SensorObservation);

		ObjectNode n1 = mapper.createObjectNode();
		e.put("sensor", n1);

		n1.put("id", "s1");
		n1.put("type", SSN.Sensor);

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		EntityRepresentationJsonSsn r = new EntityRepresentationJsonSsn();

		Sensor s = new SensorBase("s2");
		SensorObservation so = new SensorObservationBase("so1");
		so.setSensor(s);
		JsonNode a = r.createRepresentation(so);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "so1");
		e.put("type", WOE.SensorObservation);

		ObjectNode n1 = mapper.createObjectNode();
		e.put("sensor", n1);

		n1.put("id", "s1");
		n1.put("type", SSN.Sensor);

		assertNotEquals(e, a);
	}

}
