/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.json.test;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ArrayNode;
import com.fasterxml.jackson.databind.node.ObjectNode;

import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.Value;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ElementaryInfonBase;
import fi.uef.envi.wavellite.entity.situation.base.RelationBase;
import fi.uef.envi.wavellite.entity.situation.base.RelevantIndividualBase;
import fi.uef.envi.wavellite.entity.situation.base.SituationBase;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.representation.json.EntityRepresentationJsonSto;

/**
 * <p>
 * Title: EntityRepresentationJsonStoTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationJsonStoTest {

	private static final ObjectMapper mapper = new ObjectMapper();
	
	@Test
	public void test1() {
		EntityRepresentationJsonSto r = new EntityRepresentationJsonSto();

		Situation s = new SituationBase("s1", "t1");
		JsonNode a = r.createRepresentation(s);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "s1");
		e.put("type", "t1");
		e.put("class", SituationBase.class.getName());
		
		assertEquals(e, a);
	}
	
	@Test
	public void test2() {
		EntityRepresentationJsonSto r = new EntityRepresentationJsonSto();

		Situation s = new SituationBase("s1", "t1");
		ElementaryInfon i = new ElementaryInfonBase("i1", "t2");
		s.addSupportedInfon(i);
		JsonNode a = r.createRepresentation(s);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "s1");
		e.put("type", "t1");
		e.put("class", SituationBase.class.getName());
		
		ArrayNode supportedInfonsN = mapper.createArrayNode();
		ObjectNode infonN = mapper.createObjectNode();
		supportedInfonsN.add(infonN);
		
		infonN.put("id", i.getId());
		infonN.put("type", i.getType());
		infonN.put("class", i.getClass().getName());
		infonN.put("polarity", "1");
		
		e.put("supportedInfons", supportedInfonsN);

		assertEquals(e, a);
	}
	
	@Test
	public void test3() {
		EntityRepresentationJsonSto r = new EntityRepresentationJsonSto();

		Situation s = new SituationBase("s1", "t1");
		ElementaryInfon i = new ElementaryInfonBase("i1", "t2");
		i.setRelation(new RelationBase("r1", "t3"));
		s.addSupportedInfon(i);
		JsonNode a = r.createRepresentation(s);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "s1");
		e.put("type", "t1");
		e.put("class", SituationBase.class.getName());
		
		ArrayNode supportedInfonsN = mapper.createArrayNode();
		ObjectNode infonN = mapper.createObjectNode();
		supportedInfonsN.add(infonN);
		
		ObjectNode relationN = mapper.createObjectNode();
		relationN.put("id", "r1");
		relationN.put("type", "t3");
		relationN.put("class", RelationBase.class.getName());
		
		infonN.put("id", i.getId());
		infonN.put("type", i.getType());
		infonN.put("class", i.getClass().getName());
		infonN.put("relation", relationN);
		infonN.put("polarity", "1");
		
		e.put("supportedInfons", supportedInfonsN);

		assertEquals(e, a);
	}
	
	@Test
	public void test4() {
		EntityRepresentationJsonSto r = new EntityRepresentationJsonSto();

		Situation s = new SituationBase("s1", "t1");
		ElementaryInfon i = new ElementaryInfonBase("i1", "t2");
		i.setRelation(new RelationBase("r1", "t3"));
		i.addRelevantObject(new ValueString("v1", "t4", "s1"));
		s.addSupportedInfon(i);
		JsonNode a = r.createRepresentation(s);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "s1");
		e.put("type", "t1");
		e.put("class", SituationBase.class.getName());
		
		ArrayNode supportedInfonsN = mapper.createArrayNode();
		ObjectNode infonN = mapper.createObjectNode();
		supportedInfonsN.add(infonN);
		
		ObjectNode relationN = mapper.createObjectNode();
		relationN.put("id", "r1");
		relationN.put("type", "t3");
		relationN.put("class", RelationBase.class.getName());
		
		ArrayNode objectsN = mapper.createArrayNode();
		ObjectNode object1 = mapper.createObjectNode();
		objectsN.add(object1);
		
		object1.put("id", "v1");
		object1.put("type", "t4");
		object1.put("class", ValueString.class.getName());
		object1.put("value", "s1");
		
		infonN.put("id", "i1");
		infonN.put("type", "t2");
		infonN.put("class", ElementaryInfonBase.class.getName());
		infonN.put("relation", relationN);
		infonN.put("objects", objectsN);
		infonN.put("polarity", "1");
		
		e.put("supportedInfons", supportedInfonsN);

		assertEquals(e, a);
	}
	
	@Test
	public void test5() {
		EntityRepresentationJsonSto r = new EntityRepresentationJsonSto();

		Situation s = new SituationBase("s1", "t1");
		ElementaryInfon i = new ElementaryInfonBase("i1", "t2");
		i.setRelation(new RelationBase("r1", "t3"));
		RelevantIndividual ri = new RelevantIndividualBase("ri1", "t4");
		Attribute at = new AttributeValue("at1", "t5");
		Value av = new ValueString("av1", "t6", "s1");
		at.setValue(av);
		ri.addAttribute(at);
		i.addRelevantObject(ri);
		s.addSupportedInfon(i);
		JsonNode a = r.createRepresentation(s);

		ObjectNode e = mapper.createObjectNode();
		e.put("id", "s1");
		e.put("type", "t1");
		e.put("class", SituationBase.class.getName());
		
		ArrayNode supportedInfonsN = mapper.createArrayNode();
		ObjectNode infonN = mapper.createObjectNode();
		supportedInfonsN.add(infonN);
		
		ObjectNode relationN = mapper.createObjectNode();
		relationN.put("id", "r1");
		relationN.put("type", "t3");
		relationN.put("class", RelationBase.class.getName());
		
		ArrayNode objectsN = mapper.createArrayNode();
		ObjectNode object1 = mapper.createObjectNode();
		objectsN.add(object1);
		object1.put("id", "ri1");
		object1.put("type", "t4");
		object1.put("class", RelevantIndividualBase.class.getName());
		
		ArrayNode attributesN = mapper.createArrayNode();
		object1.put("attributes", attributesN);
		
		ObjectNode attribute1 = mapper.createObjectNode();
		attributesN.add(attribute1);
		attribute1.put("id", "at1");
		attribute1.put("type", "t5");
		attribute1.put("class", AttributeValue.class.getName());
		
		ObjectNode value1 = mapper.createObjectNode();
		attribute1.put("value", value1);
		value1.put("id", "av1");
		value1.put("type", "t6");
		value1.put("class", ValueString.class.getName());
		value1.put("value", "s1");
		
		infonN.put("id", "i1");
		infonN.put("type", "t2");
		infonN.put("class", ElementaryInfonBase.class.getName());
		infonN.put("relation", relationN);
		infonN.put("objects", objectsN);
		infonN.put("polarity", "1");
		
		e.put("supportedInfons", supportedInfonsN);

		assertEquals(e, a);
	}
	
}
