/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.rdf.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import java.util.HashSet;
import java.util.Set;

import org.junit.Test;
import org.openrdf.model.Statement;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;
import org.openrdf.model.vocabulary.RDF;
import org.openrdf.model.vocabulary.RDFS;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.LineString;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.geom.Polygon;

import fi.uef.envi.wavellite.entity.core.SpatialGeometry;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryLineString;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfGeo;
import fi.uef.envi.wavellite.vocabulary.GeoSPARQL;
import fi.uef.envi.wavellite.vocabulary.SF;
import fi.uef.envi.wavellite.vocabulary.WO;
import fi.uef.envi.wavellite.vocabulary.WOE;

/**
 * <p>
 * Title: EntityRepresentationRdfGeoTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationRdfGeoTest {

	private static final ValueFactory vf = ValueFactoryImpl.getInstance();

	@Test
	public void test1() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo();

		SpatialLocation sl = new SpatialLocationPlace("sl1", "l1");

		Set<Statement> a = r.createRepresentation(sl);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDFS.LABEL,
				vf.createLiteral("l1")));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo();

		SpatialLocation sl = new SpatialLocationPlace("sl1", "l1");

		Set<Statement> a = r.createRepresentation(sl);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDFS.LABEL,
				vf.createLiteral("l2")));

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo();

		GeometryFactory gf = new GeometryFactory();
		Point p = gf.createPoint(new Coordinate(0.0, 0.0));

		SpatialGeometry sg = new SpatialGeometryPoint("l1", p);
		SpatialLocationRegion sl = new SpatialLocationRegion("sl1", sg);

		Set<Statement> a = r.createRepresentation(sl);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.Point));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asWKT, vf.createLiteral(sg.getValueAsWKT(),
						GeoSPARQL.asURI.wktLiteral)));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo();

		GeometryFactory gf = new GeometryFactory();
		Point p1 = gf.createPoint(new Coordinate(0.0, 0.0));

		SpatialGeometry sg1 = new SpatialGeometryPoint("l1", p1);
		SpatialLocationRegion sl = new SpatialLocationRegion("sl1", sg1);

		Set<Statement> a = r.createRepresentation(sl);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.Point));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asWKT, vf.createLiteral(
						new SpatialGeometryPoint("l1", gf
								.createPoint(new Coordinate(1.0, 1.0)))
								.getValueAsWKT(), GeoSPARQL.asURI.wktLiteral)));

		assertNotEquals(e, a);
	}

	@Test
	public void test5() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo(
				"http://example.org");

		SpatialLocationPlace l = new SpatialLocationPlace("sl1");

		Set<Statement> statements = r.createRepresentation(l);

		SpatialLocationPlace a = r.createSpatialLocationPlace(statements);

		SpatialLocationPlace e = new SpatialLocationPlace(
				"http://example.org#sl1");

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo(
				"http://example.org");

		SpatialLocationPlace l = new SpatialLocationPlace("sl1", "p1");

		Set<Statement> statements = r.createRepresentation(l);

		SpatialLocationPlace a = r.createSpatialLocationPlace(statements);

		SpatialLocationPlace e = new SpatialLocationPlace(
				"http://example.org#sl1", "p1");

		assertEquals(e, a);
	}

	@Test
	public void test7() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo(
				"http://example.org");

		SpatialLocationPlace l = new SpatialLocationPlace("sl1");
		l.setLabel("p1");
		l.addSameAs(vf.createURI("http://example.org#a1"));

		Set<Statement> statements = r.createRepresentation(l);

		SpatialLocationPlace a = r.createSpatialLocationPlace(statements);

		SpatialLocationPlace e = new SpatialLocationPlace(
				"http://example.org#sl1", "p1");
		e.addSameAs(vf.createURI("http://example.org#a1"));

		assertEquals(e, a);
	}

	@Test
	public void test8() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo(
				"http://example.org");

		GeometryFactory gf = new GeometryFactory();
		Point p1 = gf.createPoint(new Coordinate(0.0, 0.0));
		SpatialGeometry g1 = new SpatialGeometryPoint("p1");
		g1.setValue(p1);

		SpatialLocationRegion l = new SpatialLocationRegion("sl1");
		l.setSpatialGeometry(g1);

		Set<Statement> statements = r.createRepresentation(l);

		SpatialLocationRegion a = r.createSpatialLocationRegion(statements);

		SpatialLocationRegion e = new SpatialLocationRegion(
				"http://example.org#sl1");
		e.setSpatialGeometry(g1);

		assertEquals(e, a);
	}

	@Test
	public void test9() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo(
				"http://example.org");

		GeometryFactory gf = new GeometryFactory();
		Polygon p1 = gf.createPolygon(new Coordinate[] {
				new Coordinate(0.0, 0.0), new Coordinate(1.0, 0.0),
				new Coordinate(0.0, 1.0), new Coordinate(0.0, 0.0) });
		SpatialGeometry g1 = new SpatialGeometryPolygon("p1");
		g1.setValue(p1);

		SpatialLocationRegion l = new SpatialLocationRegion("sl1");

		l.setSpatialGeometry(g1);

		Set<Statement> statements = r.createRepresentation(l);

		SpatialLocationRegion a = r.createSpatialLocationRegion(statements);

		SpatialLocationRegion e = new SpatialLocationRegion(
				"http://example.org#sl1");
		e.setSpatialGeometry(g1);

		assertEquals(e, a);
	}

	@Test
	public void test10() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo(
				"http://example.org");

		GeometryFactory gf = new GeometryFactory();
		LineString p1 = gf.createLineString(new Coordinate[] {
				new Coordinate(0.0, 0.0), new Coordinate(1.0, 0.0),
				new Coordinate(0.0, 1.0) });
		SpatialGeometry g1 = new SpatialGeometryLineString("p1");
		g1.setValue(p1);

		SpatialLocationRegion l = new SpatialLocationRegion("sl1");

		l.setSpatialGeometry(g1);

		Set<Statement> statements = r.createRepresentation(l);

		SpatialLocationRegion a = r.createSpatialLocationRegion(statements);

		SpatialLocationRegion e = new SpatialLocationRegion(
				"http://example.org#sl1");
		e.setSpatialGeometry(g1);

		assertEquals(e, a);
	}

	@Test
	public void test11() {
		EntityRepresentationRdfGeo r = new EntityRepresentationRdfGeo();

		GeometryFactory gf = new GeometryFactory();
		Point p = gf.createPoint(new Coordinate(0.0, 0.0));

		SpatialGeometry sg = new SpatialGeometryPoint("l1", p);
		SpatialLocationRegion sl = new SpatialLocationRegion("sl1", sg);

		Set<Statement> a = r.createRepresentation(sl, GeoSPARQL.gmlLiteral);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.Point));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asGML, vf.createLiteral(sg.getValueAsGML(),
						GeoSPARQL.asURI.gmlLiteral)));

		assertEquals(e, a);
	}

}
