/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.rdf.test;

import java.util.HashSet;
import java.util.Set;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import org.openrdf.model.Statement;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;
import org.openrdf.model.vocabulary.RDF;

import fi.uef.envi.wavellite.entity.core.Operation;
import fi.uef.envi.wavellite.entity.core.Operator;
import fi.uef.envi.wavellite.entity.core.base.OperationBase;
import fi.uef.envi.wavellite.entity.core.base.OperatorBase;
import fi.uef.envi.wavellite.entity.core.base.SensorBase;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.base.SensorObservationBase;
import fi.uef.envi.wavellite.entity.observation.base.StimulusBase;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.ElementaryInfonBase;
import fi.uef.envi.wavellite.entity.situation.base.RelationBase;
import fi.uef.envi.wavellite.entity.situation.base.RelevantIndividualBase;
import fi.uef.envi.wavellite.entity.situation.base.SituationBase;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfProv;
import fi.uef.envi.wavellite.vocabulary.PROV;
import fi.uef.envi.wavellite.vocabulary.WO;

/**
 * <p>
 * Title: EntityRepresentationRdfProvTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationRdfProvTest {

	private static final ValueFactory vf = ValueFactoryImpl.getInstance();

	@Test
	public void test1() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		Set<Statement> a = r.createRepresentation(new SensorBase("s1"));

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				PROV.asURI.Agent));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		Set<Statement> a = r.createRepresentation(new StimulusBase("s1"));

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				PROV.asURI.Activity));

		assertEquals(e, a);
	}

	@Test
	public void test3() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		SensorObservation o = new SensorObservationBase("o1");
		o.setSensor(new SensorBase("s1"));
		o.setStimulus(new StimulusBase("t1"));
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				PROV.asURI.Agent));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"), RDF.TYPE,
				PROV.asURI.Activity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasAttributedTo, vf.createURI(WO.ns + "#s1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasGeneratedBy, vf.createURI(WO.ns + "#t1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"),
				PROV.asURI.wasAssociatedWith, vf.createURI(WO.ns + "#s1")));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		Set<Statement> a = r.createRepresentation(new OperationBase("o1"));

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Activity));

		assertEquals(e, a);
	}

	@Test
	public void test5() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		Operation o = new OperationBase("o1");
		o.setAssociatedWith(new OperatorBase("o2"));

		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Activity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o2"), RDF.TYPE,
				PROV.asURI.Agent));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasAssociatedWith, vf.createURI(WO.ns + "#o2")));

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		Set<Statement> a = r.createRepresentation(new OperatorBase("o1"));

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Agent));

		assertEquals(e, a);
	}

	@Test
	public void test7() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		DatasetObservation o = new DatasetObservationBase("do1");
		o.setAttributedTo(new OperatorBase("o1"));
		o.setGeneratedBy(new OperationBase("o2"));
		o.addDerivedFrom(new DatasetObservationBase("do2"));

		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do2"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Agent));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o2"), RDF.TYPE,
				PROV.asURI.Activity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasAttributedTo, vf.createURI(WO.ns + "#o1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasGeneratedBy, vf.createURI(WO.ns + "#o2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasDerivedFrom, vf.createURI(WO.ns + "#do2")));

		assertEquals(e, a);
	}

	@Test
	public void test8() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		DatasetObservation o = new DatasetObservationBase("do1");
		o.setAttributedTo(new OperatorBase("o1"));
		o.setGeneratedBy(new OperationBase("o2"));
		o.addDerivedFrom(new SensorObservationBase("so1"));

		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Agent));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o2"), RDF.TYPE,
				PROV.asURI.Activity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasAttributedTo, vf.createURI(WO.ns + "#o1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasGeneratedBy, vf.createURI(WO.ns + "#o2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasDerivedFrom, vf.createURI(WO.ns + "#so1")));

		assertEquals(e, a);
	}

	@Test
	public void test9() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		DatasetObservation o = new DatasetObservationBase("do1");
		o.setAttributedTo(new OperatorBase("o1"));
		o.setGeneratedBy(new OperationBase("o2"));
		o.addDerivedFrom(new SensorObservationBase("so1"));
		o.addDerivedFrom(new DatasetObservationBase("do2"));

		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do2"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Agent));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o2"), RDF.TYPE,
				PROV.asURI.Activity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasAttributedTo, vf.createURI(WO.ns + "#o1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasGeneratedBy, vf.createURI(WO.ns + "#o2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasDerivedFrom, vf.createURI(WO.ns + "#so1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"),
				PROV.asURI.wasDerivedFrom, vf.createURI(WO.ns + "#do2")));

		assertEquals(e, a);
	}

	@Test
	public void test10() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		Situation s = new SituationBase("s1");
		ElementaryInfon i = new ElementaryInfonBase("i1");
		s.addSupportedInfon(i);
		i.setRelation(new RelationBase("r1"));
		RelevantIndividual o1 = new RelevantIndividualBase("o1");
		o1.addDerivedFrom(new DatasetObservationBase("do1"));
		Operator op1 = new OperatorBase("op1");
		o1.setAttributedTo(op1);
		Operation op2 = new OperationBase("op2");
		o1.setGeneratedBy(op2);
		op2.setAssociatedWith(op1);

		i.addRelevantObject(o1);

		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#op1"), RDF.TYPE,
				PROV.asURI.Agent));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#op2"), RDF.TYPE,
				PROV.asURI.Activity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasDerivedFrom, vf.createURI(WO.ns + "#do1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasAttributedTo, vf.createURI(WO.ns + "#op1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasGeneratedBy, vf.createURI(WO.ns + "#op2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#op2"),
				PROV.asURI.wasAssociatedWith, vf.createURI(WO.ns + "#op1")));

		assertEquals(e, a);
	}

	@Test
	public void test11() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		Situation s = new SituationBase("s1");
		ElementaryInfon i = new ElementaryInfonBase("i1");
		s.addSupportedInfon(i);
		i.setRelation(new RelationBase("r1"));
		RelevantIndividual o1 = new RelevantIndividualBase("o1");
		o1.addDerivedFrom(new DatasetObservationBase("do1"));
		Operator op1 = new OperatorBase("op1");
		o1.setAttributedTo(op1);
		Operation op2 = new OperationBase("op2");
		o1.setGeneratedBy(op2);
		op2.setAssociatedWith(op1);

		i.addRelevantObject(o1);

		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#op1"), RDF.TYPE,
				PROV.asURI.Agent));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#op2"), RDF.TYPE,
				PROV.asURI.Activity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasDerivedFrom, vf.createURI(WO.ns + "#do1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasAttributedTo, vf.createURI(WO.ns + "#op1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				PROV.asURI.wasGeneratedBy, vf.createURI(WO.ns + "#op2")));

		assertNotEquals(e, a);
	}

	@Test
	public void test12() {
		EntityRepresentationRdfProv r = new EntityRepresentationRdfProv();

		Situation s = new SituationBase("s1");
		ElementaryInfon i = new ElementaryInfonBase("i1");
		s.addSupportedInfon(i);
		Relation t = new RelationBase("r1");
		i.setRelation(t);
		t.addDerivedFrom(new DatasetObservationBase("do1"));
		t.setAttributedTo(new OperatorBase("op1"));
		t.setGeneratedBy(new OperationBase("op2"));

		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#do1"), RDF.TYPE,
				PROV.asURI.Entity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#op1"), RDF.TYPE,
				PROV.asURI.Agent));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#op2"), RDF.TYPE,
				PROV.asURI.Activity));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"),
				PROV.asURI.wasDerivedFrom, vf.createURI(WO.ns + "#do1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"),
				PROV.asURI.wasAttributedTo, vf.createURI(WO.ns + "#op1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"),
				PROV.asURI.wasGeneratedBy, vf.createURI(WO.ns + "#op2")));

		assertEquals(e, a);
	}

}
