/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.rdf.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import java.util.HashSet;
import java.util.Set;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;
import org.openrdf.model.Statement;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;
import org.openrdf.model.vocabulary.RDF;
import org.openrdf.model.vocabulary.RDFS;
import org.openrdf.model.vocabulary.XMLSchema;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.Point;

import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.derivation.ComponentProperty;
import fi.uef.envi.wavellite.entity.derivation.ComponentSpecification;
import fi.uef.envi.wavellite.entity.derivation.DataStructureDefinition;
import fi.uef.envi.wavellite.entity.derivation.Dataset;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyDimension;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueInteger;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueSpatialLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueString;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueUri;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentSpecificationBase;
import fi.uef.envi.wavellite.entity.derivation.base.DataStructureDefinitionBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfQb;
import fi.uef.envi.wavellite.vocabulary.GeoSPARQL;
import fi.uef.envi.wavellite.vocabulary.QB;
import fi.uef.envi.wavellite.vocabulary.SF;
import fi.uef.envi.wavellite.vocabulary.Time;
import fi.uef.envi.wavellite.vocabulary.WO;
import fi.uef.envi.wavellite.vocabulary.WOE;

/**
 * <p>
 * Title: EntityRepresentationRdfQbTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationRdfQbTest {

	private static final DateTimeFormatter dtf = ISODateTimeFormat.dateTimeParser()
			.withOffsetParsed();
	private static final ValueFactory vf = ValueFactoryImpl.getInstance();

	@Test
	public void test1() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		Dataset d = new DatasetBase(WO.ns + "#d1");
		
		Set<Statement> a = r.createRepresentation(d);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		Dataset d = new DatasetBase(WO.ns + "#d2");
		
		Set<Statement> a = r.createRepresentation(d);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		ComponentProperty p = new ComponentPropertyBase(WO.ns + "#p1");
		
		Set<Statement> a = r.createRepresentation(p);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		ComponentProperty p = new ComponentPropertyBase(WO.ns + "#p2");
		
		Set<Statement> a = r.createRepresentation(p);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));

		assertNotEquals(e, a);
	}

	@Test
	public void test5() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase(WO.ns + "#o1");
		o.setDataset(new DatasetBase(WO.ns + "#d1"));
		o.addComponent(new ComponentPropertyBase(WO.ns + "#p1"),
				new ComponentPropertyValueDouble(WO.ns + "#v1", 0.0));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createLiteral(0.0)));

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase(WO.ns + "#o1");
		o.setDataset(new DatasetBase(WO.ns + "#d1"));
		o.addComponent(new ComponentPropertyBase(WO.ns + "#p1"),
				new ComponentPropertyValueDouble(WO.ns + "#v1", 0.5));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createLiteral(0.0)));

		assertNotEquals(e, a);
	}

	@Test
	public void test7() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase(WO.ns + "#o1");

		o.setDataset(new DatasetBase(WO.ns + "#d1"));
		o.addComponent(new ComponentPropertyBase(WO.ns + "#p1"),
				new ComponentPropertyValueInteger(WO.ns + "#v1", 0));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createLiteral(0)));

		assertEquals(e, a);
	}

	@Test
	public void test8() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase(WO.ns + "#o1");

		o.setDataset(new DatasetBase(WO.ns + "#d1"));
		o.addComponent(new ComponentPropertyBase(WO.ns + "#p1"),
				new ComponentPropertyValueInteger(WO.ns + "#v1", 0));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createLiteral(5)));

		assertNotEquals(e, a);
	}

	@Test
	public void test9() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		Dataset d = new DatasetBase(WO.ns + "#d1");
		
		Set<Statement> a = r.createRepresentation(d);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));

		assertEquals(e, a);
	}

	@Test
	public void test10() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		Dataset d = new DatasetBase(WO.ns + "#d1");
		
		Set<Statement> a = r.createRepresentation(d);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d2"), RDF.TYPE,
				QB.asURI.DataSet));

		assertNotEquals(e, a);
	}

	@Test
	public void test11() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		Dataset d = new DatasetBase("d1");
		DataStructureDefinition s = new DataStructureDefinitionBase("s1");
		ComponentSpecification c = new ComponentSpecificationBase("c1");
		c.setComponentProperty(new ComponentPropertyDimension("p1"));
		c.setComponentRequired(false);
		c.setOrder(1);
		s.addComponentSpecification(c);
		d.setDataStructureDefinition(s);
		
		Set<Statement> a = r.createRepresentation(d);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				QB.asURI.DataStructureDefinition));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#c1"), RDF.TYPE,
				QB.asURI.ComponentSpecification));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.DimensionProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"),
				QB.asURI.structure, vf.createURI(WO.ns + "#s1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"),
				QB.asURI.component, vf.createURI(WO.ns + "#c1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#c1"),
				QB.asURI.dimension, vf.createURI(WO.ns + "#p1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#c1"),
				QB.asURI.componentRequired,
				vf.createLiteral("false", XMLSchema.BOOLEAN)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#c1"), QB.asURI.order,
				vf.createLiteral("1", XMLSchema.INT)));

		assertEquals(e, a);
	}

	@Test
	public void test12() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		Dataset d = new DatasetBase("d1");
		DataStructureDefinition s = new DataStructureDefinitionBase("s1");
		ComponentSpecification c = new ComponentSpecificationBase("c1");
		c.setComponentProperty(new ComponentPropertyDimension("p1"));
		c.setComponentRequired(false);
		c.setOrder(1);
		s.addComponentSpecification(c);
		d.setDataStructureDefinition(s);
		
		Set<Statement> a = r.createRepresentation(d);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				QB.asURI.DataStructureDefinition));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#c1"), RDF.TYPE,
				QB.asURI.ComponentSpecification));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.DimensionProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"),
				QB.asURI.structure, vf.createURI(WO.ns + "#s1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"),
				QB.asURI.component, vf.createURI(WO.ns + "#c1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#c1"),
				QB.asURI.dimension, vf.createURI(WO.ns + "#p1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#c1"),
				QB.asURI.componentRequired,
				vf.createLiteral("true", XMLSchema.BOOLEAN)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#c1"), QB.asURI.order,
				vf.createLiteral("1", XMLSchema.INT)));

		assertNotEquals(e, a);
	}

	@Test
	public void test13() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase("#o1");

		o.setDataset(new DatasetBase("#d1"));
		o.addComponent(
				new ComponentPropertyBase("#p1"),
				new ComponentPropertyValueTemporalLocation(
						"#v1",
						new TemporalLocationDateTime("#tl1", dtf
								.parseDateTime("2014-01-02T00:00:00.000+02:00"))));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createURI(WO.ns + "#tl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T00:00:00.000+02:00", XMLSchema.DATETIME)));

		assertEquals(e, a);
	}

	@Test
	public void test14() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase("#o1");

		o.setDataset(new DatasetBase("#d1"));
		o.addComponent(
				new ComponentPropertyBase("#p1"),
				new ComponentPropertyValueTemporalLocation(
						"#v1",
						new TemporalLocationDateTime("#tl1", dtf
								.parseDateTime("2014-01-02T00:00:00.000+02:00"))));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createURI(WO.ns + "#tl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T01:00:00.000+02:00", XMLSchema.DATETIME)));

		assertNotEquals(e, a);
	}

	@Test
	public void test15() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase("#o1");

		o.setDataset(new DatasetBase("#d1"));
		o.addComponent(
				new ComponentPropertyBase("#p1"),
				new ComponentPropertyValueTemporalLocation(
						"#v1",
						new TemporalLocationInterval(
								"#tl1",
								new TemporalLocationDateTime(
										"l1",
										dtf.parseDateTime("2014-01-02T00:00:00.000+02:00")),
								new TemporalLocationDateTime(
										"l2",
										dtf.parseDateTime("2014-01-02T01:00:00.000+02:00")))));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createURI(WO.ns + "#tl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimeInterval));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasBeginning, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasEnd, vf.createURI(WO.ns + "#l2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T01:00:00.000+02:00", XMLSchema.DATETIME)));

		assertEquals(e, a);
	}

	@Test
	public void test16() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase("#o1");

		o.setDataset(new DatasetBase("#d1"));
		o.addComponent(
				new ComponentPropertyBase("#p1"),
				new ComponentPropertyValueTemporalLocation(
						"#v1",
						new TemporalLocationInterval(
								"#tl1",
								new TemporalLocationDateTime(
										"l1",
										dtf.parseDateTime("2014-01-02T00:00:00.000+02:00")),
								new TemporalLocationDateTime(
										"l2",
										dtf.parseDateTime("2014-01-02T01:00:00.000+02:00")))));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createURI(WO.ns + "#tl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimeInterval));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasBeginning, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasEnd, vf.createURI(WO.ns + "#l2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T02:00:00.000+02:00", XMLSchema.DATETIME)));

		assertNotEquals(e, a);
	}

	@Test
	public void test19() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentBase("c1", new ComponentPropertyBase("p1"),
				new ComponentPropertyValueSpatialLocation("v1",
						new SpatialLocationPlace("sl1", "l1"))));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDFS.LABEL,
				vf.createLiteral("l1")));

		assertEquals(e, a);
	}

	@Test
	public void test20() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentBase("c1", new ComponentPropertyBase("p1"),
				new ComponentPropertyValueSpatialLocation("v1",
						new SpatialLocationPlace("sl1", "l1"))));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDFS.LABEL,
				vf.createLiteral("l2")));

		assertNotEquals(e, a);
	}

	@Test
	public void test21() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		GeometryFactory gf = new GeometryFactory();
		Point p = gf.createPoint(new Coordinate(0.0, 0.0));

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentBase("c1", new ComponentPropertyBase("p1"),
				new ComponentPropertyValueSpatialLocation("v1",
						new SpatialLocationRegion("sl1",
								new SpatialGeometryPoint("l1", p)))));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.Point));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"), vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asWKT, vf.createLiteral(
						new SpatialGeometryPoint("l1", p).getValueAsWKT(),
						GeoSPARQL.asURI.wktLiteral)));

		assertEquals(e, a);
	}

	@Test
	public void test22() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase(WO.ns + "#o1");

		o.setDataset(new DatasetBase(WO.ns + "#d1"));
		o.addComponent(new ComponentPropertyBase(WO.ns + "#p1"),
				new ComponentPropertyValueString(WO.ns + "#v1", "s"));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"),
				vf.createLiteral("s", XMLSchema.STRING)));

		assertEquals(e, a);
	}

	@Test
	public void test23() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		DatasetObservation o = new DatasetObservationBase(WO.ns + "#o1");

		o.setDataset(new DatasetBase(WO.ns + "#d1"));
		o.addComponent(
				new ComponentPropertyBase(WO.ns + "#p1"),
				new ComponentPropertyValueUri(WO.ns + "#v1", vf
						.createURI("http://example.org#u1")));
		
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				WOE.asURI.DatasetObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#d1"), RDF.TYPE,
				QB.asURI.DataSet));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				QB.asURI.ComponentProperty));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), QB.asURI.dataSet,
				vf.createURI(WO.ns + "#d1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				vf.createURI(WO.ns + "#p1"),
				vf.createURI("http://example.org#u1")));

		assertEquals(e, a);
	}

	@Test
	public void test24() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb(
				"http://example.org#");

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentPropertyBase("cp1"),
				new ComponentPropertyValueDouble("pv1", 0.0));
		
		Set<Statement> s = r.createRepresentation(o);

		DatasetObservation a = r.createDatasetObservation(s);

		DatasetObservation e = new DatasetObservationBase(
				"http://example.org#o1");
		e.setDataset(new DatasetBase("http://example.org#d1"));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp1"),
				new ComponentPropertyValueDouble("http://example.org#pv1", 0.0));

		assertEquals(e, a);
	}

	@Test
	public void test25() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb(
				"http://example.org#");

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentPropertyBase("cp1"),
				new ComponentPropertyValueDouble("pv1", 0.0));
		o.addComponent(new ComponentPropertyBase("cp2"),
				new ComponentPropertyValueInteger("pv2", 0));
		
		Set<Statement> s = r.createRepresentation(o);

		DatasetObservation a = r.createDatasetObservation(s);

		DatasetObservation e = new DatasetObservationBase(
				"http://example.org#o1");
		e.setDataset(new DatasetBase("http://example.org#d1"));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp1"),
				new ComponentPropertyValueDouble("http://example.org#pv1", 0.0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp2"),
				new ComponentPropertyValueInteger("http://example.org#pv2", 0));

		assertEquals(e, a);
	}

	@Test
	public void test26() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb(
				"http://example.org#");

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentPropertyBase("cp1"),
				new ComponentPropertyValueDouble("pv1", 0.0));
		o.addComponent(new ComponentPropertyBase("cp2"),
				new ComponentPropertyValueInteger("pv2", 0));
		o.addComponent(new ComponentPropertyBase("cp3"),
				new ComponentPropertyValueString("pv3", "string"));
		
		Set<Statement> s = r.createRepresentation(o);

		DatasetObservation a = r.createDatasetObservation(s);

		DatasetObservation e = new DatasetObservationBase(
				"http://example.org#o1");
		e.setDataset(new DatasetBase("http://example.org#d1"));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp1"),
				new ComponentPropertyValueDouble("http://example.org#pv1", 0.0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp2"),
				new ComponentPropertyValueInteger("http://example.org#pv2", 0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp3"),
				new ComponentPropertyValueString("http://example.org#pv3",
						"string"));

		assertEquals(e, a);
	}

	@Test
	public void test27() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb(
				"http://example.org#");

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentPropertyBase("cp1"),
				new ComponentPropertyValueDouble("pv1", 0.0));
		o.addComponent(new ComponentPropertyBase("cp2"),
				new ComponentPropertyValueInteger("pv2", 0));
		o.addComponent(new ComponentPropertyBase("cp3"),
				new ComponentPropertyValueString("pv3", "string"));
		o.addComponent(
				new ComponentPropertyBase("cp4"),
				new ComponentPropertyValueUri("pv4", vf
						.createURI("http://test.org#u4")));
		
		Set<Statement> s = r.createRepresentation(o);

		DatasetObservation a = r.createDatasetObservation(s);

		DatasetObservation e = new DatasetObservationBase(
				"http://example.org#o1");
		e.setDataset(new DatasetBase("http://example.org#d1"));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp1"),
				new ComponentPropertyValueDouble("http://example.org#pv1", 0.0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp2"),
				new ComponentPropertyValueInteger("http://example.org#pv2", 0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp3"),
				new ComponentPropertyValueString("http://example.org#pv3",
						"string"));
		e.addComponent(
				new ComponentPropertyBase("http://example.org#cp4"),
				new ComponentPropertyValueUri("http://example.org#pv4", vf
						.createURI("http://test.org#u4")));

		assertEquals(e, a);
	}

	@Test
	public void test28() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb(
				"http://example.org#");

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentPropertyBase("cp1"),
				new ComponentPropertyValueDouble("pv1", 0.0));
		o.addComponent(new ComponentPropertyBase("cp2"),
				new ComponentPropertyValueInteger("pv2", 0));
		o.addComponent(new ComponentPropertyBase("cp3"),
				new ComponentPropertyValueString("pv3", "string"));
		o.addComponent(
				new ComponentPropertyBase("cp4"),
				new ComponentPropertyValueUri("pv4", vf
						.createURI("http://test.org#u4")));
		o.addComponent(
				new ComponentPropertyBase("cp5"),
				new ComponentPropertyValueTemporalLocation(
						"pv5",
						new TemporalLocationDateTime("tl1", dtf
								.parseDateTime("2014-02-20T18:02:00.000+02:00"))));
		
		Set<Statement> s = r.createRepresentation(o);

		DatasetObservation a = r.createDatasetObservation(s);

		DatasetObservation e = new DatasetObservationBase(
				"http://example.org#o1");
		e.setDataset(new DatasetBase("http://example.org#d1"));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp1"),
				new ComponentPropertyValueDouble("http://example.org#pv1", 0.0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp2"),
				new ComponentPropertyValueInteger("http://example.org#pv2", 0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp3"),
				new ComponentPropertyValueString("http://example.org#pv3",
						"string"));
		e.addComponent(
				new ComponentPropertyBase("http://example.org#cp4"),
				new ComponentPropertyValueUri("http://example.org#pv4", vf
						.createURI("http://test.org#u4")));
		e.addComponent(
				new ComponentPropertyBase("http://example.org#cp5"),
				new ComponentPropertyValueTemporalLocation(
						"http://example.org#pv5",
						new TemporalLocationDateTime(
								"http://example.org#tl1",
								dtf.parseDateTime("2014-02-20T18:02:00.000+02:00"))));

		assertEquals(e, a);
	}

	@Test
	public void test29() {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb(
				"http://example.org#");

		GeometryFactory gf = new GeometryFactory();
		Point p = gf.createPoint(new Coordinate(0.0, 0.0));

		DatasetObservation o = new DatasetObservationBase("o1");
		o.setDataset(new DatasetBase("d1"));
		o.addComponent(new ComponentPropertyBase("cp1"),
				new ComponentPropertyValueDouble("pv1", 0.0));
		o.addComponent(new ComponentPropertyBase("cp2"),
				new ComponentPropertyValueInteger("pv2", 0));
		o.addComponent(new ComponentPropertyBase("cp3"),
				new ComponentPropertyValueString("pv3", "string"));
		o.addComponent(
				new ComponentPropertyBase("cp4"),
				new ComponentPropertyValueUri("pv4", vf
						.createURI("http://test.org#u4")));
		o.addComponent(
				new ComponentPropertyBase("cp5"),
				new ComponentPropertyValueTemporalLocation(
						"pv5",
						new TemporalLocationDateTime("tl1", dtf
								.parseDateTime("2014-02-20T18:02:00.000+02:00"))));
		o.addComponent(new ComponentPropertyBase("cp6"),
				new ComponentPropertyValueSpatialLocation("pv6",
						new SpatialLocationRegion("r1",
								new SpatialGeometryPoint("p1", p))));

		Set<Statement> s = r.createRepresentation(o);

		DatasetObservation a = r.createDatasetObservation(s);

		DatasetObservation e = new DatasetObservationBase(
				"http://example.org#o1");
		e.setDataset(new DatasetBase("http://example.org#d1"));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp1"),
				new ComponentPropertyValueDouble("http://example.org#pv1", 0.0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp2"),
				new ComponentPropertyValueInteger("http://example.org#pv2", 0));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp3"),
				new ComponentPropertyValueString("http://example.org#pv3",
						"string"));
		e.addComponent(
				new ComponentPropertyBase("http://example.org#cp4"),
				new ComponentPropertyValueUri("http://example.org#pv4", vf
						.createURI("http://test.org#u4")));
		e.addComponent(
				new ComponentPropertyBase("http://example.org#cp5"),
				new ComponentPropertyValueTemporalLocation(
						"http://example.org#pv5",
						new TemporalLocationDateTime(
								"http://example.org#tl1",
								dtf.parseDateTime("2014-02-20T18:02:00.000+02:00"))));
		e.addComponent(new ComponentPropertyBase("http://example.org#cp6"),
				new ComponentPropertyValueSpatialLocation(
						"http://example.org#pv6", new SpatialLocationRegion(
								"http://example.org#r1",
								new SpatialGeometryPoint(
										"http://example.org#p1", p))));

		assertEquals(e, a);
	}

}
