/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.rdf.test;

import java.util.HashSet;
import java.util.Set;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import org.openrdf.model.Statement;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;
import org.openrdf.model.vocabulary.OWL;
import org.openrdf.model.vocabulary.RDF;
import org.openrdf.model.vocabulary.RDFS;
import org.openrdf.model.vocabulary.XMLSchema;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.LineString;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.geom.Polygon;

import fi.uef.envi.wavellite.entity.core.Entity;
import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialGeometry;
import fi.uef.envi.wavellite.entity.core.base.FeatureBase;
import fi.uef.envi.wavellite.entity.core.base.PropertyBase;
import fi.uef.envi.wavellite.entity.core.base.SensorBase;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryLineString;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPolygon;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.observation.base.SensorObservationBase;
import fi.uef.envi.wavellite.entity.observation.base.SensorOutputBase;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfSsn;
import fi.uef.envi.wavellite.vocabulary.DUL;
import fi.uef.envi.wavellite.vocabulary.GeoSPARQL;
import fi.uef.envi.wavellite.vocabulary.SF;
import fi.uef.envi.wavellite.vocabulary.SSN;
import fi.uef.envi.wavellite.vocabulary.Time;
import fi.uef.envi.wavellite.vocabulary.WO;
import fi.uef.envi.wavellite.vocabulary.WOE;

/**
 * <p>
 * Title: EntityRepresentationRdfSsnTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationRdfSsnTest {

	private static final ValueFactory vf = ValueFactoryImpl.getInstance();
	private static final DateTimeFormatter dtf = ISODateTimeFormat
			.dateTimeParser().withOffsetParsed();

	@Test
	public void test1() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase(WO.ns + "#s1", SSN.Sensor);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				SSN.asURI.Sensor));

		assertEquals(e, a);
	}

	@Test
	public void test1a() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Entity s = new SensorBase(WO.ns + "#s1", SSN.Sensor);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				SSN.asURI.Sensor));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase(WO.ns + "#s2", SSN.Sensor);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				SSN.asURI.Sensor));

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase(WO.ns + "#s1");
		Property p = new PropertyBase(WO.ns + "#p1");
		Feature f = new FeatureBase(WO.ns + "#f1");
		SensorOutput o = new SensorOutputBase(WO.ns + "#o1");
		ObservationValue v = new ObservationValueDouble(WO.ns + "#v1");
		o.setObservationValue(v);
		v.setValue(0.0);

		SensorObservation so = new SensorObservationBase(WO.ns + "#so1");
		so.setSensor(s);
		so.setProperty(p);
		so.setFeature(f);
		so.setSensorOutput(o);
		so.setTemporalLocation(new TemporalLocationDateTime(WO.ns + "#tl1", dtf
				.parseDateTime("2013-10-31T00:00:00.000+02:00")));

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				SSN.asURI.Sensor));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				SSN.asURI.Property));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#f1"), RDF.TYPE,
				SSN.asURI.FeatureOfInterest));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				SSN.asURI.SensorOutput));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				SSN.asURI.ObservationValue));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observedBy, vf.createURI(WO.ns + "#s1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observedProperty, vf.createURI(WO.ns + "#p1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.featureOfInterest, vf.createURI(WO.ns + "#f1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observationResult, vf.createURI(WO.ns + "#o1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				DUL.asURI.hasRegion, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				DUL.asURI.hasRegionDataValue, vf.createLiteral(0.0)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observationResultTime, vf.createURI(WO.ns + "#tl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-10-31T00:00:00.000+02:00", XMLSchema.DATETIME)));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase(WO.ns + "#s1");
		Property p = new PropertyBase(WO.ns + "#p1");
		Feature f = new FeatureBase(WO.ns + "#f1");
		SensorOutput o = new SensorOutputBase(WO.ns + "#o1");
		ObservationValue v = new ObservationValueDouble(WO.ns + "#v1");
		o.setObservationValue(v);
		v.setValue(0.5);

		SensorObservation so = new SensorObservationBase(WO.ns + "#so1");
		so.setSensor(s);
		so.setProperty(p);
		so.setFeature(f);
		so.setSensorOutput(o);
		so.setTemporalLocation(new TemporalLocationDateTime(WO.ns + "#tl1", dtf
				.parseDateTime("2013-10-31T00:00:00.000+02:00")));

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				SSN.asURI.Sensor));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				SSN.asURI.Property));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#f1"), RDF.TYPE,
				SSN.asURI.Property));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				SSN.asURI.SensorOutput));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				SSN.asURI.ObservationValue));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observedBy, vf.createURI(WO.ns + "#s1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observedProperty, vf.createURI(WO.ns + "#p1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.featureOfInterest, vf.createURI(WO.ns + "#f1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observationResult, vf.createURI(WO.ns + "#o1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				DUL.asURI.hasRegion, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				DUL.asURI.hasRegionDataValue, vf.createLiteral(0.0)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observationResultTime, vf.createURI(WO.ns + "#tl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-10-31T00:00:00.000+02:00", XMLSchema.DATETIME)));

		assertNotEquals(e, a);
	}

	@Test
	public void test5() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn(
				"http://example.org#");

		Sensor s = new SensorBase("#s1");
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI("http://example.org#s1"),
				RDF.TYPE, SSN.asURI.Sensor));

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Property p = new PropertyBase("p1");
		Set<Statement> a = r.createRepresentation(p);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				SSN.asURI.Property));

		assertEquals(e, a);
	}

	@Test
	public void test7() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Property p = new PropertyBase("p2");
		Set<Statement> a = r.createRepresentation(p);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				SSN.asURI.Property));

		assertNotEquals(e, a);
	}

	@Test
	public void test8() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Feature f = new FeatureBase("f1");
		Set<Statement> a = r.createRepresentation(f);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#f1"), RDF.TYPE,
				SSN.asURI.FeatureOfInterest));

		assertEquals(e, a);
	}

	@Test
	public void test9() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Feature f = new FeatureBase("f2");
		Set<Statement> a = r.createRepresentation(f);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#f1"), RDF.TYPE,
				SSN.asURI.FeatureOfInterest));

		assertNotEquals(e, a);
	}

	@Test
	public void test10() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		SensorOutput o = new SensorOutputBase(WO.ns + "#so1");
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				SSN.asURI.SensorOutput));

		assertEquals(e, a);
	}

	@Test
	public void test11() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		SensorOutput o = new SensorOutputBase(WO.ns + "#so2");
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				SSN.asURI.SensorOutput));

		assertNotEquals(e, a);
	}

	@Test
	public void test12() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		ObservationValue v = new ObservationValueDouble(WO.ns + "#ov1", 0.0);
		Set<Statement> a = r.createRepresentation(v);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ov1"), RDF.TYPE,
				SSN.asURI.ObservationValue));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ov1"),
				DUL.asURI.hasRegionDataValue, vf.createLiteral(0.0)));

		assertEquals(e, a);
	}

	@Test
	public void test13() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		ObservationValue v = new ObservationValueDouble(WO.ns + "#ov1", 0.5);
		Set<Statement> a = r.createRepresentation(v);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ov1"), RDF.TYPE,
				SSN.asURI.ObservationValue));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ov1"),
				DUL.asURI.hasRegionDataValue, vf.createLiteral(0.0)));

		assertNotEquals(e, a);
	}

	@Test
	public void test14() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		SensorOutput o = new SensorOutputBase(WO.ns + "#so1",
				new ObservationValueDouble(WO.ns + "#ov1", 0.0));
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				SSN.asURI.SensorOutput));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				DUL.asURI.hasRegion, vf.createURI(WO.ns + "#ov1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ov1"), RDF.TYPE,
				SSN.asURI.ObservationValue));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ov1"),
				DUL.asURI.hasRegionDataValue, vf.createLiteral(0.0)));

		assertEquals(e, a);
	}

	@Test
	public void test15() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		SensorOutput o = new SensorOutputBase(WO.ns + "#so1",
				new ObservationValueDouble(WO.ns + "#ov1", 0.5));
		Set<Statement> a = r.createRepresentation(o);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				SSN.asURI.SensorOutput));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				DUL.asURI.hasRegion, vf.createURI(WO.ns + "#ov1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ov1"), RDF.TYPE,
				SSN.asURI.ObservationValue));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ov1"),
				DUL.asURI.hasRegionDataValue, vf.createLiteral(0.0)));

		assertNotEquals(e, a);
	}

	@Test
	public void test20() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase(WO.ns + "#s1");
		Property p = new PropertyBase(WO.ns + "#p1");
		Feature f = new FeatureBase(WO.ns + "#f1");
		SensorOutput o = new SensorOutputBase(WO.ns + "#o1");
		ObservationValue v = new ObservationValueDouble(WO.ns + "#v1");
		o.setObservationValue(v);
		v.setValue(0.0);

		SensorObservation so = new SensorObservationBase(WO.ns + "#so1");
		so.setSensor(s);
		so.setProperty(p);
		so.setFeature(f);
		so.setSensorOutput(o);
		so.setTemporalLocation(new TemporalLocationInterval(WO.ns + "#tl1",
				new TemporalLocationDateTime(WO.ns + "#l1", dtf
						.parseDateTime("2013-10-31T00:00:00.000+02:00")),
				new TemporalLocationDateTime(WO.ns + "#l2", dtf
						.parseDateTime("2013-10-31T01:00:00.000+02:00"))));

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				SSN.asURI.Sensor));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				SSN.asURI.Property));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#f1"), RDF.TYPE,
				SSN.asURI.FeatureOfInterest));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				SSN.asURI.SensorOutput));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				SSN.asURI.ObservationValue));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observedBy, vf.createURI(WO.ns + "#s1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observedProperty, vf.createURI(WO.ns + "#p1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.featureOfInterest, vf.createURI(WO.ns + "#f1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observationResult, vf.createURI(WO.ns + "#o1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				DUL.asURI.hasRegion, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				DUL.asURI.hasRegionDataValue, vf.createLiteral(0.0)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observationResultTime, vf.createURI(WO.ns + "#tl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimeInterval));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasBeginning, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-10-31T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasEnd, vf.createURI(WO.ns + "#l2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-10-31T01:00:00.000+02:00", XMLSchema.DATETIME)));

		assertEquals(e, a);
	}

	@Test
	public void test21() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase(WO.ns + "#s1");
		Property p = new PropertyBase(WO.ns + "#p1");
		Feature f = new FeatureBase(WO.ns + "#f1");
		SensorOutput o = new SensorOutputBase(WO.ns + "#o1");
		ObservationValue v = new ObservationValueDouble(WO.ns + "#v1");
		o.setObservationValue(v);
		v.setValue(0.0);

		SensorObservation so = new SensorObservationBase(WO.ns + "#so1");
		so.setSensor(s);
		so.setProperty(p);
		so.setFeature(f);
		so.setSensorOutput(o);
		so.setTemporalLocation(new TemporalLocationInterval(WO.ns + "#tl1",
				new TemporalLocationDateTime(WO.ns + "#l1", dtf
						.parseDateTime("2013-10-31T00:00:00.000+02:00")),
				new TemporalLocationDateTime(WO.ns + "#l2", dtf
						.parseDateTime("2013-10-31T01:00:00.000+02:00"))));

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				SSN.asURI.Sensor));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#p1"), RDF.TYPE,
				SSN.asURI.Property));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#f1"), RDF.TYPE,
				SSN.asURI.FeatureOfInterest));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				SSN.asURI.SensorOutput));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				SSN.asURI.ObservationValue));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observedBy, vf.createURI(WO.ns + "#s1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observedProperty, vf.createURI(WO.ns + "#p1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.featureOfInterest, vf.createURI(WO.ns + "#f1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observationResult, vf.createURI(WO.ns + "#o1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"),
				DUL.asURI.hasRegion, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				DUL.asURI.hasRegionDataValue, vf.createLiteral(0.0)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				SSN.asURI.observationResultTime, vf.createURI(WO.ns + "#tl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimeInterval));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasBeginning, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-10-31T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasEnd, vf.createURI(WO.ns + "#l2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-10-31T02:00:00.000+02:00", XMLSchema.DATETIME)));

		assertNotEquals(e, a);
	}

	@Test
	public void test22() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		SensorObservation so = new SensorObservationBase("so1");
		so.setSpatialLocation(new SpatialLocationPlace("sl1", "l1"));

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				WOE.asURI.observationResultLocation,
				vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDFS.LABEL,
				vf.createLiteral("l1")));

		assertEquals(e, a);
	}

	@Test
	public void test23() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		SensorObservation so = new SensorObservationBase("so1");
		so.setSpatialLocation(new SpatialLocationPlace("sl1", "l1"));

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				DUL.asURI.hasLocation, vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDFS.LABEL,
				vf.createLiteral("l2")));

		assertNotEquals(e, a);
	}

	@Test
	public void test25() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		SensorObservation so = new SensorObservationBase("so1");
		SpatialLocationPlace sl = new SpatialLocationPlace("sl1", "l1");
		sl.addSameAs(vf.createURI("http://example.org#1"));
		so.setSpatialLocation(sl);

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				WOE.asURI.observationResultLocation,
				vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDFS.LABEL,
				vf.createLiteral("l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), OWL.SAMEAS,
				vf.createURI("http://example.org#1")));

		assertEquals(e, a);
	}

	@Test
	public void test26() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		SensorObservation so = new SensorObservationBase("so1");
		SpatialLocationPlace sl = new SpatialLocationPlace("sl1", "l1");
		sl.addSameAs(vf.createURI("http://example.org#1"));
		so.setSpatialLocation(sl);

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				WOE.asURI.observationResultLocation,
				vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDFS.LABEL,
				vf.createLiteral("l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), OWL.SAMEAS,
				vf.createURI("http://example.org#2")));

		assertNotEquals(e, a);
	}

	@Test
	public void test27() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		GeometryFactory gf = new GeometryFactory();
		Point p = gf.createPoint(new Coordinate(0.0, 0.0));

		SensorObservation so = new SensorObservationBase("so1");
		SpatialGeometry sg = new SpatialGeometryPoint("l1", p);
		SpatialLocationRegion sl = new SpatialLocationRegion("sl1", sg);
		so.setSpatialLocation(sl);

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.Point));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				WOE.asURI.observationResultLocation,
				vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asWKT, vf.createLiteral(sg.getValueAsWKT(),
						GeoSPARQL.asURI.wktLiteral)));

		assertEquals(e, a);
	}

	@Test
	public void test28() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		GeometryFactory gf = new GeometryFactory();
		Point p1 = gf.createPoint(new Coordinate(0.0, 0.0));
		Point p2 = gf.createPoint(new Coordinate(1.0, 1.0));

		SensorObservation so = new SensorObservationBase("so1");
		SpatialGeometry sg1 = new SpatialGeometryPoint("l1", p1);
		SpatialGeometry sg2 = new SpatialGeometryPoint("l1", p2);
		SpatialLocationRegion sl = new SpatialLocationRegion("sl1", sg1);
		so.setSpatialLocation(sl);

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.Point));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				WOE.asURI.observationResultLocation,
				vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asWKT, vf.createLiteral(
						"<![CDATA[" + sg2.getValueAsWKT() + "]]>",
						GeoSPARQL.asURI.wktLiteral)));

		assertNotEquals(e, a);
	}

	@Test
	public void test29() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		GeometryFactory gf = new GeometryFactory();
		Polygon p = gf.createPolygon(new Coordinate[] {
				new Coordinate(0.0, 0.0), new Coordinate(1.0, 1.0),
				new Coordinate(-1.0, -1.0), new Coordinate(0.0, 0.0) });

		SensorObservation so = new SensorObservationBase("so1");
		SpatialGeometry sg = new SpatialGeometryPolygon("l1", p);
		SpatialLocationRegion sl = new SpatialLocationRegion("sl1", sg);
		so.setSpatialLocation(sl);

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.Polygon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				WOE.asURI.observationResultLocation,
				vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asWKT, vf.createLiteral(sg.getValueAsWKT(),
						GeoSPARQL.asURI.wktLiteral)));

		assertEquals(e, a);
	}

	@Test
	public void test30() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		GeometryFactory gf = new GeometryFactory();
		LineString p = gf.createLineString(new Coordinate[] {
				new Coordinate(0.0, 0.0), new Coordinate(1.0, 1.0) });

		SensorObservation so = new SensorObservationBase("so1");
		SpatialGeometry sg = new SpatialGeometryLineString("l1", p);
		SpatialLocationRegion sl = new SpatialLocationRegion("sl1", sg);
		so.setSpatialLocation(sl);

		Set<Statement> a = r.createRepresentation(so);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"), RDF.TYPE,
				WOE.asURI.SensorObservation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.LineString));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#so1"),
				WOE.asURI.observationResultLocation,
				vf.createURI(WO.ns + "#sl1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#sl1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asWKT, vf.createLiteral(sg.getValueAsWKT(),
						GeoSPARQL.asURI.wktLiteral)));

		assertEquals(e, a);
	}

	@Test
	public void test31() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn(
				"http://example.org");

		SensorObservation o = new SensorObservationBase("o1");
		o.setSensor(new SensorBase("s1"));
		o.setProperty(new PropertyBase("p1"));
		o.setFeature(new FeatureBase("f1"));

		Set<Statement> statements = r.createRepresentation(o);

		SensorObservation a = r.createSensorObservation(statements);

		SensorObservation e = new SensorObservationBase("http://example.org#o1");
		e.setSensor(new SensorBase("http://example.org#s1"));
		e.setProperty(new PropertyBase("http://example.org#p1"));
		e.setFeature(new FeatureBase("http://example.org#f1"));

		assertEquals(e, a);
	}

	@Test
	public void test32() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn(
				"http://example.org");

		SensorObservation o = new SensorObservationBase("o1");

		Set<Statement> statements = r.createRepresentation(o);

		SensorObservation a = r.createSensorObservation(statements);

		SensorObservation e = new SensorObservationBase("http://example.org#o1");

		assertEquals(e, a);
	}

	@Test
	public void test33() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn(
				"http://example.org");

		SensorObservation o = new SensorObservationBase("o1");
		o.setSensorOutput(new SensorOutputBase("so1",
				new ObservationValueDouble("ov1", 0.0)));

		Set<Statement> statements = r.createRepresentation(o);

		SensorObservation a = r.createSensorObservation(statements);

		SensorObservation e = new SensorObservationBase("http://example.org#o1");
		e.setSensorOutput(new SensorOutputBase("http://example.org#so1",
				new ObservationValueDouble("http://example.org#ov1", 0.0)));

		assertEquals(e, a);
	}

	@Test
	public void test34() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn(
				"http://example.org");

		SensorObservation o = new SensorObservationBase("o1");
		o.setTemporalLocation(new TemporalLocationDateTime("tl1", dtf
				.parseDateTime("2014-02-17T00:00:00.000+02:00")));

		Set<Statement> statements = r.createRepresentation(o);

		SensorObservation a = r.createSensorObservation(statements);

		SensorObservation e = new SensorObservationBase("http://example.org#o1");
		e.setTemporalLocation(new TemporalLocationDateTime(
				"http://example.org#tl1", dtf
						.parseDateTime("2014-02-17T00:00:00.000+02:00")));

		assertEquals(e, a);
	}

	@Test
	public void test35() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn(
				"http://example.org");

		SensorObservation o = new SensorObservationBase("o1");
		o.setSensor(new SensorBase("s1"));
		o.setTemporalLocation(new TemporalLocationInterval("tl1",
				new TemporalLocationDateTime("dt1", dtf
						.parseDateTime("2014-02-17T00:00:00.000+02:00")),
				new TemporalLocationDateTime("dt2", dtf
						.parseDateTime("2014-02-17T01:00:00.000+02:00"))));

		Set<Statement> statements = r.createRepresentation(o);

		SensorObservation a = r.createSensorObservation(statements);

		SensorObservation e = new SensorObservationBase("http://example.org#o1");
		e.setSensor(new SensorBase("http://example.org#s1"));
		e.setTemporalLocation(new TemporalLocationInterval("tl1",
				new TemporalLocationDateTime("dt1", dtf
						.parseDateTime("2014-02-17T00:00:00.000+02:00")),
				new TemporalLocationDateTime("dt2", dtf
						.parseDateTime("2014-02-17T01:00:00.000+02:00"))));

		assertEquals(e, a);
	}

	@Test
	public void test37() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn(
				"http://example.org");

		SensorObservation o = new SensorObservationBase("o1");
		o.setSpatialLocation(new SpatialLocationPlace("sl1", "p1"));

		Set<Statement> statements = r.createRepresentation(o);

		SensorObservation a = r.createSensorObservation(statements);

		SensorObservation e = new SensorObservationBase("http://example.org#o1");
		e.setSpatialLocation(new SpatialLocationPlace("http://example.org#sl1",
				"p1"));

		assertEquals(e, a);
	}

	@Test
	public void test38() {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn(
				"http://example.org");

		SensorObservation o = new SensorObservationBase("o1");

		GeometryFactory gf = new GeometryFactory();
		Point p1 = gf.createPoint(new Coordinate(0.0, 0.0));
		SpatialGeometry g1 = new SpatialGeometryPoint("p1");
		g1.setValue(p1);

		SpatialLocationRegion l = new SpatialLocationRegion("sl1");
		l.setSpatialGeometry(g1);

		o.setSpatialLocation(l);

		Set<Statement> statements = r.createRepresentation(o);

		SensorObservation a = r.createSensorObservation(statements);

		SensorObservation e = new SensorObservationBase("http://example.org#o1");
		e.setSpatialLocation(l);

		assertEquals(e, a);
	}

}
