/*
 * Copyright (C) 2013 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.rdf.test;

import java.util.HashSet;
import java.util.Set;

import org.joda.time.DateTime;
import org.joda.time.Period;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import org.openrdf.model.Statement;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;
import org.openrdf.model.vocabulary.RDF;
import org.openrdf.model.vocabulary.RDFS;
import org.openrdf.model.vocabulary.XMLSchema;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.Point;

import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.situation.Attribute;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.RelevantIndividual;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeValue;
import fi.uef.envi.wavellite.entity.situation.base.ValueDouble;
import fi.uef.envi.wavellite.entity.situation.base.ValueInteger;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.ValuePeriod;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.entity.situation.base.ElementaryInfonBase;
import fi.uef.envi.wavellite.entity.situation.base.RelationBase;
import fi.uef.envi.wavellite.entity.situation.base.RelevantIndividualBase;
import fi.uef.envi.wavellite.entity.situation.base.SituationBase;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfSto;
import fi.uef.envi.wavellite.vocabulary.GeoSPARQL;
import fi.uef.envi.wavellite.vocabulary.SF;
import fi.uef.envi.wavellite.vocabulary.STO;
import fi.uef.envi.wavellite.vocabulary.Time;
import fi.uef.envi.wavellite.vocabulary.WO;
import fi.uef.envi.wavellite.vocabulary.WOE;

/**
 * <p>
 * Title: EntityRepresentationRdfStoTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2013
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationRdfStoTest {

	private static final ValueFactory vf = ValueFactoryImpl.getInstance();
	private static final DateTimeFormatter dtf1 = ISODateTimeFormat
			.dateTimeParser().withOffsetParsed();
	private static final DateTimeFormatter dtf2 = ISODateTimeFormat.dateTime()
			.withOffsetParsed();

	@Test
	public void test1() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase(WO.ns + "#s1");
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				STO.asURI.Situation));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase(WO.ns + "#s1");
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s2"), RDF.TYPE,
				STO.asURI.Situation));

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		ElementaryInfon i = new ElementaryInfonBase(WO.ns + "#i1");
		i.setRelation(new RelationBase(WO.ns + "#r1"));
		i.setPolarity(Polarity.True);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				STO.asURI.Relation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.relation, vf.createURI(WO.ns + "#r1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		ElementaryInfon i = new ElementaryInfonBase(WO.ns + "#i1");
		i.setRelation(new RelationBase(WO.ns + "#r1"));
		i.setPolarity(Polarity.True);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				STO.asURI.Relation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.relation, vf.createURI(WO.ns + "#r1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.polarity, STO.asURI._0));

		assertNotEquals(e, a);
	}

	@Test
	public void test5() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase(WO.ns + "#s1");
		ElementaryInfon i = new ElementaryInfonBase(WO.ns + "#i1");
		i.setRelation(new RelationBase(WO.ns + "#r1"));
		i.setPolarity(Polarity.True);
		s.addSupportedInfon(i);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				STO.asURI.Situation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				STO.asURI.Relation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"),
				STO.asURI.supportedInfon, vf.createURI(WO.ns + "#i1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.relation, vf.createURI(WO.ns + "#r1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase(WO.ns + "#s1");
		ElementaryInfon i = new ElementaryInfonBase(WO.ns + "#i1");
		i.setRelation(new RelationBase(WO.ns + "#r1"));
		i.setPolarity(Polarity.True);
		s.addSupportedInfon(i);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				STO.asURI.Situation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				STO.asURI.Relation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"),
				STO.asURI.supportedInfon, vf.createURI(WO.ns + "#i1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.relation, vf.createURI(WO.ns + "#r1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.polarity, STO.asURI._0));

		assertNotEquals(e, a);
	}

	@Test
	public void test7() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase(WO.ns + "#i1");
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));

		assertEquals(e, a);
	}

	@Test
	public void test8() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase(WO.ns + "#i1");
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i2"), RDF.TYPE,
				STO.asURI.RelevantIndividual));

		assertNotEquals(e, a);
	}

	@Test
	public void test9() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase(WO.ns + "#s1");
		ElementaryInfon i = new ElementaryInfonBase(WO.ns + "#i1");
		i.setRelation(new RelationBase(WO.ns + "#r1"));
		i.setPolarity(Polarity.True);
		s.addSupportedInfon(i);
		RelevantIndividual o = new RelevantIndividualBase(WO.ns + "#o1");
		i.addRelevantObject(o);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				STO.asURI.Situation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				STO.asURI.Relation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#o1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"),
				STO.asURI.supportedInfon, vf.createURI(WO.ns + "#i1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.relation, vf.createURI(WO.ns + "#r1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#o1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test10() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase(WO.ns + "#i1");
		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		i.addAttribute(a1);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.hasAttribute, vf.createURI(WO.ns + "#a1")));

		assertEquals(e, a);
	}

	@Test
	public void test11() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase(WO.ns + "#i1");
		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		i.addAttribute(a1);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.hasAttribute, vf.createURI(WO.ns + "#a2")));

		assertNotEquals(e, a);
	}

	@Test
	public void test12() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setValue(new ValueDouble(WO.ns + "#v1", 0.0));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"),
				STO.asURI.hasAttributeValue, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				STO.asURI.attributeValue, vf.createLiteral(0.0)));

		assertEquals(e, a);
	}

	@Test
	public void test13() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setValue(new ValueDouble(WO.ns + "#v1", 0.0));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"),
				STO.asURI.hasAttributeValue, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				STO.asURI.attributeValue, vf.createLiteral(0.5)));

		assertNotEquals(e, a);
	}

	@Test
	public void test14() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeTemporalLocation(WO.ns + "#v1",
				new TemporalLocationDateTime(WO.ns + "#t1", new DateTime(2013,
						11, 05, 0, 0, 0)));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						dtf2.print(new DateTime(2013, 11, 05, 0, 0, 0)),
						XMLSchema.DATETIME)));

		assertEquals(e, a);
	}

	@Test
	public void test15() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeTemporalLocation(WO.ns + "#v1",
				new TemporalLocationDateTime(WO.ns + "#t1", new DateTime(2013,
						11, 05, 0, 0, 0)));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						dtf2.print(new DateTime(2013, 11, 05, 1, 0, 0)),
						XMLSchema.DATETIME)));

		assertNotEquals(e, a);
	}

	@Test
	public void test16() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setValue(new ValueString(WO.ns + "#v1", "v1"));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"),
				STO.asURI.hasAttributeValue, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				STO.asURI.attributeValue,
				vf.createLiteral("v1", XMLSchema.STRING)));

		assertEquals(e, a);
	}

	@Test
	public void test17() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setValue(new ValueString(WO.ns + "#v1", "v1"));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"),
				STO.asURI.hasAttributeValue, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				STO.asURI.attributeValue,
				vf.createLiteral("v2", XMLSchema.STRING)));

		assertNotEquals(e, a);
	}

	@Test
	public void test18() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeTemporalLocation("v1",
				new TemporalLocationInterval("tl1",
						new TemporalLocationDateTime("l1", new DateTime(2013,
								11, 5, 0, 0, 0)), new TemporalLocationDateTime(
								"l2", new DateTime(2013, 11, 5, 1, 0, 0))));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimeInterval));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasBeginning, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-11-05T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasEnd, vf.createURI(WO.ns + "#l2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-11-05T01:00:00.000+02:00", XMLSchema.DATETIME)));

		assertEquals(e, a);
	}

	@Test
	public void test19() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeTemporalLocation("v1",
				new TemporalLocationInterval("tl1",
						new TemporalLocationDateTime("l1", new DateTime(2013,
								11, 5, 0, 0, 0)), new TemporalLocationDateTime(
								"l2", new DateTime(2013, 11, 5, 1, 0, 0))));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimeInterval));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasBeginning, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-11-05T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasEnd, vf.createURI(WO.ns + "#l2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-11-05T02:00:00.000+02:00", XMLSchema.DATETIME)));

		assertNotEquals(e, a);
	}

	@Test
	public void test20() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setValue(new ValueInteger(WO.ns + "#v1", 0));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"),
				STO.asURI.hasAttributeValue, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				STO.asURI.attributeValue, vf.createLiteral(0)));

		assertEquals(e, a);
	}

	@Test
	public void test21() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setValue(new ValueInteger(WO.ns + "#v1", 0));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"),
				STO.asURI.hasAttributeValue, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				STO.asURI.attributeValue, vf.createLiteral(1)));

		assertNotEquals(e, a);
	}

	@Test
	public void test22() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeUri(WO.ns + "#a1",
				vf.createURI("http://example.org#s1"));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI("http://example.org#s1"),
				RDF.TYPE, STO.asURI.Attribute));

		assertEquals(e, a);
	}

	@Test
	public void test23() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeUri(WO.ns + "#a1",
				vf.createURI("http://example.org#s1"));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI("http://example.org#s2"),
				RDF.TYPE, STO.asURI.Attribute));

		assertNotEquals(e, a);
	}

	@Test
	public void test24() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeSpatialLocation(WO.ns + "#v1",
				new SpatialLocationPlace(WO.ns + "#t1", "l1"));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"), RDFS.LABEL,
				vf.createLiteral("l1")));

		assertEquals(e, a);
	}

	@Test
	public void test25() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeSpatialLocation(WO.ns + "#v1",
				new SpatialLocationPlace(WO.ns + "#t1", "l1"));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"), RDFS.LABEL,
				vf.createLiteral("l2")));

		assertNotEquals(e, a);
	}

	@Test
	public void test26() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		GeometryFactory gf = new GeometryFactory();
		Point p = gf.createPoint(new Coordinate(0.0, 0.0));

		Attribute a1 = new AttributeSpatialLocation("v1",
				new SpatialLocationRegion("t1", new SpatialGeometryPoint("l1",
						p)));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"), RDF.TYPE,
				WOE.asURI.SpatialRegion));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				SF.asURI.Point));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#t1"),
				GeoSPARQL.asURI.hasGeometry, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				GeoSPARQL.asURI.asWKT, vf.createLiteral(
						new SpatialGeometryPoint(p).getValueAsWKT(),
						GeoSPARQL.asURI.wktLiteral)));

		assertEquals(e, a);
	}

	@Test
	public void test27() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase(WO.ns + "#s1");
		ElementaryInfon i = new ElementaryInfonBase(WO.ns + "#i1");
		i.setRelation(new RelationBase(WO.ns + "#r1"));
		i.setPolarity(Polarity.True);
		s.addSupportedInfon(i);
		RelevantObject o = new AttributeSpatialLocation(WO.ns + "#o1",
				new SpatialLocationPlace("l1", "p1"));
		i.addRelevantObject(o);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				STO.asURI.Situation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				STO.asURI.Relation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"),
				STO.asURI.supportedInfon, vf.createURI(WO.ns + "#i1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.relation, vf.createURI(WO.ns + "#r1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDFS.LABEL,
				vf.createLiteral("p1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test28() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase(WO.ns + "#s1");
		ElementaryInfon i = new ElementaryInfonBase(WO.ns + "#i1");
		i.setRelation(new RelationBase(WO.ns + "#r1"));
		i.setPolarity(Polarity.True);
		s.addSupportedInfon(i);
		RelevantObject o = new AttributeSpatialLocation(WO.ns + "#o1",
				new SpatialLocationPlace("l1", "p1"));
		i.addRelevantObject(o);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				STO.asURI.Situation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				STO.asURI.Relation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"),
				STO.asURI.supportedInfon, vf.createURI(WO.ns + "#i1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.relation, vf.createURI(WO.ns + "#r1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDFS.LABEL,
				vf.createLiteral("p2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.polarity, STO.asURI._1));

		assertNotEquals(e, a);
	}

	@Test
	public void test29() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase("s1");
		ElementaryInfon i = new ElementaryInfonBase("i1");
		i.setRelation(new RelationBase("r1"));
		i.setPolarity(Polarity.True);
		s.addSupportedInfon(i);
		RelevantObject o = new AttributeTemporalLocation("o1",
				new TemporalLocationDateTime("l1", new DateTime(
						"2014-01-10T01:00:00.000+02:00")));
		i.addRelevantObject(o);
		Set<Statement> a = r.createRepresentation(s);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"), RDF.TYPE,
				STO.asURI.Situation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#r1"), RDF.TYPE,
				STO.asURI.Relation));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#s1"),
				STO.asURI.supportedInfon, vf.createURI(WO.ns + "#i1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.relation, vf.createURI(WO.ns + "#r1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-10T01:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test30() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setValue(new ValuePeriod(WO.ns + "#v1", new Period(new DateTime(
				2000, 1, 1, 0, 0, 0), new DateTime(2000, 1, 1, 0, 0, 1))));
		Set<Statement> a = r.createRepresentation(a1);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"),
				STO.asURI.hasAttributeValue, vf.createURI(WO.ns + "#v1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#v1"),
				STO.asURI.attributeValue,
				vf.createLiteral("PT1S", XMLSchema.DURATION)));

		assertEquals(e, a);
	}

	@Test
	public void test31() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase("i1");
		Attribute a1 = new AttributeSpatialLocation("a1");
		a1.setValue(new SpatialLocationPlace("l1"));
		i.addAttribute(a1);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.hasAttribute, vf.createURI(WO.ns + "#l1")));

		assertEquals(e, a);
	}

	@Test
	public void test32() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase("i1");
		Attribute a1 = new AttributeTemporalLocation("a1");
		a1.setValue(new TemporalLocationDateTime("l1", new DateTime(2011, 1, 1,
				0, 0, 0)));
		i.addAttribute(a1);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.hasAttribute, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						dtf2.print(new DateTime(2011, 1, 1, 0, 0, 0)),
						XMLSchema.DATETIME)));

		assertEquals(e, a);
	}

	@Test
	public void test33() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase("i1");
		Attribute a1 = new AttributeUri("a1", vf.createURI(WO.ns + "#u1"));
		i.addAttribute(a1);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#u1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.hasAttribute, vf.createURI(WO.ns + "#u1")));

		assertEquals(e, a);
	}

	@Test
	public void test34() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		ElementaryInfon ei = new ElementaryInfonBase("ei1");
		RelevantIndividual ri = new RelevantIndividualBase("ri1");
		Attribute a1 = new AttributeUri(vf.createURI(WO.ns + "#u1"));
		ri.addAttribute(a1);
		ei.addRelevantObject(ri);
		ei.addRelevantObject(new AttributeUri(vf.createURI(WO.ns + "#u2")));
		Set<Statement> a = r.createRepresentation(ei);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ri1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#u1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#u2"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#ri1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ri1"),
				STO.asURI.hasAttribute, vf.createURI(WO.ns + "#u1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.anchor2, vf.createURI(WO.ns + "#u2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test35() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		ElementaryInfon ei = new ElementaryInfonBase("ei1");
		ValueDouble ro = new ValueDouble("ro1", 0.0);
		ei.addRelevantObject(ro);
		Set<Statement> a = r.createRepresentation(ei);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ro1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#ro1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ro1"),
				STO.asURI.attributeValue,
				vf.createLiteral("0.0", XMLSchema.DOUBLE)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test36() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		ElementaryInfon ei = new ElementaryInfonBase("ei1");
		ValueInteger ro = new ValueInteger("ro1", 0);
		ei.addRelevantObject(ro);
		Set<Statement> a = r.createRepresentation(ei);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ro1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#ro1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ro1"),
				STO.asURI.attributeValue, vf.createLiteral("0", XMLSchema.INT)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test37() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		ElementaryInfon ei = new ElementaryInfonBase("ei1");
		ValueString ro = new ValueString("ro1", "ro1");
		ei.addRelevantObject(ro);
		Set<Statement> a = r.createRepresentation(ei);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ro1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#ro1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ro1"),
				STO.asURI.attributeValue,
				vf.createLiteral("ro1", XMLSchema.STRING)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test38() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		ElementaryInfon ei = new ElementaryInfonBase("ei1");
		ei.addRelevantObject(new ValuePeriod("ro1", new Period(dtf1
				.parseDateTime("2000-01-01T00:00:00.000+02:00"), dtf1
				.parseDateTime("2000-01-01T00:00:01.000+02:00"))));
		Set<Statement> a = r.createRepresentation(ei);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"), RDF.TYPE,
				STO.asURI.ElementaryInfon));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ro1"), RDF.TYPE,
				STO.asURI.Value));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.anchor1, vf.createURI(WO.ns + "#ro1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ro1"),
				STO.asURI.attributeValue,
				vf.createLiteral("PT1S", XMLSchema.DURATION)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#ei1"),
				STO.asURI.polarity, STO.asURI._1));

		assertEquals(e, a);
	}

	@Test
	public void test39() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase(WO.ns + "#i1");
		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setName(WO.ns + "#n1");
		i.addAttribute(a1);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.hasAttribute, vf.createURI(WO.ns + "#a1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				vf.createURI(WO.ns + "#n1"), vf.createURI(WO.ns + "#a1")));

		assertEquals(e, a);
	}

	@Test
	public void test40() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase(WO.ns + "#i1");
		Attribute a1 = new AttributeValue(WO.ns + "#a1");
		a1.setName(WO.ns + "#n1");
		i.addAttribute(a1);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#a1"), RDF.TYPE,
				STO.asURI.Attribute));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				vf.createURI(WO.ns + "#n2"), vf.createURI(WO.ns + "#a1")));

		assertNotEquals(e, a);
	}

	@Test
	public void test41() {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		RelevantIndividual i = new RelevantIndividualBase("i1");
		Attribute a1 = new AttributeSpatialLocation("a1");
		a1.setName("hasLocation");
		a1.setValue(new SpatialLocationPlace("l1"));
		i.addAttribute(a1);
		Set<Statement> a = r.createRepresentation(i);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"), RDF.TYPE,
				STO.asURI.RelevantIndividual));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.SpatialPlace));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				STO.asURI.hasAttribute, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#i1"),
				vf.createURI(WO.ns + "#hasLocation"),
				vf.createURI(WO.ns + "#l1")));

		assertEquals(e, a);
	}

}
