/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.rdf.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import java.util.HashSet;
import java.util.Set;

import org.joda.time.DateTime;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Test;
import org.openrdf.model.Statement;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;
import org.openrdf.model.vocabulary.RDF;
import org.openrdf.model.vocabulary.XMLSchema;

import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfTime;
import fi.uef.envi.wavellite.vocabulary.Time;
import fi.uef.envi.wavellite.vocabulary.WO;
import fi.uef.envi.wavellite.vocabulary.WOE;

/**
 * <p>
 * Title: EntityRepresentationRdfTimeTest
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class EntityRepresentationRdfTimeTest {

	private static final ValueFactory vf = ValueFactoryImpl.getInstance();
	private static final DateTimeFormatter dtf = ISODateTimeFormat.dateTimeParser()
			.withOffsetParsed();

	@Test
	public void test1() {
		EntityRepresentationRdfTime r = new EntityRepresentationRdfTime();

		TemporalLocation l = new TemporalLocationDateTime(WO.ns + "#tl1",
				new DateTime(2013, 10, 31, 0, 0, 0));
		Set<Statement> a = r.createRepresentation(l);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-10-31T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimePoint));

		assertEquals(e, a);
	}

	@Test
	public void test2() {
		EntityRepresentationRdfTime r = new EntityRepresentationRdfTime();

		TemporalLocation l = new TemporalLocationDateTime(WO.ns + "#tl1",
				new DateTime(2013, 10, 31, 0, 0, 0));
		Set<Statement> a = r.createRepresentation(l);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2013-11-01T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimePoint));

		assertNotEquals(e, a);
	}

	@Test
	public void test3() {
		EntityRepresentationRdfTime r = new EntityRepresentationRdfTime();

		TemporalLocation l = new TemporalLocationInterval(WO.ns + "#tl1",
				new TemporalLocationDateTime(WO.ns + "#l1", new DateTime(2014,
						1, 2, 0, 0, 0)), new TemporalLocationDateTime(WO.ns
						+ "#l2", new DateTime(2014, 1, 2, 1, 0, 0)));
		Set<Statement> a = r.createRepresentation(l);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimeInterval));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasBeginning, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasEnd, vf.createURI(WO.ns + "#l2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T01:00:00.000+02:00", XMLSchema.DATETIME)));

		assertEquals(e, a);
	}

	@Test
	public void test4() {
		EntityRepresentationRdfTime r = new EntityRepresentationRdfTime();

		TemporalLocation l = new TemporalLocationInterval(WO.ns + "#tl1",
				new TemporalLocationDateTime(WO.ns + "#l1", new DateTime(2014,
						1, 2, 0, 0, 0)), new TemporalLocationDateTime(WO.ns
						+ "#l2", new DateTime(2014, 1, 2, 1, 0, 0)));
		Set<Statement> a = r.createRepresentation(l);

		Set<Statement> e = new HashSet<Statement>();
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"), RDF.TYPE,
				WOE.asURI.TimeInterval));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasBeginning, vf.createURI(WO.ns + "#l1")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l1"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T00:00:00.000+02:00", XMLSchema.DATETIME)));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#tl1"),
				Time.asURI.hasEnd, vf.createURI(WO.ns + "#l2")));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"), RDF.TYPE,
				WOE.asURI.TimePoint));
		e.add(vf.createStatement(vf.createURI(WO.ns + "#l2"),
				Time.asURI.inXSDDateTime, vf.createLiteral(
						"2014-01-02T02:00:00.000+02:00", XMLSchema.DATETIME)));

		assertNotEquals(e, a);
	}

	@Test
	public void test5() {
		EntityRepresentationRdfTime r = new EntityRepresentationRdfTime(
				"http://example.org");

		TemporalLocation l = new TemporalLocationDateTime("tl1",
				dtf.parseDateTime("2014-02-17T00:00:00.000+02:00"));

		Set<Statement> statements = r.createRepresentation(l);

		TemporalLocation a = r.createTemporalLocation(statements);

		TemporalLocation e = new TemporalLocationDateTime(
				"http://example.org#tl1",
				dtf.parseDateTime("2014-02-17T00:00:00.000+02:00"));

		assertEquals(e, a);
	}

	@Test
	public void test6() {
		EntityRepresentationRdfTime r = new EntityRepresentationRdfTime(
				"http://example.org");

		TemporalLocationDateTime l = new TemporalLocationDateTime("tl1",
				dtf.parseDateTime("2014-02-17T00:00:00.000+02:00"));

		Set<Statement> statements = r.createRepresentation(l);

		TemporalLocationDateTime a = r
				.createTemporalLocationDateTime(statements);

		TemporalLocationDateTime e = new TemporalLocationDateTime(
				"http://example.org#tl1",
				dtf.parseDateTime("2014-02-17T00:00:00.000+02:00"));

		assertEquals(e, a);
	}

	@Test
	public void test7() {
		EntityRepresentationRdfTime r = new EntityRepresentationRdfTime(
				"http://example.org");

		TemporalLocation l = new TemporalLocationInterval("tl1",
				new TemporalLocationDateTime("dt1", dtf
						.parseDateTime("2014-02-17T00:00:00.000+02:00")),
				new TemporalLocationDateTime("dt2", dtf
						.parseDateTime("2014-02-17T01:00:00.000+02:00")));

		Set<Statement> statements = r.createRepresentation(l);

		TemporalLocation a = r.createTemporalLocation(statements);

		TemporalLocation e = new TemporalLocationInterval("tl1",
				new TemporalLocationDateTime("dt1", dtf
						.parseDateTime("2014-02-17T00:00:00.000+02:00")),
				new TemporalLocationDateTime("dt2", dtf
						.parseDateTime("2014-02-17T01:00:00.000+02:00")));

		assertEquals(e, a);
	}
	
	@Test
	public void test8() {
		EntityRepresentationRdfTime r = new EntityRepresentationRdfTime(
				"http://example.org");

		TemporalLocation l = new TemporalLocationInterval("tl1",
				new TemporalLocationDateTime("dt1", dtf
						.parseDateTime("2014-02-17T00:00:00Z")),
				new TemporalLocationDateTime("dt2", dtf
						.parseDateTime("2014-02-17T01:00:00Z")));

		Set<Statement> statements = r.createRepresentation(l);

		TemporalLocation a = r.createTemporalLocation(statements);

		TemporalLocation e = new TemporalLocationInterval("tl1",
				new TemporalLocationDateTime("dt1", dtf
						.parseDateTime("2014-02-17T00:00:00Z")),
				new TemporalLocationDateTime("dt2", dtf
						.parseDateTime("2014-02-17T01:00:00Z")));

		assertEquals(e, a);
	}

}
