/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.representation.rdf.test;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.assertFalse;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.InputStream;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.joda.time.DateTime;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;
import org.junit.Before;
import org.junit.Test;
import org.openrdf.model.Statement;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;
import org.openrdf.rio.RDFFormat;
import org.openrdf.rio.RDFHandlerException;
import org.openrdf.rio.RDFWriter;
import org.openrdf.rio.Rio;
import org.semanticweb.HermiT.Reasoner;
import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLDataFactory;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.semanticweb.owlapi.reasoner.OWLReasoner;
import org.semanticweb.owlapi.reasoner.OWLReasonerFactory;
import org.semanticweb.owlapi.util.SimpleIRIMapper;
import org.semanticweb.owlapi.vocab.OWL2Datatype;

import uk.ac.manchester.cs.owl.owlapi.OWLDatatypeImpl;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.io.WKTWriter;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.SpatialLocation;
import fi.uef.envi.wavellite.entity.core.TemporalLocation;
import fi.uef.envi.wavellite.entity.core.base.FeatureBase;
import fi.uef.envi.wavellite.entity.core.base.PropertyBase;
import fi.uef.envi.wavellite.entity.core.base.SensorBase;
import fi.uef.envi.wavellite.entity.core.base.SpatialGeometryPoint;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationPlace;
import fi.uef.envi.wavellite.entity.core.base.SpatialLocationRegion;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.derivation.DatasetObservation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyBase;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueDouble;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueSpatialLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueTemporalLocation;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyValueUri;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetObservationBase;
import fi.uef.envi.wavellite.entity.observation.ObservationValue;
import fi.uef.envi.wavellite.entity.observation.Stimulus;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.observation.SensorOutput;
import fi.uef.envi.wavellite.entity.observation.base.ObservationValueDouble;
import fi.uef.envi.wavellite.entity.observation.base.StimulusBase;
import fi.uef.envi.wavellite.entity.observation.base.SensorObservationBase;
import fi.uef.envi.wavellite.entity.observation.base.SensorOutputBase;
import fi.uef.envi.wavellite.entity.situation.ElementaryInfon;
import fi.uef.envi.wavellite.entity.situation.Polarity;
import fi.uef.envi.wavellite.entity.situation.RelevantObject;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeSpatialLocation;
import fi.uef.envi.wavellite.entity.situation.base.AttributeTemporalLocation;
import fi.uef.envi.wavellite.entity.situation.base.ElementaryInfonBase;
import fi.uef.envi.wavellite.entity.situation.base.RelationBase;
import fi.uef.envi.wavellite.entity.situation.base.RelevantIndividualBase;
import fi.uef.envi.wavellite.entity.situation.base.SituationBase;
import fi.uef.envi.wavellite.entity.situation.base.ValueString;
import fi.uef.envi.wavellite.entity.situation.base.AttributeUri;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfProv;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfQb;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfSsn;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfSto;
import fi.uef.envi.wavellite.vocabulary.DUL;
import fi.uef.envi.wavellite.vocabulary.GeoSPARQL;
import fi.uef.envi.wavellite.vocabulary.PROV;
import fi.uef.envi.wavellite.vocabulary.QB;
import fi.uef.envi.wavellite.vocabulary.SSN;
import fi.uef.envi.wavellite.vocabulary.STO;
import fi.uef.envi.wavellite.vocabulary.Time;
import fi.uef.envi.wavellite.vocabulary.WOE;

/**
 * <p>
 * Title: RdfConsistencyTests
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Representation
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class RdfConsistencyTests {

	private static OWLOntologyManager manager;
	private static final DateTimeFormatter dtf1 = ISODateTimeFormat.dateTime()
			.withOffsetParsed();
	private static final ValueFactory vf = ValueFactoryImpl.getInstance();
	private static OWLDataFactory odf;
	private static final WKTWriter ww = new WKTWriter();

	@Test
	public void test1() throws OWLOntologyCreationException {
		EntityRepresentationRdfSto r = new EntityRepresentationRdfSto();

		Situation s = new SituationBase("http://example.org#s1");
		ElementaryInfon i = new ElementaryInfonBase("http://example.org#i1");
		i.setRelation(new RelationBase("http://example.org#r1"));
		i.setPolarity(Polarity.True);
		s.addSupportedInfon(i);
		RelevantObject o = new AttributeTemporalLocation(
				"http://example.org#o1", new TemporalLocationDateTime(
						"http://example.org#l1", new DateTime(
								"2014-01-10T01:00:00.000+02:00")));
		i.addRelevantObject(o);

		Set<Statement> statements = new HashSet<Statement>();
		statements.addAll(r.createRepresentation(s));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(ontology.containsIndividualInSignature(IRI
				.create("http://example.org#s1")));
		assertTrue(ontology.containsIndividualInSignature(IRI
				.create("http://example.org#i1")));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(STO.supportedInfon)),
						odf.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#i1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(STO.relation)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#i1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#r1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(STO.polarity)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#i1")), odf
						.getOWLNamedIndividual(IRI.create(STO._1)))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(STO.anchor1)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#i1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#l1")))));

		assertTrue(ontology.containsAxiom(odf.getOWLDataPropertyAssertionAxiom(
				odf.getOWLDataProperty(IRI.create(Time.inXSDDateTime)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#l1")), odf
						.getOWLLiteral(dtf1.print(new DateTime(
								"2014-01-10T01:00:00.000+02:00")),
								OWL2Datatype.XSD_DATE_TIME))));

		assertTrue(reasoner.isConsistent());
	}

	@Test
	public void test2() throws OWLOntologyCreationException {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase("http://example.org#s1");
		Property p = new PropertyBase("http://example.org#p1");
		Feature f = new FeatureBase("http://example.org#f1");
		SensorOutput o = new SensorOutputBase("http://example.org#o1");
		ObservationValue v = new ObservationValueDouble("http://example.org#v1");
		o.setObservationValue(v);
		v.setValue(0.0);

		SensorObservation so = new SensorObservationBase(
				"http://example.org#so1");
		so.setSensor(s);
		so.setProperty(p);
		so.setFeature(f);
		so.setSensorOutput(o);
		so.setTemporalLocation(new TemporalLocationInterval(
				"http://example.org#tl1", new TemporalLocationDateTime(
						"http://example.org#l1", new DateTime(2013, 10, 31, 0,
								0, 0)), new TemporalLocationDateTime(
						"http://example.org#l2", new DateTime(2013, 10, 31, 1,
								0, 0))));

		Set<Statement> statements = new HashSet<Statement>();
		statements.addAll(r.createRepresentation(so));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(SSN.observedBy)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(
						odf.getOWLObjectProperty(IRI
								.create(SSN.observedProperty)), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#so1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#p1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(
						odf.getOWLObjectProperty(IRI
								.create(SSN.featureOfInterest)), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#so1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#f1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(
						odf.getOWLObjectProperty(IRI
								.create(SSN.observationResult)), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#so1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#o1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(DUL.hasRegion)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#o1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#v1")))));

		assertTrue(ontology.containsAxiom(odf.getOWLDataPropertyAssertionAxiom(
				odf.getOWLDataProperty(IRI.create(DUL.hasRegionDataValue)),
				odf.getOWLNamedIndividual(IRI.create("http://example.org#v1")),
				odf.getOWLLiteral(0.0))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI
								.create(SSN.observationResultTime)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl1")))));

		assertTrue(reasoner.isConsistent());
	}

	@Test
	public void test3() throws OWLOntologyCreationException {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase("http://example.org#s1");
		Property p = new PropertyBase("http://example.org#p1");
		Feature f = new FeatureBase("http://example.org#f1");
		SensorOutput o = new SensorOutputBase("http://example.org#o1");
		ObservationValue v = new ObservationValueDouble("http://example.org#v1");
		o.setObservationValue(v);
		v.setValue(0.0);

		SpatialLocation sl1 = new SpatialLocationPlace("http://example.org#sl2");

		SensorObservation so = new SensorObservationBase(
				"http://example.org#so1");
		so.setSensor(s);
		so.setProperty(p);
		so.setFeature(f);
		so.setSensorOutput(o);
		so.setSpatialLocation(sl1);
		so.setTemporalLocation(new TemporalLocationInterval(
				"http://example.org#tl1", new TemporalLocationDateTime(
						"http://example.org#l1", new DateTime(2013, 10, 31, 0,
								0, 0)), new TemporalLocationDateTime(
						"http://example.org#l2", new DateTime(2013, 10, 31, 1,
								0, 0))));

		Set<Statement> statements = new HashSet<Statement>();
		statements.addAll(r.createRepresentation(so));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(reasoner.isConsistent());
	}

	@Test
	public void test4() throws OWLOntologyCreationException {
		EntityRepresentationRdfSsn r = new EntityRepresentationRdfSsn();

		Sensor s = new SensorBase("http://example.org#s1");
		Property p = new PropertyBase("http://example.org#p1");
		Feature f = new FeatureBase("http://example.org#f1");
		SensorOutput o = new SensorOutputBase("http://example.org#o1");
		ObservationValue v = new ObservationValueDouble("http://example.org#v1");
		o.setObservationValue(v);
		v.setValue(0.0);

		GeometryFactory gf = new GeometryFactory();

		SpatialLocation sl1 = new SpatialLocationRegion(
				"http://example.org#sl1", new SpatialGeometryPoint(
						"http://example.org#g1", gf.createPoint(new Coordinate(
								0.0, 0.0))));

		SensorObservation so = new SensorObservationBase(
				"http://example.org#so1");
		so.setSensor(s);
		so.setProperty(p);
		so.setFeature(f);
		so.setSensorOutput(o);
		so.setSpatialLocation(sl1);
		so.setTemporalLocation(new TemporalLocationInterval(
				"http://example.org#tl1", new TemporalLocationDateTime(
						"http://example.org#l1", new DateTime(2013, 10, 31, 0,
								0, 0)), new TemporalLocationDateTime(
						"http://example.org#l2", new DateTime(2013, 10, 31, 1,
								0, 0))));

		Set<Statement> statements = new HashSet<Statement>();
		statements.addAll(r.createRepresentation(so));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(reasoner.isConsistent());
	}

	@Test
	public void test5() throws OWLOntologyCreationException {
		EntityRepresentationRdfQb r = new EntityRepresentationRdfQb();

		GeometryFactory gf = new GeometryFactory();
		Point p = gf.createPoint(new Coordinate(0.0, 0.0));

		DatasetObservation o = new DatasetObservationBase(
				"http://example.org#do1");
		o.setDataset(new DatasetBase("http://example.org#d1"));
		o.addComponent(new ComponentBase(new ComponentPropertyBase(
				"http://example.org#cp1"),
				new ComponentPropertyValueSpatialLocation(
						new SpatialLocationRegion("http://example.org#sl1",
								new SpatialGeometryPoint(
										"http://example.org#l1", p)))));

		Set<Statement> statements = new HashSet<Statement>();

		statements.addAll(r.createRepresentation(o));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(QB.dataSet)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#do1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#d1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI
								.create("http://example.org#cp1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#do1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#sl1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(
						odf.getOWLObjectProperty(IRI
								.create(GeoSPARQL.hasGeometry)), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#sl1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#l1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLDataPropertyAssertionAxiom(odf
						.getOWLDataProperty(IRI.create(GeoSPARQL.asWKT)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#l1")), odf
						.getOWLLiteral(
								ww.write(p),
								new OWLDatatypeImpl(IRI
										.create(GeoSPARQL.wktLiteral))))));

		assertTrue(reasoner.isConsistent());
	}

	@Test
	public void test6() throws OWLOntologyCreationException {
		EntityRepresentationRdfSsn r1 = new EntityRepresentationRdfSsn();
		EntityRepresentationRdfSto r2 = new EntityRepresentationRdfSto();

		SensorObservation o = new SensorObservationBase(
				"http://example.org#observation1");
		o.setSensor(new SensorBase("http://example.org#sensor1"));

		Situation s = new SituationBase("http://example.org#situation1");
		ElementaryInfon i = new ElementaryInfonBase("http://example.org#infon1");
		i.addRelevantObject(new RelevantIndividualBase(
				"http://example.org#sensor1"));
		s.addSupportedInfon(i);

		Set<Statement> statements = new HashSet<Statement>();

		statements.addAll(r1.createRepresentation(o));
		statements.addAll(r2.createRepresentation(s));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(reasoner.isEntailed(odf.getOWLClassAssertionAxiom(odf
				.getOWLClass(IRI.create(SSN.Sensor)),
				odf.getOWLNamedIndividual(IRI
						.create("http://example.org#sensor1")))));

		assertTrue(reasoner.isEntailed(odf.getOWLClassAssertionAxiom(odf
				.getOWLClass(IRI.create(STO.RelevantIndividual)),
				odf.getOWLNamedIndividual(IRI
						.create("http://example.org#sensor1")))));

		assertTrue(reasoner.isConsistent());
	}

	@Test
	public void test7() throws OWLOntologyCreationException {
		EntityRepresentationRdfSsn r1 = new EntityRepresentationRdfSsn();
		EntityRepresentationRdfQb r2 = new EntityRepresentationRdfQb();
		EntityRepresentationRdfSto r3 = new EntityRepresentationRdfSto();

		TemporalLocation tl = new TemporalLocationDateTime(
				"http://example.org#tl", new DateTime(2011, 1, 1, 0, 0, 0));

		SensorObservation o1 = new SensorObservationBase(
				"http://example.org#so1");
		o1.setTemporalLocation(tl);

		DatasetObservation o2 = new DatasetObservationBase(
				"http://example.org#do1");
		o2.addComponent(new ComponentPropertyBase("http://example.org#cp1"),
				new ComponentPropertyValueTemporalLocation(tl));

		Situation s = new SituationBase("http://example.org#situation1");
		ElementaryInfon i = new ElementaryInfonBase("http://example.org#infon1");
		i.addRelevantObject(new AttributeTemporalLocation(tl));
		s.addSupportedInfon(i);

		Set<Statement> statements = new HashSet<Statement>();

		statements.addAll(r1.createRepresentation(o1));
		statements.addAll(r2.createRepresentation(o2));
		statements.addAll(r3.createRepresentation(s));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI
								.create(SSN.observationResultTime)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI
								.create("http://example.org#cp1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#do1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(STO.anchor1)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#infon1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl")))));

		assertTrue(reasoner.isConsistent());
	}

	@Test
	public void test8() throws OWLOntologyCreationException {
		EntityRepresentationRdfSsn r1 = new EntityRepresentationRdfSsn();
		EntityRepresentationRdfQb r2 = new EntityRepresentationRdfQb();
		EntityRepresentationRdfSto r3 = new EntityRepresentationRdfSto();

		TemporalLocation tl1 = new TemporalLocationDateTime(
				"http://example.org#tl1", new DateTime(2011, 1, 1, 0, 0, 0));

		TemporalLocation tl2 = new TemporalLocationInterval(
				"http://example.org#tl2", new TemporalLocationDateTime(
						"http://example.org#dt1", new DateTime(2011, 1, 1, 0,
								0, 0)), new TemporalLocationDateTime(
						"http://example.org#dt2", new DateTime(2011, 1, 1, 0,
								0, 0)));

		GeometryFactory gf = new GeometryFactory();
		Point p = gf.createPoint(new Coordinate(0.0, 0.0));

		SpatialLocation sl1 = new SpatialLocationRegion(
				"http://example.org#sl1", new SpatialGeometryPoint(
						"http://example.org#g1", p));

		SpatialLocation sl2 = new SpatialLocationPlace("http://example.org#sl2");

		SensorObservation o1 = new SensorObservationBase(
				"http://example.org#so1");
		o1.setFeature(new FeatureBase("http://example.org#f1"));
		o1.setProperty(new PropertyBase("http://example.org#p1"));
		o1.setSensor(new SensorBase("http://example.org#s1"));
		o1.setTemporalLocation(tl1);
		o1.setSensorOutput(new SensorOutputBase("http://example.org#o1",
				new ObservationValueDouble("http://example.org#v1", 1.0)));
		o1.setSpatialLocation(sl2);

		DatasetObservation o2 = new DatasetObservationBase(
				"http://example.org#do1");
		o2.setDataset(new DatasetBase("http://example.org#d1"));
		o2.addComponent(new ComponentPropertyBase("http://example.org#cp1"),
				new ComponentPropertyValueTemporalLocation(tl1));
		o2.addComponent(new ComponentPropertyBase("http://example.org#cp2"),
				new ComponentPropertyValueSpatialLocation(sl1));
		o2.addComponent(new ComponentPropertyBase("http://example.org#cp3"),
				new ComponentPropertyValueSpatialLocation(sl2));
		o2.addComponent(new ComponentPropertyBase("http://example.org#cp4"),
				new ComponentPropertyValueDouble(1.0));
		o2.addComponent(
				new ComponentPropertyBase("http://example.org#cp5"),
				new ComponentPropertyValueUri(vf
						.createURI("http://example.org#f1")));
		o2.addComponent(new ComponentPropertyBase("http://example.org#cp6"),
				new ComponentPropertyValueTemporalLocation(tl2));

		Situation s = new SituationBase("http://example.org#sit");
		ElementaryInfon i = new ElementaryInfonBase("http://example.org#inf1");
		i.addRelevantObject(new AttributeTemporalLocation(tl1));
		i.addRelevantObject(new AttributeTemporalLocation(tl2));
		i.addRelevantObject(new AttributeSpatialLocation(sl1));
		i.addRelevantObject(new AttributeSpatialLocation(sl2));
		i.addRelevantObject(new AttributeUri("http://example.org#v2", vf
				.createURI("http://example.org#s1")));
		i.addRelevantObject(new RelevantIndividualBase("http://example.org#s1"));
		i.addRelevantObject(new RelevantIndividualBase("http://example.org#p1"));
		i.addRelevantObject(new RelevantIndividualBase("http://example.org#f1"));
		// TODO this fails if it is not a ValueString (because of STO Value
		// range being XSD string
		i.addRelevantObject(new ValueString("http://example.org#v1", "s1"));
		s.addSupportedInfon(i);

		Set<Statement> statements = new HashSet<Statement>();

		statements.addAll(r1.createRepresentation(o1));
		statements.addAll(r2.createRepresentation(o2));
		statements.addAll(r3.createRepresentation(s));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(reasoner.isConsistent());

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(WOE.TimePoint)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(WOE.TimeInterval)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl2")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(Time.Instant)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#tl1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(Time.Interval)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#tl2")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLDataPropertyAssertionAxiom(odf
						.getOWLDataProperty(IRI.create(Time.inXSDDateTime)),
						odf.getOWLNamedIndividual(IRI
								.create("http://example.org#tl1")), odf
								.getOWLLiteral(dtf1.print(new DateTime(2011, 1,
										1, 0, 0, 0)),
										OWL2Datatype.XSD_DATE_TIME))));

		assertFalse(ontology.containsAxiom(odf
				.getOWLDataPropertyAssertionAxiom(odf.getOWLDataProperty(IRI
						.create(Time.inXSDDateTime)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl1")), odf
						.getOWLLiteral(
								dtf1.print(new DateTime(2012, 1, 1, 0, 0, 0)),
								OWL2Datatype.XSD_DATE_TIME))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(WOE.SpatialRegion)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#sl1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(WOE.SpatialPlace)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#sl2")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(GeoSPARQL.Feature)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#sl2")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(GeoSPARQL.Feature)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#sl1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(WOE.TimeInterval)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl2")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(WOE.TimeInterval)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl2")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(WOE.SensorObservation)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(SSN.Observation)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(SSN.FeatureOfInterest)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#f1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(STO.RelevantIndividual)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#f1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(SSN.Property)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#p1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(STO.RelevantIndividual)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#p1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(SSN.Sensor)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#s1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(STO.RelevantIndividual)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(SSN.observedBy)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(
						odf.getOWLObjectProperty(IRI
								.create(SSN.observedProperty)), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#so1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#p1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(
						odf.getOWLObjectProperty(IRI
								.create(SSN.featureOfInterest)), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#so1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#f1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(
						odf.getOWLObjectProperty(IRI
								.create(SSN.observationResult)), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#so1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#o1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(DUL.hasRegion)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#o1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#v1")))));

		assertTrue(ontology.containsAxiom(odf.getOWLDataPropertyAssertionAxiom(
				odf.getOWLDataProperty(IRI.create(DUL.hasRegionDataValue)),
				odf.getOWLNamedIndividual(IRI.create("http://example.org#v1")),
				odf.getOWLLiteral(1.0))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI
								.create(SSN.observationResultTime)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#tl1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(WOE.DatasetObservation)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#do1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(QB.Observation)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#do1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(QB.DataSet)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#d1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(QB.dataSet)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#do1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#d1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(QB.ComponentProperty)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#cp1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLClassAssertionAxiom(odf
						.getOWLClass(IRI.create(STO.Attribute)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")))));
	}

	// PROV consistency tests
	@Test
	public void test9() throws OWLOntologyCreationException {
		EntityRepresentationRdfSsn r1 = new EntityRepresentationRdfSsn();
		EntityRepresentationRdfProv r2 = new EntityRepresentationRdfProv();
		
		SensorObservation o1 = new SensorObservationBase(
				"http://example.org#so1");
		Sensor s1 = new SensorBase("http://example.org#s1");
		Stimulus p1 = new StimulusBase("http://example.org#p1");

		o1.setSensor(s1);
		o1.setStimulus(p1);

		Set<Statement> statements = new HashSet<Statement>();

		statements.addAll(r1.createRepresentation(o1));
		statements.addAll(r1.createRepresentation(s1));
		statements.addAll(r1.createRepresentation(p1));
		
		statements.addAll(r2.createRepresentation(o1));
		statements.addAll(r2.createRepresentation(s1));
		statements.addAll(r2.createRepresentation(p1));

		OWLOntology ontology = createOntology(statements);
		OWLReasoner reasoner = createReasoner(ontology);

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(SSN.Observation)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")))));
		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(PROV.Entity)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#so1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(SSN.Sensor)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#s1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(PROV.Agent)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#s1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(SSN.Stimulus)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#p1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLClassAssertionAxiom(odf.getOWLClass(IRI
						.create(PROV.Activity)), odf.getOWLNamedIndividual(IRI
						.create("http://example.org#p1")))));

		assertTrue(ontology.containsAxiom(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(SSN.observedBy)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")))));
		
		assertTrue(reasoner.isEntailed(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(PROV.wasAttributedTo)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")))));

		assertTrue(ontology
				.containsAxiom(odf.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(DUL.includesEvent)),
						odf.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#p1")))));
		
		assertTrue(reasoner.isEntailed(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(PROV.wasAssociatedWith)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#p1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")))));
		
		assertTrue(reasoner.isEntailed(odf
				.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(PROV.wasAssociateFor)), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#s1")), odf
						.getOWLNamedIndividual(IRI
								.create("http://example.org#p1")))));

		assertTrue(reasoner
				.isEntailed(odf.getOWLObjectPropertyAssertionAxiom(odf
						.getOWLObjectProperty(IRI.create(PROV.wasGeneratedBy)),
						odf.getOWLNamedIndividual(IRI
								.create("http://example.org#so1")), odf
								.getOWLNamedIndividual(IRI
										.create("http://example.org#p1")))));

		assertTrue(reasoner.isConsistent());
	}

	private OWLOntology createOntology(Set<Statement> statements)
			throws OWLOntologyCreationException {
		statements.add(vf.createStatement(
				vf.createURI("http://envi.uef.fi/wavellite/ontology/test"),
				vf.createURI("http://www.w3.org/2002/07/owl#imports"),
				vf.createURI("http://envi.uef.fi/wavellite/ontology/entity")));
		statements
				.add(vf.createStatement(
						vf.createURI("http://example.org#cp1"),
						vf.createURI("http://www.w3.org/1999/02/22-rdf-syntax-ns#type"),
						vf.createURI("http://www.w3.org/2002/07/owl#ObjectProperty")));
		statements
				.add(vf.createStatement(
						vf.createURI("http://example.org#cp2"),
						vf.createURI("http://www.w3.org/1999/02/22-rdf-syntax-ns#type"),
						vf.createURI("http://www.w3.org/2002/07/owl#ObjectProperty")));
		statements
				.add(vf.createStatement(
						vf.createURI("http://example.org#cp3"),
						vf.createURI("http://www.w3.org/1999/02/22-rdf-syntax-ns#type"),
						vf.createURI("http://www.w3.org/2002/07/owl#ObjectProperty")));
		statements
				.add(vf.createStatement(
						vf.createURI("http://example.org#cp4"),
						vf.createURI("http://www.w3.org/1999/02/22-rdf-syntax-ns#type"),
						vf.createURI("http://www.w3.org/2002/07/owl#ObjectProperty")));
		statements
				.add(vf.createStatement(
						vf.createURI("http://example.org#cp5"),
						vf.createURI("http://www.w3.org/1999/02/22-rdf-syntax-ns#type"),
						vf.createURI("http://www.w3.org/2002/07/owl#ObjectProperty")));
		statements
				.add(vf.createStatement(
						vf.createURI("http://example.org#cp6"),
						vf.createURI("http://www.w3.org/1999/02/22-rdf-syntax-ns#type"),
						vf.createURI("http://www.w3.org/2002/07/owl#ObjectProperty")));

		ByteArrayOutputStream os = new ByteArrayOutputStream();

		RDFWriter rdfWriter = Rio.createWriter(RDFFormat.RDFXML, os);

		try {
			rdfWriter.startRDF();

			for (Statement statement : statements) {
				rdfWriter.handleStatement(statement);
			}

			rdfWriter.endRDF();
		} catch (RDFHandlerException e) {
			throw new RuntimeException(e);
		}

		InputStream is = new ByteArrayInputStream(os.toByteArray());

		// System.out.println(os.toString());

		return manager.loadOntologyFromOntologyDocument(is);
	}

	private OWLReasoner createReasoner(OWLOntology ontology) {
		OWLReasonerFactory reasonerFactory = new Reasoner.ReasonerFactory();

		return reasonerFactory.createReasoner(ontology);
	}

	// Has to be @Before and not @BeforeClass because otherwise you get an
	// ontology already exist exception
	// (http://envi.uef.fi/wavellite/ontology/test is used in each test)
	@Before
	public void before() {
		String dir = "../wavellite-vocabulary/ontology/";

		Map<String, String> m = new HashMap<String, String>();

		m.put("http://www.loa-cnr.it/ontologies/DUL.owl", "DUL.owl");
		m.put("http://purl.oclc.org/NET/ssnx/ssn", "ssn.owl");
		m.put("http://purl.org/linked-data/cube", "cube.rdf");
		m.put("http://vistology.com/ont/2008/STO/STO.owl", "STO.owl");
		m.put("http://www.opengis.net/ont/geosparql", "geosparql_vocab_all.rdf");
		m.put("http://www.opengis.net/ont/gml", "gml_32_geometries.rdf");
		m.put("http://www.opengis.net/ont/sf", "simple_features_geometries.rdf");
		m.put("http://www.w3.org/2006/time", "owl-time.owl");
		m.put("http://www.w3.org/2004/02/skos/core", "skos.rdf");
		m.put("http://purl.org/dc/elements/1.1/", "dcelements.rdf");
		m.put("http://www.w3.org/ns/prov", "prov.owl");
		m.put("http://envi.uef.fi/wavellite/ontology/core",
				"wavellite/1.1.0/wavellite-core-1.1.0.owl");
		m.put("http://envi.uef.fi/wavellite/ontology/entity",
				"wavellite/1.1.0/wavellite-entity-1.1.0.owl");

		manager = OWLManager.createOWLOntologyManager();
		odf = manager.getOWLDataFactory();

		for (Map.Entry<String, String> e : m.entrySet()) {
			manager.addIRIMapper(new SimpleIRIMapper(IRI.create(e.getKey()),
					IRI.create(new File(dir + e.getValue()))));
		}
	}
}
