/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.server;

import java.util.Iterator;
import java.util.List;

import javax.servlet.ServletContext;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import org.apache.commons.lang.StringEscapeUtils;

import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.representation.json.EntityRepresentationJsonSto;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdfSto;
import fi.uef.envi.wavellite.representation.text.EntityRepresentationTextSto;
import fi.uef.envi.wavellite.server.handler.ParamHandler;
import fi.uef.envi.wavellite.server.handler.RequestHandler;
import fi.uef.envi.wavellite.server.handler.ResponseHandler;

/**
 * <p>
 * Title: ResourceSituation
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Server
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

@Path("{db}/situation")
public class ResourceSituation {

	@PathParam("db")
	private String db;

	@Context
	private ServletContext servletContext;

	@GET
	@Path("list")
	@Produces(MediaType.APPLICATION_JSON)
	public Response getListAsJson(
			@QueryParam("relationId") final List<String> relationIds,
			@QueryParam("from") String from, @QueryParam("to") String to) {
		return ResponseHandler.getJsonResponse(
				new EntityRepresentationJsonSto(),
				RequestHandler.getSituations(servletContext, db,
						ParamHandler.asInterval(from, to),
						ParamHandler.asRelationArray(relationIds)));
	}

	@GET
	@Path("list")
	@Produces(MediaType.TEXT_HTML)
	public Response getListAsHtml(
			@QueryParam("relationId") final List<String> relationIds,
			@QueryParam("from") String from, @QueryParam("to") String to) {
		Iterator<Situation> it = RequestHandler.getSituations(servletContext,
				db, ParamHandler.asInterval(from, to),
				ParamHandler.asRelationArray(relationIds));

		StringBuffer sb = new StringBuffer();
		EntityRepresentationTextSto r = new EntityRepresentationTextSto();

		while (it.hasNext()) {
			sb.append(r.createRepresentation(it.next()));
		}

		return ResponseHandler.getHtmlResponse(
				"/situation-list",
				StringEscapeUtils.escapeHtml(sb.toString()).replaceAll("\\n",
						"<br/>"));
	}

	@GET
	@Path("list")
	@Produces("application/rdf+xml")
	public Response getListAsRdfXml(
			@QueryParam("relationId") final List<String> relationIds,
			@QueryParam("from") String from, @QueryParam("to") String to) {
		return ResponseHandler.getRdfResponse(
				new EntityRepresentationRdfSto(),
				RequestHandler.getSituations(servletContext, db,
						ParamHandler.asInterval(from, to),
						ParamHandler.asRelationArray(relationIds)));
	}

}
