/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.server.handler;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.List;

import javax.ws.rs.WebApplicationException;

import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.base.FeatureBase;
import fi.uef.envi.wavellite.entity.core.base.PropertyBase;
import fi.uef.envi.wavellite.entity.core.base.SensorBase;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationDateTime;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.base.RelationBase;

/**
 * <p>
 * Title: ParamHandler
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Server
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class ParamHandler {

	private static final DateTimeFormatter dtf = ISODateTimeFormat.dateTime()
			.withOffsetParsed();

	public static TemporalLocationDateTime asDateTime(String time) {
		if (time == null)
			return null;

		return new TemporalLocationDateTime(dtf.parseDateTime(time));
	}

	public static TemporalLocationInterval asInterval(String from, String to) {
		if (from == null || to == null)
			return null;

		return new TemporalLocationInterval(asDateTime(from), asDateTime(to));
	}

	public static Relation[] asRelationArray(List<String> relations) {
		Relation[] ret = new Relation[] {};

		if (relations == null)
			return ret;

		ret = new Relation[relations.size()];

		for (int i = 0; i < relations.size(); i++) {
			ret[i] = new RelationBase(decode(relations.get(i)));
		}

		return ret;
	}
	
	public static Sensor asSensor(String sensorId) {
		if (sensorId == null)
			return null;
		
		return new SensorBase(decode(sensorId));
	}
	
	public static Property asProperty(String propertyId) {
		if (propertyId == null)
			return null;
		
		return new PropertyBase(decode(propertyId));
	}
	
	public static Feature asFeature(String featureId) {
		if (featureId == null)
			return null;
		
		return new FeatureBase(decode(featureId));
	}
	
	private static String decode(String encoded) {
		if (encoded == null)
			return null;
		
		try {
			return URLDecoder.decode(encoded, "UTF-8");
		} catch (UnsupportedEncodingException e) {
			throw new WebApplicationException(e);
		}
	}
}
