/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.server.handler;

import java.io.IOException;
import java.io.InputStream;
import java.util.Iterator;
import java.util.Properties;

import javax.servlet.ServletContext;
import javax.ws.rs.WebApplicationException;

import fi.uef.envi.wavellite.entity.core.Feature;
import fi.uef.envi.wavellite.entity.core.Property;
import fi.uef.envi.wavellite.entity.core.Sensor;
import fi.uef.envi.wavellite.entity.core.base.TemporalLocationInterval;
import fi.uef.envi.wavellite.entity.observation.SensorObservation;
import fi.uef.envi.wavellite.entity.situation.Relation;
import fi.uef.envi.wavellite.entity.situation.Situation;
import fi.uef.envi.wavellite.module.store.ModuleStore;
import fi.uef.envi.wavellite.module.store.stardog.ModuleStoreStardog;
import fi.uef.envi.wavellite.server.Options;

/**
 * <p>
 * Title: RequestHandler
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Server
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class RequestHandler {

	public static Iterator<SensorObservation> getSensorObservations(
			ServletContext context, String db, Sensor sensor,
			Property property, Feature feature,
			TemporalLocationInterval interval) {
		ModuleStore store = create(context, db);

		Iterator<SensorObservation> ret = store.getSensorObservations(sensor,
				property, feature, interval, true);

		store.close();

		return ret;
	}

	public static Iterator<Relation> getRelations(ServletContext context,
			String db) {
		ModuleStore store = create(context, db);

		Iterator<Relation> ret = store.getRelations();

		store.close();

		return ret;
	}

	public static Iterator<Situation> getSituations(ServletContext context,
			String db, TemporalLocationInterval interval, Relation[] relations) {
		ModuleStore store = create(context, db);

		Iterator<Situation> ret = store.getSituations(interval, relations);

		store.close();

		return ret;
	}

	private static ModuleStore create(ServletContext servletContext, String db) {
		Properties properties = new Properties();

		try {
			InputStream is = servletContext
					.getResourceAsStream(Options.MODULE_STORE_PROPERTIES);

			if (is != null)
				properties.load(is);
		} catch (IOException e) {
			throw new WebApplicationException(e);
		}

		return new ModuleStoreStardog("snarl", properties.getProperty("host",
				Options.DEFAULT_HOST), Integer.valueOf(properties.getProperty(
				"port", Options.DEFAULT_PORT.toString())), db);
	}
}
