/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.server.handler;

import java.io.ByteArrayOutputStream;
import java.io.UnsupportedEncodingException;
import java.util.Iterator;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Response;

import org.openrdf.model.Statement;
import org.openrdf.rio.RDFFormat;
import org.openrdf.rio.RDFHandlerException;
import org.openrdf.rio.RDFWriter;
import org.openrdf.rio.Rio;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ArrayNode;
import com.sun.jersey.api.view.Viewable;

import fi.uef.envi.wavellite.entity.core.Entity;
import fi.uef.envi.wavellite.representation.json.EntityRepresentationJson;
import fi.uef.envi.wavellite.representation.rdf.EntityRepresentationRdf;

/**
 * <p>
 * Title: ResponseHandler
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Server
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class ResponseHandler {

	private static final ObjectMapper mapper = new ObjectMapper();

	public static Response getTextResponse(String text) {
		return asResponse(text);
	}
	
	public static Response getJsonResponse(
			EntityRepresentationJson entityRepresentation,
			Iterator<? extends Entity> it) {
		return asResponse(asString(asArrayNode(entityRepresentation, it)));
	}

	public static Response getRdfResponse(
			EntityRepresentationRdf entityRepresentation,
			Iterator<? extends Entity> it) {
		return asResponse(asString(entityRepresentation, it));
	}

	public static Response getHtmlResponse(String templateName, Object object) {
		return asResponse(new Viewable(templateName, object));
	}

	private static Response asResponse(Object ret) {
		return Response.ok(ret).header("Access-Control-Allow-Origin", "*")
				.build();
	}

	private static ArrayNode asArrayNode(
			EntityRepresentationJson entityRepresentation,
			Iterator<? extends Entity> it) {
		ArrayNode ret = mapper.createArrayNode();

		while (it.hasNext()) {
			ret.add(entityRepresentation.createRepresentation(it.next()));
		}

		return ret;
	}

	public static String asString(EntityRepresentationRdf entityRepresentation,
			Iterator<? extends Entity> it) {
		ByteArrayOutputStream out = new ByteArrayOutputStream();
		RDFWriter writer = Rio.createWriter(RDFFormat.RDFXML, out);

		try {
			writer.startRDF();

			while (it.hasNext()) {
				for (Statement st : entityRepresentation
						.createRepresentation(it.next())) {
					writer.handleStatement(st);
				}
			}

			writer.endRDF();
		} catch (RDFHandlerException e) {
			throw new WebApplicationException(e);
		}

		try {
			return out.toString("UTF-8");
		} catch (UnsupportedEncodingException e) {
			throw new WebApplicationException(e);
		}
	}

	private static String asString(JsonNode node) {
		String ret = null;

		try {
			ret = mapper.writeValueAsString(node);
		} catch (JsonProcessingException e) {
			throw new WebApplicationException(e);
		}

		return ret;
	}

}
