/*
 * Copyright (C) 2014 see CREDITS.txt
 * All rights reserved.
 */

package fi.uef.envi.wavellite.shell;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import javax.naming.Context;

import fi.uef.envi.wavellite.component.Component;
import fi.uef.envi.wavellite.component.engine.activemq.EngineDatasetActiveMq;
import fi.uef.envi.wavellite.component.engine.activemq.EngineObservationActiveMq;
import fi.uef.envi.wavellite.component.writer.activemq.WriterDerivationActiveMq;
import fi.uef.envi.wavellite.component.writer.activemq.WriterObservationActiveMq;
import fi.uef.envi.wavellite.component.writer.activemq.WriterSituationActiveMq;
import fi.uef.envi.wavellite.entity.derivation.base.ComponentPropertyMeasure;
import fi.uef.envi.wavellite.entity.derivation.base.DatasetBase;
import fi.uef.envi.wavellite.module.store.stardog.ModuleStoreStardog;
import fi.uef.envi.wavellite.operator.translation.base.SensorObservationTranslatorBase;

import asg.cliche.Command;
import asg.cliche.ShellFactory;

/**
 * <p>
 * Title: WavelliteShell
 * </p>
 * <p>
 * Description:
 * </p>
 * <p>
 * Project: Wavellite Shell
 * </p>
 * <p>
 * Copyright: Copyright (C) 2014
 * </p>
 * 
 * @author Markus Stocker
 */

public class WavelliteShell {

	private Map<String, Component> components;

	public WavelliteShell() {
		components = new HashMap<String, Component>();
	}

	@Command
	public void startObservationEngine(String id, String url,
			String consumerDestinationName, String producerDestinationName) {
		components.put(
				id,
				new EngineObservationActiveMq(consumerDestinationName,
						producerDestinationName, createProperties(url,
								consumerDestinationName,
								producerDestinationName)));
	}

	@Command
	public void startDatasetEngine(String id, String url,
			String consumerDestinationName, String producerDestinationName,
			String sensorOutputMeasureId, String datasetId) {
		components.put(
				id,
				new EngineDatasetActiveMq(consumerDestinationName,
						producerDestinationName,
						new SensorObservationTranslatorBase(
								new ComponentPropertyMeasure(
										sensorOutputMeasureId),
								new DatasetBase(datasetId)), createProperties(
								url, consumerDestinationName,
								producerDestinationName)));
	}

	@Command
	public void startObservationWriter(String id, String url,
			String consumerDestinationName, String stardogUrl,
			String stardogDatabaseName) {
		components.put(
				id,
				new WriterObservationActiveMq(new ModuleStoreStardog(
						stardogUrl, stardogDatabaseName),
						consumerDestinationName, createProperties(url,
								consumerDestinationName, null)));
	}

	@Command
	public void startDerivationWriter(String id, String url,
			String consumerDestinationName, String stardogUrl,
			String stardogDatabaseName) {
		components.put(id, new WriterDerivationActiveMq(new ModuleStoreStardog(
				stardogUrl, stardogDatabaseName), consumerDestinationName,
				createProperties(url, consumerDestinationName, null)));
	}
	
	@Command
	public void startSituationWriter(String id, String url,
			String consumerDestinationName, String stardogUrl,
			String stardogDatabaseName) {
		components.put(id, new WriterSituationActiveMq(new ModuleStoreStardog(
				stardogUrl, stardogDatabaseName), consumerDestinationName,
				createProperties(url, consumerDestinationName, null)));
	}

	@Command
	public void stopComponent(String id) {
		components.get(id).close();
	}

	@Command
	public void listComponents() {
		StringBuffer sb = new StringBuffer();

		for (String id : components.keySet())
			sb.append(id + "\n");

		System.out.print(sb);
	}

	@Command
	public void exit() {
		for (Component component : components.values())
			component.close();
	}

	private Properties createProperties(String url,
			String consumerDestinationName, String producerDestinationName) {
		Properties properties = new Properties();
		properties.setProperty(Context.INITIAL_CONTEXT_FACTORY,
				"org.apache.activemq.jndi.ActiveMQInitialContextFactory");
		properties.setProperty(Context.PROVIDER_URL, url);
		properties.setProperty("connectionFactoryNames", "ConnectionFactory");

		if (consumerDestinationName != null)
			properties.setProperty("topic." + consumerDestinationName,
					consumerDestinationName);

		if (producerDestinationName != null)
			properties.setProperty("topic." + producerDestinationName,
					producerDestinationName);

		return properties;
	}

	public static void main(String[] args) throws IOException {
		ShellFactory.createConsoleShell("wavellite", "", new WavelliteShell())
				.commandLoop();
	}

}
